(function(){"use strict";var Zn={exports:{}},Du={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var gc;function Ho(){if(gc)return Du;gc=1;var p=Symbol.for("react.transitional.element"),cl=Symbol.for("react.fragment");function $(h,vl,Sl){var rl=null;if(Sl!==void 0&&(rl=""+Sl),vl.key!==void 0&&(rl=""+vl.key),"key"in vl){Sl={};for(var Dl in vl)Dl!=="key"&&(Sl[Dl]=vl[Dl])}else Sl=vl;return vl=Sl.ref,{$$typeof:p,type:h,key:rl,ref:vl!==void 0?vl:null,props:Sl}}return Du.Fragment=cl,Du.jsx=$,Du.jsxs=$,Du}var Sc;function Ro(){return Sc||(Sc=1,Zn.exports=Ho()),Zn.exports}var B=Ro(),Vn={exports:{}},Uu={},Ln={exports:{}},Kn={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var rc;function No(){return rc||(rc=1,(function(p){function cl(r,A){var C=r.length;r.push(A);l:for(;0<C;){var el=C-1>>>1,sl=r[el];if(0<vl(sl,A))r[el]=A,r[C]=sl,C=el;else break l}}function $(r){return r.length===0?null:r[0]}function h(r){if(r.length===0)return null;var A=r[0],C=r.pop();if(C!==A){r[0]=C;l:for(var el=0,sl=r.length,d=sl>>>1;el<d;){var T=2*(el+1)-1,_=r[T],O=T+1,j=r[O];if(0>vl(_,C))O<sl&&0>vl(j,_)?(r[el]=j,r[O]=C,el=O):(r[el]=_,r[T]=C,el=T);else if(O<sl&&0>vl(j,C))r[el]=j,r[O]=C,el=O;else break l}}return A}function vl(r,A){var C=r.sortIndex-A.sortIndex;return C!==0?C:r.id-A.id}if(p.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var Sl=performance;p.unstable_now=function(){return Sl.now()}}else{var rl=Date,Dl=rl.now();p.unstable_now=function(){return rl.now()-Dl}}var U=[],E=[],k=1,R=null,P=3,jl=!1,Yl=!1,Ml=!1,Il=!1,H=typeof setTimeout=="function"?setTimeout:null,Pl=typeof clearTimeout=="function"?clearTimeout:null,Gl=typeof setImmediate<"u"?setImmediate:null;function dt(r){for(var A=$(E);A!==null;){if(A.callback===null)h(E);else if(A.startTime<=r)h(E),A.sortIndex=A.expirationTime,cl(U,A);else break;A=$(E)}}function _t(r){if(Ml=!1,dt(r),!Yl)if($(U)!==null)Yl=!0,Zl||(Zl=!0,Ll());else{var A=$(E);A!==null&&Tt(_t,A.startTime-r)}}var Zl=!1,w=-1,Vl=5,Mt=-1;function Va(){return Il?!0:!(p.unstable_now()-Mt<Vl)}function Ot(){if(Il=!1,Zl){var r=p.unstable_now();Mt=r;var A=!0;try{l:{Yl=!1,Ml&&(Ml=!1,Pl(w),w=-1),jl=!0;var C=P;try{t:{for(dt(r),R=$(U);R!==null&&!(R.expirationTime>r&&Va());){var el=R.callback;if(typeof el=="function"){R.callback=null,P=R.priorityLevel;var sl=el(R.expirationTime<=r);if(r=p.unstable_now(),typeof sl=="function"){R.callback=sl,dt(r),A=!0;break t}R===$(U)&&h(U),dt(r)}else h(U);R=$(U)}if(R!==null)A=!0;else{var d=$(E);d!==null&&Tt(_t,d.startTime-r),A=!1}}break l}finally{R=null,P=C,jl=!1}A=void 0}}finally{A?Ll():Zl=!1}}}var Ll;if(typeof Gl=="function")Ll=function(){Gl(Ot)};else if(typeof MessageChannel<"u"){var pa=new MessageChannel,Nt=pa.port2;pa.port1.onmessage=Ot,Ll=function(){Nt.postMessage(null)}}else Ll=function(){H(Ot,0)};function Tt(r,A){w=H(function(){r(p.unstable_now())},A)}p.unstable_IdlePriority=5,p.unstable_ImmediatePriority=1,p.unstable_LowPriority=4,p.unstable_NormalPriority=3,p.unstable_Profiling=null,p.unstable_UserBlockingPriority=2,p.unstable_cancelCallback=function(r){r.callback=null},p.unstable_forceFrameRate=function(r){0>r||125<r?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):Vl=0<r?Math.floor(1e3/r):5},p.unstable_getCurrentPriorityLevel=function(){return P},p.unstable_next=function(r){switch(P){case 1:case 2:case 3:var A=3;break;default:A=P}var C=P;P=A;try{return r()}finally{P=C}},p.unstable_requestPaint=function(){Il=!0},p.unstable_runWithPriority=function(r,A){switch(r){case 1:case 2:case 3:case 4:case 5:break;default:r=3}var C=P;P=r;try{return A()}finally{P=C}},p.unstable_scheduleCallback=function(r,A,C){var el=p.unstable_now();switch(typeof C=="object"&&C!==null?(C=C.delay,C=typeof C=="number"&&0<C?el+C:el):C=el,r){case 1:var sl=-1;break;case 2:sl=250;break;case 5:sl=1073741823;break;case 4:sl=1e4;break;default:sl=5e3}return sl=C+sl,r={id:k++,callback:A,priorityLevel:r,startTime:C,expirationTime:sl,sortIndex:-1},C>el?(r.sortIndex=C,cl(E,r),$(U)===null&&r===$(E)&&(Ml?(Pl(w),w=-1):Ml=!0,Tt(_t,C-el))):(r.sortIndex=sl,cl(U,r),Yl||jl||(Yl=!0,Zl||(Zl=!0,Ll()))),r},p.unstable_shouldYield=Va,p.unstable_wrapCallback=function(r){var A=P;return function(){var C=P;P=A;try{return r.apply(this,arguments)}finally{P=C}}}})(Kn)),Kn}var bc;function Co(){return bc||(bc=1,Ln.exports=No()),Ln.exports}var Jn={exports:{}},q={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var zc;function Bo(){if(zc)return q;zc=1;var p=Symbol.for("react.transitional.element"),cl=Symbol.for("react.portal"),$=Symbol.for("react.fragment"),h=Symbol.for("react.strict_mode"),vl=Symbol.for("react.profiler"),Sl=Symbol.for("react.consumer"),rl=Symbol.for("react.context"),Dl=Symbol.for("react.forward_ref"),U=Symbol.for("react.suspense"),E=Symbol.for("react.memo"),k=Symbol.for("react.lazy"),R=Symbol.for("react.activity"),P=Symbol.iterator;function jl(d){return d===null||typeof d!="object"?null:(d=P&&d[P]||d["@@iterator"],typeof d=="function"?d:null)}var Yl={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},Ml=Object.assign,Il={};function H(d,T,_){this.props=d,this.context=T,this.refs=Il,this.updater=_||Yl}H.prototype.isReactComponent={},H.prototype.setState=function(d,T){if(typeof d!="object"&&typeof d!="function"&&d!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,d,T,"setState")},H.prototype.forceUpdate=function(d){this.updater.enqueueForceUpdate(this,d,"forceUpdate")};function Pl(){}Pl.prototype=H.prototype;function Gl(d,T,_){this.props=d,this.context=T,this.refs=Il,this.updater=_||Yl}var dt=Gl.prototype=new Pl;dt.constructor=Gl,Ml(dt,H.prototype),dt.isPureReactComponent=!0;var _t=Array.isArray;function Zl(){}var w={H:null,A:null,T:null,S:null},Vl=Object.prototype.hasOwnProperty;function Mt(d,T,_){var O=_.ref;return{$$typeof:p,type:d,key:T,ref:O!==void 0?O:null,props:_}}function Va(d,T){return Mt(d.type,T,d.props)}function Ot(d){return typeof d=="object"&&d!==null&&d.$$typeof===p}function Ll(d){var T={"=":"=0",":":"=2"};return"$"+d.replace(/[=:]/g,function(_){return T[_]})}var pa=/\/+/g;function Nt(d,T){return typeof d=="object"&&d!==null&&d.key!=null?Ll(""+d.key):T.toString(36)}function Tt(d){switch(d.status){case"fulfilled":return d.value;case"rejected":throw d.reason;default:switch(typeof d.status=="string"?d.then(Zl,Zl):(d.status="pending",d.then(function(T){d.status==="pending"&&(d.status="fulfilled",d.value=T)},function(T){d.status==="pending"&&(d.status="rejected",d.reason=T)})),d.status){case"fulfilled":return d.value;case"rejected":throw d.reason}}throw d}function r(d,T,_,O,j){var Q=typeof d;(Q==="undefined"||Q==="boolean")&&(d=null);var tl=!1;if(d===null)tl=!0;else switch(Q){case"bigint":case"string":case"number":tl=!0;break;case"object":switch(d.$$typeof){case p:case cl:tl=!0;break;case k:return tl=d._init,r(tl(d._payload),T,_,O,j)}}if(tl)return j=j(d),tl=O===""?"."+Nt(d,0):O,_t(j)?(_="",tl!=null&&(_=tl.replace(pa,"$&/")+"/"),r(j,T,_,"",function(xu){return xu})):j!=null&&(Ot(j)&&(j=Va(j,_+(j.key==null||d&&d.key===j.key?"":(""+j.key).replace(pa,"$&/")+"/")+tl)),T.push(j)),1;tl=0;var Xl=O===""?".":O+":";if(_t(d))for(var bl=0;bl<d.length;bl++)O=d[bl],Q=Xl+Nt(O,bl),tl+=r(O,T,_,Q,j);else if(bl=jl(d),typeof bl=="function")for(d=bl.call(d),bl=0;!(O=d.next()).done;)O=O.value,Q=Xl+Nt(O,bl++),tl+=r(O,T,_,Q,j);else if(Q==="object"){if(typeof d.then=="function")return r(Tt(d),T,_,O,j);throw T=String(d),Error("Objects are not valid as a React child (found: "+(T==="[object Object]"?"object with keys {"+Object.keys(d).join(", ")+"}":T)+"). If you meant to render a collection of children, use an array instead.")}return tl}function A(d,T,_){if(d==null)return d;var O=[],j=0;return r(d,O,"","",function(Q){return T.call(_,Q,j++)}),O}function C(d){if(d._status===-1){var T=d._result;T=T(),T.then(function(_){(d._status===0||d._status===-1)&&(d._status=1,d._result=_)},function(_){(d._status===0||d._status===-1)&&(d._status=2,d._result=_)}),d._status===-1&&(d._status=0,d._result=T)}if(d._status===1)return d._result.default;throw d._result}var el=typeof reportError=="function"?reportError:function(d){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var T=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof d=="object"&&d!==null&&typeof d.message=="string"?String(d.message):String(d),error:d});if(!window.dispatchEvent(T))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",d);return}console.error(d)},sl={map:A,forEach:function(d,T,_){A(d,function(){T.apply(this,arguments)},_)},count:function(d){var T=0;return A(d,function(){T++}),T},toArray:function(d){return A(d,function(T){return T})||[]},only:function(d){if(!Ot(d))throw Error("React.Children.only expected to receive a single React element child.");return d}};return q.Activity=R,q.Children=sl,q.Component=H,q.Fragment=$,q.Profiler=vl,q.PureComponent=Gl,q.StrictMode=h,q.Suspense=U,q.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=w,q.__COMPILER_RUNTIME={__proto__:null,c:function(d){return w.H.useMemoCache(d)}},q.cache=function(d){return function(){return d.apply(null,arguments)}},q.cacheSignal=function(){return null},q.cloneElement=function(d,T,_){if(d==null)throw Error("The argument must be a React element, but you passed "+d+".");var O=Ml({},d.props),j=d.key;if(T!=null)for(Q in T.key!==void 0&&(j=""+T.key),T)!Vl.call(T,Q)||Q==="key"||Q==="__self"||Q==="__source"||Q==="ref"&&T.ref===void 0||(O[Q]=T[Q]);var Q=arguments.length-2;if(Q===1)O.children=_;else if(1<Q){for(var tl=Array(Q),Xl=0;Xl<Q;Xl++)tl[Xl]=arguments[Xl+2];O.children=tl}return Mt(d.type,j,O)},q.createContext=function(d){return d={$$typeof:rl,_currentValue:d,_currentValue2:d,_threadCount:0,Provider:null,Consumer:null},d.Provider=d,d.Consumer={$$typeof:Sl,_context:d},d},q.createElement=function(d,T,_){var O,j={},Q=null;if(T!=null)for(O in T.key!==void 0&&(Q=""+T.key),T)Vl.call(T,O)&&O!=="key"&&O!=="__self"&&O!=="__source"&&(j[O]=T[O]);var tl=arguments.length-2;if(tl===1)j.children=_;else if(1<tl){for(var Xl=Array(tl),bl=0;bl<tl;bl++)Xl[bl]=arguments[bl+2];j.children=Xl}if(d&&d.defaultProps)for(O in tl=d.defaultProps,tl)j[O]===void 0&&(j[O]=tl[O]);return Mt(d,Q,j)},q.createRef=function(){return{current:null}},q.forwardRef=function(d){return{$$typeof:Dl,render:d}},q.isValidElement=Ot,q.lazy=function(d){return{$$typeof:k,_payload:{_status:-1,_result:d},_init:C}},q.memo=function(d,T){return{$$typeof:E,type:d,compare:T===void 0?null:T}},q.startTransition=function(d){var T=w.T,_={};w.T=_;try{var O=d(),j=w.S;j!==null&&j(_,O),typeof O=="object"&&O!==null&&typeof O.then=="function"&&O.then(Zl,el)}catch(Q){el(Q)}finally{T!==null&&_.types!==null&&(T.types=_.types),w.T=T}},q.unstable_useCacheRefresh=function(){return w.H.useCacheRefresh()},q.use=function(d){return w.H.use(d)},q.useActionState=function(d,T,_){return w.H.useActionState(d,T,_)},q.useCallback=function(d,T){return w.H.useCallback(d,T)},q.useContext=function(d){return w.H.useContext(d)},q.useDebugValue=function(){},q.useDeferredValue=function(d,T){return w.H.useDeferredValue(d,T)},q.useEffect=function(d,T){return w.H.useEffect(d,T)},q.useEffectEvent=function(d){return w.H.useEffectEvent(d)},q.useId=function(){return w.H.useId()},q.useImperativeHandle=function(d,T,_){return w.H.useImperativeHandle(d,T,_)},q.useInsertionEffect=function(d,T){return w.H.useInsertionEffect(d,T)},q.useLayoutEffect=function(d,T){return w.H.useLayoutEffect(d,T)},q.useMemo=function(d,T){return w.H.useMemo(d,T)},q.useOptimistic=function(d,T){return w.H.useOptimistic(d,T)},q.useReducer=function(d,T,_){return w.H.useReducer(d,T,_)},q.useRef=function(d){return w.H.useRef(d)},q.useState=function(d){return w.H.useState(d)},q.useSyncExternalStore=function(d,T,_){return w.H.useSyncExternalStore(d,T,_)},q.useTransition=function(){return w.H.useTransition()},q.version="19.2.4",q}var Tc;function wn(){return Tc||(Tc=1,Jn.exports=Bo()),Jn.exports}var Wn={exports:{}},ql={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Ec;function qo(){if(Ec)return ql;Ec=1;var p=wn();function cl(U){var E="https://react.dev/errors/"+U;if(1<arguments.length){E+="?args[]="+encodeURIComponent(arguments[1]);for(var k=2;k<arguments.length;k++)E+="&args[]="+encodeURIComponent(arguments[k])}return"Minified React error #"+U+"; visit "+E+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function $(){}var h={d:{f:$,r:function(){throw Error(cl(522))},D:$,C:$,L:$,m:$,X:$,S:$,M:$},p:0,findDOMNode:null},vl=Symbol.for("react.portal");function Sl(U,E,k){var R=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:vl,key:R==null?null:""+R,children:U,containerInfo:E,implementation:k}}var rl=p.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function Dl(U,E){if(U==="font")return"";if(typeof E=="string")return E==="use-credentials"?E:""}return ql.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=h,ql.createPortal=function(U,E){var k=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!E||E.nodeType!==1&&E.nodeType!==9&&E.nodeType!==11)throw Error(cl(299));return Sl(U,E,null,k)},ql.flushSync=function(U){var E=rl.T,k=h.p;try{if(rl.T=null,h.p=2,U)return U()}finally{rl.T=E,h.p=k,h.d.f()}},ql.preconnect=function(U,E){typeof U=="string"&&(E?(E=E.crossOrigin,E=typeof E=="string"?E==="use-credentials"?E:"":void 0):E=null,h.d.C(U,E))},ql.prefetchDNS=function(U){typeof U=="string"&&h.d.D(U)},ql.preinit=function(U,E){if(typeof U=="string"&&E&&typeof E.as=="string"){var k=E.as,R=Dl(k,E.crossOrigin),P=typeof E.integrity=="string"?E.integrity:void 0,jl=typeof E.fetchPriority=="string"?E.fetchPriority:void 0;k==="style"?h.d.S(U,typeof E.precedence=="string"?E.precedence:void 0,{crossOrigin:R,integrity:P,fetchPriority:jl}):k==="script"&&h.d.X(U,{crossOrigin:R,integrity:P,fetchPriority:jl,nonce:typeof E.nonce=="string"?E.nonce:void 0})}},ql.preinitModule=function(U,E){if(typeof U=="string")if(typeof E=="object"&&E!==null){if(E.as==null||E.as==="script"){var k=Dl(E.as,E.crossOrigin);h.d.M(U,{crossOrigin:k,integrity:typeof E.integrity=="string"?E.integrity:void 0,nonce:typeof E.nonce=="string"?E.nonce:void 0})}}else E==null&&h.d.M(U)},ql.preload=function(U,E){if(typeof U=="string"&&typeof E=="object"&&E!==null&&typeof E.as=="string"){var k=E.as,R=Dl(k,E.crossOrigin);h.d.L(U,k,{crossOrigin:R,integrity:typeof E.integrity=="string"?E.integrity:void 0,nonce:typeof E.nonce=="string"?E.nonce:void 0,type:typeof E.type=="string"?E.type:void 0,fetchPriority:typeof E.fetchPriority=="string"?E.fetchPriority:void 0,referrerPolicy:typeof E.referrerPolicy=="string"?E.referrerPolicy:void 0,imageSrcSet:typeof E.imageSrcSet=="string"?E.imageSrcSet:void 0,imageSizes:typeof E.imageSizes=="string"?E.imageSizes:void 0,media:typeof E.media=="string"?E.media:void 0})}},ql.preloadModule=function(U,E){if(typeof U=="string")if(E){var k=Dl(E.as,E.crossOrigin);h.d.m(U,{as:typeof E.as=="string"&&E.as!=="script"?E.as:void 0,crossOrigin:k,integrity:typeof E.integrity=="string"?E.integrity:void 0})}else h.d.m(U)},ql.requestFormReset=function(U){h.d.r(U)},ql.unstable_batchedUpdates=function(U,E){return U(E)},ql.useFormState=function(U,E,k){return rl.H.useFormState(U,E,k)},ql.useFormStatus=function(){return rl.H.useHostTransitionStatus()},ql.version="19.2.4",ql}var pc;function jo(){if(pc)return Wn.exports;pc=1;function p(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(p)}catch(cl){console.error(cl)}}return p(),Wn.exports=qo(),Wn.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Ac;function Yo(){if(Ac)return Uu;Ac=1;var p=Co(),cl=wn(),$=jo();function h(l){var t="https://react.dev/errors/"+l;if(1<arguments.length){t+="?args[]="+encodeURIComponent(arguments[1]);for(var a=2;a<arguments.length;a++)t+="&args[]="+encodeURIComponent(arguments[a])}return"Minified React error #"+l+"; visit "+t+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function vl(l){return!(!l||l.nodeType!==1&&l.nodeType!==9&&l.nodeType!==11)}function Sl(l){var t=l,a=l;if(l.alternate)for(;t.return;)t=t.return;else{l=t;do t=l,(t.flags&4098)!==0&&(a=t.return),l=t.return;while(l)}return t.tag===3?a:null}function rl(l){if(l.tag===13){var t=l.memoizedState;if(t===null&&(l=l.alternate,l!==null&&(t=l.memoizedState)),t!==null)return t.dehydrated}return null}function Dl(l){if(l.tag===31){var t=l.memoizedState;if(t===null&&(l=l.alternate,l!==null&&(t=l.memoizedState)),t!==null)return t.dehydrated}return null}function U(l){if(Sl(l)!==l)throw Error(h(188))}function E(l){var t=l.alternate;if(!t){if(t=Sl(l),t===null)throw Error(h(188));return t!==l?null:l}for(var a=l,u=t;;){var e=a.return;if(e===null)break;var n=e.alternate;if(n===null){if(u=e.return,u!==null){a=u;continue}break}if(e.child===n.child){for(n=e.child;n;){if(n===a)return U(e),l;if(n===u)return U(e),t;n=n.sibling}throw Error(h(188))}if(a.return!==u.return)a=e,u=n;else{for(var f=!1,i=e.child;i;){if(i===a){f=!0,a=e,u=n;break}if(i===u){f=!0,u=e,a=n;break}i=i.sibling}if(!f){for(i=n.child;i;){if(i===a){f=!0,a=n,u=e;break}if(i===u){f=!0,u=n,a=e;break}i=i.sibling}if(!f)throw Error(h(189))}}if(a.alternate!==u)throw Error(h(190))}if(a.tag!==3)throw Error(h(188));return a.stateNode.current===a?l:t}function k(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l;for(l=l.child;l!==null;){if(t=k(l),t!==null)return t;l=l.sibling}return null}var R=Object.assign,P=Symbol.for("react.element"),jl=Symbol.for("react.transitional.element"),Yl=Symbol.for("react.portal"),Ml=Symbol.for("react.fragment"),Il=Symbol.for("react.strict_mode"),H=Symbol.for("react.profiler"),Pl=Symbol.for("react.consumer"),Gl=Symbol.for("react.context"),dt=Symbol.for("react.forward_ref"),_t=Symbol.for("react.suspense"),Zl=Symbol.for("react.suspense_list"),w=Symbol.for("react.memo"),Vl=Symbol.for("react.lazy"),Mt=Symbol.for("react.activity"),Va=Symbol.for("react.memo_cache_sentinel"),Ot=Symbol.iterator;function Ll(l){return l===null||typeof l!="object"?null:(l=Ot&&l[Ot]||l["@@iterator"],typeof l=="function"?l:null)}var pa=Symbol.for("react.client.reference");function Nt(l){if(l==null)return null;if(typeof l=="function")return l.$$typeof===pa?null:l.displayName||l.name||null;if(typeof l=="string")return l;switch(l){case Ml:return"Fragment";case H:return"Profiler";case Il:return"StrictMode";case _t:return"Suspense";case Zl:return"SuspenseList";case Mt:return"Activity"}if(typeof l=="object")switch(l.$$typeof){case Yl:return"Portal";case Gl:return l.displayName||"Context";case Pl:return(l._context.displayName||"Context")+".Consumer";case dt:var t=l.render;return l=l.displayName,l||(l=t.displayName||t.name||"",l=l!==""?"ForwardRef("+l+")":"ForwardRef"),l;case w:return t=l.displayName||null,t!==null?t:Nt(l.type)||"Memo";case Vl:t=l._payload,l=l._init;try{return Nt(l(t))}catch{}}return null}var Tt=Array.isArray,r=cl.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,A=$.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,C={pending:!1,data:null,method:null,action:null},el=[],sl=-1;function d(l){return{current:l}}function T(l){0>sl||(l.current=el[sl],el[sl]=null,sl--)}function _(l,t){sl++,el[sl]=l.current,l.current=t}var O=d(null),j=d(null),Q=d(null),tl=d(null);function Xl(l,t){switch(_(Q,t),_(j,l),_(O,null),t.nodeType){case 9:case 11:l=(l=t.documentElement)&&(l=l.namespaceURI)?Pd(l):0;break;default:if(l=t.tagName,t=t.namespaceURI)t=Pd(t),l=lo(t,l);else switch(l){case"svg":l=1;break;case"math":l=2;break;default:l=0}}T(O),_(O,l)}function bl(){T(O),T(j),T(Q)}function xu(l){l.memoizedState!==null&&_(tl,l);var t=O.current,a=lo(t,l.type);t!==a&&(_(j,l),_(O,a))}function pe(l){j.current===l&&(T(O),T(j)),tl.current===l&&(T(tl),be._currentValue=C)}var Fn,Uc;function Aa(l){if(Fn===void 0)try{throw Error()}catch(a){var t=a.stack.trim().match(/\n( *(at )?)/);Fn=t&&t[1]||"",Uc=-1<a.stack.indexOf(`
    at`)?" (<anonymous>)":-1<a.stack.indexOf("@")?"@unknown:0:0":""}return`
`+Fn+l+Uc}var In=!1;function Pn(l,t){if(!l||In)return"";In=!0;var a=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var u={DetermineComponentFrameRoot:function(){try{if(t){var z=function(){throw Error()};if(Object.defineProperty(z.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(z,[])}catch(g){var m=g}Reflect.construct(l,[],z)}else{try{z.call()}catch(g){m=g}l.call(z.prototype)}}else{try{throw Error()}catch(g){m=g}(z=l())&&typeof z.catch=="function"&&z.catch(function(){})}}catch(g){if(g&&m&&typeof g.stack=="string")return[g.stack,m.stack]}return[null,null]}};u.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var e=Object.getOwnPropertyDescriptor(u.DetermineComponentFrameRoot,"name");e&&e.configurable&&Object.defineProperty(u.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var n=u.DetermineComponentFrameRoot(),f=n[0],i=n[1];if(f&&i){var c=f.split(`
`),v=i.split(`
`);for(e=u=0;u<c.length&&!c[u].includes("DetermineComponentFrameRoot");)u++;for(;e<v.length&&!v[e].includes("DetermineComponentFrameRoot");)e++;if(u===c.length||e===v.length)for(u=c.length-1,e=v.length-1;1<=u&&0<=e&&c[u]!==v[e];)e--;for(;1<=u&&0<=e;u--,e--)if(c[u]!==v[e]){if(u!==1||e!==1)do if(u--,e--,0>e||c[u]!==v[e]){var S=`
`+c[u].replace(" at new "," at ");return l.displayName&&S.includes("<anonymous>")&&(S=S.replace("<anonymous>",l.displayName)),S}while(1<=u&&0<=e);break}}}finally{In=!1,Error.prepareStackTrace=a}return(a=l?l.displayName||l.name:"")?Aa(a):""}function Ko(l,t){switch(l.tag){case 26:case 27:case 5:return Aa(l.type);case 16:return Aa("Lazy");case 13:return l.child!==t&&t!==null?Aa("Suspense Fallback"):Aa("Suspense");case 19:return Aa("SuspenseList");case 0:case 15:return Pn(l.type,!1);case 11:return Pn(l.type.render,!1);case 1:return Pn(l.type,!0);case 31:return Aa("Activity");default:return""}}function xc(l){try{var t="",a=null;do t+=Ko(l,a),a=l,l=l.return;while(l);return t}catch(u){return`
Error generating stack: `+u.message+`
`+u.stack}}var lf=Object.prototype.hasOwnProperty,tf=p.unstable_scheduleCallback,af=p.unstable_cancelCallback,Jo=p.unstable_shouldYield,wo=p.unstable_requestPaint,lt=p.unstable_now,Wo=p.unstable_getCurrentPriorityLevel,Hc=p.unstable_ImmediatePriority,Rc=p.unstable_UserBlockingPriority,Ae=p.unstable_NormalPriority,$o=p.unstable_LowPriority,Nc=p.unstable_IdlePriority,ko=p.log,Fo=p.unstable_setDisableYieldValue,Hu=null,tt=null;function It(l){if(typeof ko=="function"&&Fo(l),tt&&typeof tt.setStrictMode=="function")try{tt.setStrictMode(Hu,l)}catch{}}var at=Math.clz32?Math.clz32:ly,Io=Math.log,Po=Math.LN2;function ly(l){return l>>>=0,l===0?32:31-(Io(l)/Po|0)|0}var _e=256,Me=262144,Oe=4194304;function _a(l){var t=l&42;if(t!==0)return t;switch(l&-l){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:return l&261888;case 262144:case 524288:case 1048576:case 2097152:return l&3932160;case 4194304:case 8388608:case 16777216:case 33554432:return l&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return l}}function De(l,t,a){var u=l.pendingLanes;if(u===0)return 0;var e=0,n=l.suspendedLanes,f=l.pingedLanes;l=l.warmLanes;var i=u&134217727;return i!==0?(u=i&~n,u!==0?e=_a(u):(f&=i,f!==0?e=_a(f):a||(a=i&~l,a!==0&&(e=_a(a))))):(i=u&~n,i!==0?e=_a(i):f!==0?e=_a(f):a||(a=u&~l,a!==0&&(e=_a(a)))),e===0?0:t!==0&&t!==e&&(t&n)===0&&(n=e&-e,a=t&-t,n>=a||n===32&&(a&4194048)!==0)?t:e}function Ru(l,t){return(l.pendingLanes&~(l.suspendedLanes&~l.pingedLanes)&t)===0}function ty(l,t){switch(l){case 1:case 2:case 4:case 8:case 64:return t+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return t+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function Cc(){var l=Oe;return Oe<<=1,(Oe&62914560)===0&&(Oe=4194304),l}function uf(l){for(var t=[],a=0;31>a;a++)t.push(l);return t}function Nu(l,t){l.pendingLanes|=t,t!==268435456&&(l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0)}function ay(l,t,a,u,e,n){var f=l.pendingLanes;l.pendingLanes=a,l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0,l.expiredLanes&=a,l.entangledLanes&=a,l.errorRecoveryDisabledLanes&=a,l.shellSuspendCounter=0;var i=l.entanglements,c=l.expirationTimes,v=l.hiddenUpdates;for(a=f&~a;0<a;){var S=31-at(a),z=1<<S;i[S]=0,c[S]=-1;var m=v[S];if(m!==null)for(v[S]=null,S=0;S<m.length;S++){var g=m[S];g!==null&&(g.lane&=-536870913)}a&=~z}u!==0&&Bc(l,u,0),n!==0&&e===0&&l.tag!==0&&(l.suspendedLanes|=n&~(f&~t))}function Bc(l,t,a){l.pendingLanes|=t,l.suspendedLanes&=~t;var u=31-at(t);l.entangledLanes|=t,l.entanglements[u]=l.entanglements[u]|1073741824|a&261930}function qc(l,t){var a=l.entangledLanes|=t;for(l=l.entanglements;a;){var u=31-at(a),e=1<<u;e&t|l[u]&t&&(l[u]|=t),a&=~e}}function jc(l,t){var a=t&-t;return a=(a&42)!==0?1:ef(a),(a&(l.suspendedLanes|t))!==0?0:a}function ef(l){switch(l){case 2:l=1;break;case 8:l=4;break;case 32:l=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:l=128;break;case 268435456:l=134217728;break;default:l=0}return l}function nf(l){return l&=-l,2<l?8<l?(l&134217727)!==0?32:268435456:8:2}function Yc(){var l=A.p;return l!==0?l:(l=window.event,l===void 0?32:Ao(l.type))}function Gc(l,t){var a=A.p;try{return A.p=l,t()}finally{A.p=a}}var Pt=Math.random().toString(36).slice(2),Hl="__reactFiber$"+Pt,Kl="__reactProps$"+Pt,La="__reactContainer$"+Pt,ff="__reactEvents$"+Pt,uy="__reactListeners$"+Pt,ey="__reactHandles$"+Pt,Xc="__reactResources$"+Pt,Cu="__reactMarker$"+Pt;function cf(l){delete l[Hl],delete l[Kl],delete l[ff],delete l[uy],delete l[ey]}function Ka(l){var t=l[Hl];if(t)return t;for(var a=l.parentNode;a;){if(t=a[La]||a[Hl]){if(a=t.alternate,t.child!==null||a!==null&&a.child!==null)for(l=io(l);l!==null;){if(a=l[Hl])return a;l=io(l)}return t}l=a,a=l.parentNode}return null}function Ja(l){if(l=l[Hl]||l[La]){var t=l.tag;if(t===5||t===6||t===13||t===31||t===26||t===27||t===3)return l}return null}function Bu(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l.stateNode;throw Error(h(33))}function wa(l){var t=l[Xc];return t||(t=l[Xc]={hoistableStyles:new Map,hoistableScripts:new Map}),t}function Ul(l){l[Cu]=!0}var Qc=new Set,Zc={};function Ma(l,t){Wa(l,t),Wa(l+"Capture",t)}function Wa(l,t){for(Zc[l]=t,l=0;l<t.length;l++)Qc.add(t[l])}var ny=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),Vc={},Lc={};function fy(l){return lf.call(Lc,l)?!0:lf.call(Vc,l)?!1:ny.test(l)?Lc[l]=!0:(Vc[l]=!0,!1)}function Ue(l,t,a){if(fy(t))if(a===null)l.removeAttribute(t);else{switch(typeof a){case"undefined":case"function":case"symbol":l.removeAttribute(t);return;case"boolean":var u=t.toLowerCase().slice(0,5);if(u!=="data-"&&u!=="aria-"){l.removeAttribute(t);return}}l.setAttribute(t,""+a)}}function xe(l,t,a){if(a===null)l.removeAttribute(t);else{switch(typeof a){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(t);return}l.setAttribute(t,""+a)}}function Ct(l,t,a,u){if(u===null)l.removeAttribute(a);else{switch(typeof u){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(a);return}l.setAttributeNS(t,a,""+u)}}function ot(l){switch(typeof l){case"bigint":case"boolean":case"number":case"string":case"undefined":return l;case"object":return l;default:return""}}function Kc(l){var t=l.type;return(l=l.nodeName)&&l.toLowerCase()==="input"&&(t==="checkbox"||t==="radio")}function iy(l,t,a){var u=Object.getOwnPropertyDescriptor(l.constructor.prototype,t);if(!l.hasOwnProperty(t)&&typeof u<"u"&&typeof u.get=="function"&&typeof u.set=="function"){var e=u.get,n=u.set;return Object.defineProperty(l,t,{configurable:!0,get:function(){return e.call(this)},set:function(f){a=""+f,n.call(this,f)}}),Object.defineProperty(l,t,{enumerable:u.enumerable}),{getValue:function(){return a},setValue:function(f){a=""+f},stopTracking:function(){l._valueTracker=null,delete l[t]}}}}function sf(l){if(!l._valueTracker){var t=Kc(l)?"checked":"value";l._valueTracker=iy(l,t,""+l[t])}}function Jc(l){if(!l)return!1;var t=l._valueTracker;if(!t)return!0;var a=t.getValue(),u="";return l&&(u=Kc(l)?l.checked?"true":"false":l.value),l=u,l!==a?(t.setValue(l),!0):!1}function He(l){if(l=l||(typeof document<"u"?document:void 0),typeof l>"u")return null;try{return l.activeElement||l.body}catch{return l.body}}var cy=/[\n"\\]/g;function yt(l){return l.replace(cy,function(t){return"\\"+t.charCodeAt(0).toString(16)+" "})}function df(l,t,a,u,e,n,f,i){l.name="",f!=null&&typeof f!="function"&&typeof f!="symbol"&&typeof f!="boolean"?l.type=f:l.removeAttribute("type"),t!=null?f==="number"?(t===0&&l.value===""||l.value!=t)&&(l.value=""+ot(t)):l.value!==""+ot(t)&&(l.value=""+ot(t)):f!=="submit"&&f!=="reset"||l.removeAttribute("value"),t!=null?of(l,f,ot(t)):a!=null?of(l,f,ot(a)):u!=null&&l.removeAttribute("value"),e==null&&n!=null&&(l.defaultChecked=!!n),e!=null&&(l.checked=e&&typeof e!="function"&&typeof e!="symbol"),i!=null&&typeof i!="function"&&typeof i!="symbol"&&typeof i!="boolean"?l.name=""+ot(i):l.removeAttribute("name")}function wc(l,t,a,u,e,n,f,i){if(n!=null&&typeof n!="function"&&typeof n!="symbol"&&typeof n!="boolean"&&(l.type=n),t!=null||a!=null){if(!(n!=="submit"&&n!=="reset"||t!=null)){sf(l);return}a=a!=null?""+ot(a):"",t=t!=null?""+ot(t):a,i||t===l.value||(l.value=t),l.defaultValue=t}u=u??e,u=typeof u!="function"&&typeof u!="symbol"&&!!u,l.checked=i?l.checked:!!u,l.defaultChecked=!!u,f!=null&&typeof f!="function"&&typeof f!="symbol"&&typeof f!="boolean"&&(l.name=f),sf(l)}function of(l,t,a){t==="number"&&He(l.ownerDocument)===l||l.defaultValue===""+a||(l.defaultValue=""+a)}function $a(l,t,a,u){if(l=l.options,t){t={};for(var e=0;e<a.length;e++)t["$"+a[e]]=!0;for(a=0;a<l.length;a++)e=t.hasOwnProperty("$"+l[a].value),l[a].selected!==e&&(l[a].selected=e),e&&u&&(l[a].defaultSelected=!0)}else{for(a=""+ot(a),t=null,e=0;e<l.length;e++){if(l[e].value===a){l[e].selected=!0,u&&(l[e].defaultSelected=!0);return}t!==null||l[e].disabled||(t=l[e])}t!==null&&(t.selected=!0)}}function Wc(l,t,a){if(t!=null&&(t=""+ot(t),t!==l.value&&(l.value=t),a==null)){l.defaultValue!==t&&(l.defaultValue=t);return}l.defaultValue=a!=null?""+ot(a):""}function $c(l,t,a,u){if(t==null){if(u!=null){if(a!=null)throw Error(h(92));if(Tt(u)){if(1<u.length)throw Error(h(93));u=u[0]}a=u}a==null&&(a=""),t=a}a=ot(t),l.defaultValue=a,u=l.textContent,u===a&&u!==""&&u!==null&&(l.value=u),sf(l)}function ka(l,t){if(t){var a=l.firstChild;if(a&&a===l.lastChild&&a.nodeType===3){a.nodeValue=t;return}}l.textContent=t}var sy=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function kc(l,t,a){var u=t.indexOf("--")===0;a==null||typeof a=="boolean"||a===""?u?l.setProperty(t,""):t==="float"?l.cssFloat="":l[t]="":u?l.setProperty(t,a):typeof a!="number"||a===0||sy.has(t)?t==="float"?l.cssFloat=a:l[t]=(""+a).trim():l[t]=a+"px"}function Fc(l,t,a){if(t!=null&&typeof t!="object")throw Error(h(62));if(l=l.style,a!=null){for(var u in a)!a.hasOwnProperty(u)||t!=null&&t.hasOwnProperty(u)||(u.indexOf("--")===0?l.setProperty(u,""):u==="float"?l.cssFloat="":l[u]="");for(var e in t)u=t[e],t.hasOwnProperty(e)&&a[e]!==u&&kc(l,e,u)}else for(var n in t)t.hasOwnProperty(n)&&kc(l,n,t[n])}function yf(l){if(l.indexOf("-")===-1)return!1;switch(l){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var dy=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),oy=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function Re(l){return oy.test(""+l)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":l}function Bt(){}var vf=null;function mf(l){return l=l.target||l.srcElement||window,l.correspondingUseElement&&(l=l.correspondingUseElement),l.nodeType===3?l.parentNode:l}var Fa=null,Ia=null;function Ic(l){var t=Ja(l);if(t&&(l=t.stateNode)){var a=l[Kl]||null;l:switch(l=t.stateNode,t.type){case"input":if(df(l,a.value,a.defaultValue,a.defaultValue,a.checked,a.defaultChecked,a.type,a.name),t=a.name,a.type==="radio"&&t!=null){for(a=l;a.parentNode;)a=a.parentNode;for(a=a.querySelectorAll('input[name="'+yt(""+t)+'"][type="radio"]'),t=0;t<a.length;t++){var u=a[t];if(u!==l&&u.form===l.form){var e=u[Kl]||null;if(!e)throw Error(h(90));df(u,e.value,e.defaultValue,e.defaultValue,e.checked,e.defaultChecked,e.type,e.name)}}for(t=0;t<a.length;t++)u=a[t],u.form===l.form&&Jc(u)}break l;case"textarea":Wc(l,a.value,a.defaultValue);break l;case"select":t=a.value,t!=null&&$a(l,!!a.multiple,t,!1)}}}var hf=!1;function Pc(l,t,a){if(hf)return l(t,a);hf=!0;try{var u=l(t);return u}finally{if(hf=!1,(Fa!==null||Ia!==null)&&(zn(),Fa&&(t=Fa,l=Ia,Ia=Fa=null,Ic(t),l)))for(t=0;t<l.length;t++)Ic(l[t])}}function qu(l,t){var a=l.stateNode;if(a===null)return null;var u=a[Kl]||null;if(u===null)return null;a=u[t];l:switch(t){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(u=!u.disabled)||(l=l.type,u=!(l==="button"||l==="input"||l==="select"||l==="textarea")),l=!u;break l;default:l=!1}if(l)return null;if(a&&typeof a!="function")throw Error(h(231,t,typeof a));return a}var qt=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),gf=!1;if(qt)try{var ju={};Object.defineProperty(ju,"passive",{get:function(){gf=!0}}),window.addEventListener("test",ju,ju),window.removeEventListener("test",ju,ju)}catch{gf=!1}var la=null,Sf=null,Ne=null;function ls(){if(Ne)return Ne;var l,t=Sf,a=t.length,u,e="value"in la?la.value:la.textContent,n=e.length;for(l=0;l<a&&t[l]===e[l];l++);var f=a-l;for(u=1;u<=f&&t[a-u]===e[n-u];u++);return Ne=e.slice(l,1<u?1-u:void 0)}function Ce(l){var t=l.keyCode;return"charCode"in l?(l=l.charCode,l===0&&t===13&&(l=13)):l=t,l===10&&(l=13),32<=l||l===13?l:0}function Be(){return!0}function ts(){return!1}function Jl(l){function t(a,u,e,n,f){this._reactName=a,this._targetInst=e,this.type=u,this.nativeEvent=n,this.target=f,this.currentTarget=null;for(var i in l)l.hasOwnProperty(i)&&(a=l[i],this[i]=a?a(n):n[i]);return this.isDefaultPrevented=(n.defaultPrevented!=null?n.defaultPrevented:n.returnValue===!1)?Be:ts,this.isPropagationStopped=ts,this}return R(t.prototype,{preventDefault:function(){this.defaultPrevented=!0;var a=this.nativeEvent;a&&(a.preventDefault?a.preventDefault():typeof a.returnValue!="unknown"&&(a.returnValue=!1),this.isDefaultPrevented=Be)},stopPropagation:function(){var a=this.nativeEvent;a&&(a.stopPropagation?a.stopPropagation():typeof a.cancelBubble!="unknown"&&(a.cancelBubble=!0),this.isPropagationStopped=Be)},persist:function(){},isPersistent:Be}),t}var Oa={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(l){return l.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},qe=Jl(Oa),Yu=R({},Oa,{view:0,detail:0}),yy=Jl(Yu),rf,bf,Gu,je=R({},Yu,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:Tf,button:0,buttons:0,relatedTarget:function(l){return l.relatedTarget===void 0?l.fromElement===l.srcElement?l.toElement:l.fromElement:l.relatedTarget},movementX:function(l){return"movementX"in l?l.movementX:(l!==Gu&&(Gu&&l.type==="mousemove"?(rf=l.screenX-Gu.screenX,bf=l.screenY-Gu.screenY):bf=rf=0,Gu=l),rf)},movementY:function(l){return"movementY"in l?l.movementY:bf}}),as=Jl(je),vy=R({},je,{dataTransfer:0}),my=Jl(vy),hy=R({},Yu,{relatedTarget:0}),zf=Jl(hy),gy=R({},Oa,{animationName:0,elapsedTime:0,pseudoElement:0}),Sy=Jl(gy),ry=R({},Oa,{clipboardData:function(l){return"clipboardData"in l?l.clipboardData:window.clipboardData}}),by=Jl(ry),zy=R({},Oa,{data:0}),us=Jl(zy),Ty={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},Ey={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},py={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function Ay(l){var t=this.nativeEvent;return t.getModifierState?t.getModifierState(l):(l=py[l])?!!t[l]:!1}function Tf(){return Ay}var _y=R({},Yu,{key:function(l){if(l.key){var t=Ty[l.key]||l.key;if(t!=="Unidentified")return t}return l.type==="keypress"?(l=Ce(l),l===13?"Enter":String.fromCharCode(l)):l.type==="keydown"||l.type==="keyup"?Ey[l.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:Tf,charCode:function(l){return l.type==="keypress"?Ce(l):0},keyCode:function(l){return l.type==="keydown"||l.type==="keyup"?l.keyCode:0},which:function(l){return l.type==="keypress"?Ce(l):l.type==="keydown"||l.type==="keyup"?l.keyCode:0}}),My=Jl(_y),Oy=R({},je,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),es=Jl(Oy),Dy=R({},Yu,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:Tf}),Uy=Jl(Dy),xy=R({},Oa,{propertyName:0,elapsedTime:0,pseudoElement:0}),Hy=Jl(xy),Ry=R({},je,{deltaX:function(l){return"deltaX"in l?l.deltaX:"wheelDeltaX"in l?-l.wheelDeltaX:0},deltaY:function(l){return"deltaY"in l?l.deltaY:"wheelDeltaY"in l?-l.wheelDeltaY:"wheelDelta"in l?-l.wheelDelta:0},deltaZ:0,deltaMode:0}),Ny=Jl(Ry),Cy=R({},Oa,{newState:0,oldState:0}),By=Jl(Cy),qy=[9,13,27,32],Ef=qt&&"CompositionEvent"in window,Xu=null;qt&&"documentMode"in document&&(Xu=document.documentMode);var jy=qt&&"TextEvent"in window&&!Xu,ns=qt&&(!Ef||Xu&&8<Xu&&11>=Xu),fs=" ",is=!1;function cs(l,t){switch(l){case"keyup":return qy.indexOf(t.keyCode)!==-1;case"keydown":return t.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function ss(l){return l=l.detail,typeof l=="object"&&"data"in l?l.data:null}var Pa=!1;function Yy(l,t){switch(l){case"compositionend":return ss(t);case"keypress":return t.which!==32?null:(is=!0,fs);case"textInput":return l=t.data,l===fs&&is?null:l;default:return null}}function Gy(l,t){if(Pa)return l==="compositionend"||!Ef&&cs(l,t)?(l=ls(),Ne=Sf=la=null,Pa=!1,l):null;switch(l){case"paste":return null;case"keypress":if(!(t.ctrlKey||t.altKey||t.metaKey)||t.ctrlKey&&t.altKey){if(t.char&&1<t.char.length)return t.char;if(t.which)return String.fromCharCode(t.which)}return null;case"compositionend":return ns&&t.locale!=="ko"?null:t.data;default:return null}}var Xy={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function ds(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t==="input"?!!Xy[l.type]:t==="textarea"}function os(l,t,a,u){Fa?Ia?Ia.push(u):Ia=[u]:Fa=u,t=On(t,"onChange"),0<t.length&&(a=new qe("onChange","change",null,a,u),l.push({event:a,listeners:t}))}var Qu=null,Zu=null;function Qy(l){wd(l,0)}function Ye(l){var t=Bu(l);if(Jc(t))return l}function ys(l,t){if(l==="change")return t}var vs=!1;if(qt){var pf;if(qt){var Af="oninput"in document;if(!Af){var ms=document.createElement("div");ms.setAttribute("oninput","return;"),Af=typeof ms.oninput=="function"}pf=Af}else pf=!1;vs=pf&&(!document.documentMode||9<document.documentMode)}function hs(){Qu&&(Qu.detachEvent("onpropertychange",gs),Zu=Qu=null)}function gs(l){if(l.propertyName==="value"&&Ye(Zu)){var t=[];os(t,Zu,l,mf(l)),Pc(Qy,t)}}function Zy(l,t,a){l==="focusin"?(hs(),Qu=t,Zu=a,Qu.attachEvent("onpropertychange",gs)):l==="focusout"&&hs()}function Vy(l){if(l==="selectionchange"||l==="keyup"||l==="keydown")return Ye(Zu)}function Ly(l,t){if(l==="click")return Ye(t)}function Ky(l,t){if(l==="input"||l==="change")return Ye(t)}function Jy(l,t){return l===t&&(l!==0||1/l===1/t)||l!==l&&t!==t}var ut=typeof Object.is=="function"?Object.is:Jy;function Vu(l,t){if(ut(l,t))return!0;if(typeof l!="object"||l===null||typeof t!="object"||t===null)return!1;var a=Object.keys(l),u=Object.keys(t);if(a.length!==u.length)return!1;for(u=0;u<a.length;u++){var e=a[u];if(!lf.call(t,e)||!ut(l[e],t[e]))return!1}return!0}function Ss(l){for(;l&&l.firstChild;)l=l.firstChild;return l}function rs(l,t){var a=Ss(l);l=0;for(var u;a;){if(a.nodeType===3){if(u=l+a.textContent.length,l<=t&&u>=t)return{node:a,offset:t-l};l=u}l:{for(;a;){if(a.nextSibling){a=a.nextSibling;break l}a=a.parentNode}a=void 0}a=Ss(a)}}function bs(l,t){return l&&t?l===t?!0:l&&l.nodeType===3?!1:t&&t.nodeType===3?bs(l,t.parentNode):"contains"in l?l.contains(t):l.compareDocumentPosition?!!(l.compareDocumentPosition(t)&16):!1:!1}function zs(l){l=l!=null&&l.ownerDocument!=null&&l.ownerDocument.defaultView!=null?l.ownerDocument.defaultView:window;for(var t=He(l.document);t instanceof l.HTMLIFrameElement;){try{var a=typeof t.contentWindow.location.href=="string"}catch{a=!1}if(a)l=t.contentWindow;else break;t=He(l.document)}return t}function _f(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t&&(t==="input"&&(l.type==="text"||l.type==="search"||l.type==="tel"||l.type==="url"||l.type==="password")||t==="textarea"||l.contentEditable==="true")}var wy=qt&&"documentMode"in document&&11>=document.documentMode,lu=null,Mf=null,Lu=null,Of=!1;function Ts(l,t,a){var u=a.window===a?a.document:a.nodeType===9?a:a.ownerDocument;Of||lu==null||lu!==He(u)||(u=lu,"selectionStart"in u&&_f(u)?u={start:u.selectionStart,end:u.selectionEnd}:(u=(u.ownerDocument&&u.ownerDocument.defaultView||window).getSelection(),u={anchorNode:u.anchorNode,anchorOffset:u.anchorOffset,focusNode:u.focusNode,focusOffset:u.focusOffset}),Lu&&Vu(Lu,u)||(Lu=u,u=On(Mf,"onSelect"),0<u.length&&(t=new qe("onSelect","select",null,t,a),l.push({event:t,listeners:u}),t.target=lu)))}function Da(l,t){var a={};return a[l.toLowerCase()]=t.toLowerCase(),a["Webkit"+l]="webkit"+t,a["Moz"+l]="moz"+t,a}var tu={animationend:Da("Animation","AnimationEnd"),animationiteration:Da("Animation","AnimationIteration"),animationstart:Da("Animation","AnimationStart"),transitionrun:Da("Transition","TransitionRun"),transitionstart:Da("Transition","TransitionStart"),transitioncancel:Da("Transition","TransitionCancel"),transitionend:Da("Transition","TransitionEnd")},Df={},Es={};qt&&(Es=document.createElement("div").style,"AnimationEvent"in window||(delete tu.animationend.animation,delete tu.animationiteration.animation,delete tu.animationstart.animation),"TransitionEvent"in window||delete tu.transitionend.transition);function Ua(l){if(Df[l])return Df[l];if(!tu[l])return l;var t=tu[l],a;for(a in t)if(t.hasOwnProperty(a)&&a in Es)return Df[l]=t[a];return l}var ps=Ua("animationend"),As=Ua("animationiteration"),_s=Ua("animationstart"),Wy=Ua("transitionrun"),$y=Ua("transitionstart"),ky=Ua("transitioncancel"),Ms=Ua("transitionend"),Os=new Map,Uf="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");Uf.push("scrollEnd");function Et(l,t){Os.set(l,t),Ma(t,[l])}var Ge=typeof reportError=="function"?reportError:function(l){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var t=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof l=="object"&&l!==null&&typeof l.message=="string"?String(l.message):String(l),error:l});if(!window.dispatchEvent(t))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",l);return}console.error(l)},vt=[],au=0,xf=0;function Xe(){for(var l=au,t=xf=au=0;t<l;){var a=vt[t];vt[t++]=null;var u=vt[t];vt[t++]=null;var e=vt[t];vt[t++]=null;var n=vt[t];if(vt[t++]=null,u!==null&&e!==null){var f=u.pending;f===null?e.next=e:(e.next=f.next,f.next=e),u.pending=e}n!==0&&Ds(a,e,n)}}function Qe(l,t,a,u){vt[au++]=l,vt[au++]=t,vt[au++]=a,vt[au++]=u,xf|=u,l.lanes|=u,l=l.alternate,l!==null&&(l.lanes|=u)}function Hf(l,t,a,u){return Qe(l,t,a,u),Ze(l)}function xa(l,t){return Qe(l,null,null,t),Ze(l)}function Ds(l,t,a){l.lanes|=a;var u=l.alternate;u!==null&&(u.lanes|=a);for(var e=!1,n=l.return;n!==null;)n.childLanes|=a,u=n.alternate,u!==null&&(u.childLanes|=a),n.tag===22&&(l=n.stateNode,l===null||l._visibility&1||(e=!0)),l=n,n=n.return;return l.tag===3?(n=l.stateNode,e&&t!==null&&(e=31-at(a),l=n.hiddenUpdates,u=l[e],u===null?l[e]=[t]:u.push(t),t.lane=a|536870912),n):null}function Ze(l){if(50<ye)throw ye=0,Xi=null,Error(h(185));for(var t=l.return;t!==null;)l=t,t=l.return;return l.tag===3?l.stateNode:null}var uu={};function Fy(l,t,a,u){this.tag=l,this.key=a,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=t,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=u,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function et(l,t,a,u){return new Fy(l,t,a,u)}function Rf(l){return l=l.prototype,!(!l||!l.isReactComponent)}function jt(l,t){var a=l.alternate;return a===null?(a=et(l.tag,t,l.key,l.mode),a.elementType=l.elementType,a.type=l.type,a.stateNode=l.stateNode,a.alternate=l,l.alternate=a):(a.pendingProps=t,a.type=l.type,a.flags=0,a.subtreeFlags=0,a.deletions=null),a.flags=l.flags&65011712,a.childLanes=l.childLanes,a.lanes=l.lanes,a.child=l.child,a.memoizedProps=l.memoizedProps,a.memoizedState=l.memoizedState,a.updateQueue=l.updateQueue,t=l.dependencies,a.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext},a.sibling=l.sibling,a.index=l.index,a.ref=l.ref,a.refCleanup=l.refCleanup,a}function Us(l,t){l.flags&=65011714;var a=l.alternate;return a===null?(l.childLanes=0,l.lanes=t,l.child=null,l.subtreeFlags=0,l.memoizedProps=null,l.memoizedState=null,l.updateQueue=null,l.dependencies=null,l.stateNode=null):(l.childLanes=a.childLanes,l.lanes=a.lanes,l.child=a.child,l.subtreeFlags=0,l.deletions=null,l.memoizedProps=a.memoizedProps,l.memoizedState=a.memoizedState,l.updateQueue=a.updateQueue,l.type=a.type,t=a.dependencies,l.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext}),l}function Ve(l,t,a,u,e,n){var f=0;if(u=l,typeof l=="function")Rf(l)&&(f=1);else if(typeof l=="string")f=am(l,a,O.current)?26:l==="html"||l==="head"||l==="body"?27:5;else l:switch(l){case Mt:return l=et(31,a,t,e),l.elementType=Mt,l.lanes=n,l;case Ml:return Ha(a.children,e,n,t);case Il:f=8,e|=24;break;case H:return l=et(12,a,t,e|2),l.elementType=H,l.lanes=n,l;case _t:return l=et(13,a,t,e),l.elementType=_t,l.lanes=n,l;case Zl:return l=et(19,a,t,e),l.elementType=Zl,l.lanes=n,l;default:if(typeof l=="object"&&l!==null)switch(l.$$typeof){case Gl:f=10;break l;case Pl:f=9;break l;case dt:f=11;break l;case w:f=14;break l;case Vl:f=16,u=null;break l}f=29,a=Error(h(130,l===null?"null":typeof l,"")),u=null}return t=et(f,a,t,e),t.elementType=l,t.type=u,t.lanes=n,t}function Ha(l,t,a,u){return l=et(7,l,u,t),l.lanes=a,l}function Nf(l,t,a){return l=et(6,l,null,t),l.lanes=a,l}function xs(l){var t=et(18,null,null,0);return t.stateNode=l,t}function Cf(l,t,a){return t=et(4,l.children!==null?l.children:[],l.key,t),t.lanes=a,t.stateNode={containerInfo:l.containerInfo,pendingChildren:null,implementation:l.implementation},t}var Hs=new WeakMap;function mt(l,t){if(typeof l=="object"&&l!==null){var a=Hs.get(l);return a!==void 0?a:(t={value:l,source:t,stack:xc(t)},Hs.set(l,t),t)}return{value:l,source:t,stack:xc(t)}}var eu=[],nu=0,Le=null,Ku=0,ht=[],gt=0,ta=null,Dt=1,Ut="";function Yt(l,t){eu[nu++]=Ku,eu[nu++]=Le,Le=l,Ku=t}function Rs(l,t,a){ht[gt++]=Dt,ht[gt++]=Ut,ht[gt++]=ta,ta=l;var u=Dt;l=Ut;var e=32-at(u)-1;u&=~(1<<e),a+=1;var n=32-at(t)+e;if(30<n){var f=e-e%5;n=(u&(1<<f)-1).toString(32),u>>=f,e-=f,Dt=1<<32-at(t)+e|a<<e|u,Ut=n+l}else Dt=1<<n|a<<e|u,Ut=l}function Bf(l){l.return!==null&&(Yt(l,1),Rs(l,1,0))}function qf(l){for(;l===Le;)Le=eu[--nu],eu[nu]=null,Ku=eu[--nu],eu[nu]=null;for(;l===ta;)ta=ht[--gt],ht[gt]=null,Ut=ht[--gt],ht[gt]=null,Dt=ht[--gt],ht[gt]=null}function Ns(l,t){ht[gt++]=Dt,ht[gt++]=Ut,ht[gt++]=ta,Dt=t.id,Ut=t.overflow,ta=l}var Rl=null,ol=null,W=!1,aa=null,St=!1,jf=Error(h(519));function ua(l){var t=Error(h(418,1<arguments.length&&arguments[1]!==void 0&&arguments[1]?"text":"HTML",""));throw Ju(mt(t,l)),jf}function Cs(l){var t=l.stateNode,a=l.type,u=l.memoizedProps;switch(t[Hl]=l,t[Kl]=u,a){case"dialog":V("cancel",t),V("close",t);break;case"iframe":case"object":case"embed":V("load",t);break;case"video":case"audio":for(a=0;a<me.length;a++)V(me[a],t);break;case"source":V("error",t);break;case"img":case"image":case"link":V("error",t),V("load",t);break;case"details":V("toggle",t);break;case"input":V("invalid",t),wc(t,u.value,u.defaultValue,u.checked,u.defaultChecked,u.type,u.name,!0);break;case"select":V("invalid",t);break;case"textarea":V("invalid",t),$c(t,u.value,u.defaultValue,u.children)}a=u.children,typeof a!="string"&&typeof a!="number"&&typeof a!="bigint"||t.textContent===""+a||u.suppressHydrationWarning===!0||Fd(t.textContent,a)?(u.popover!=null&&(V("beforetoggle",t),V("toggle",t)),u.onScroll!=null&&V("scroll",t),u.onScrollEnd!=null&&V("scrollend",t),u.onClick!=null&&(t.onclick=Bt),t=!0):t=!1,t||ua(l,!0)}function Bs(l){for(Rl=l.return;Rl;)switch(Rl.tag){case 5:case 31:case 13:St=!1;return;case 27:case 3:St=!0;return;default:Rl=Rl.return}}function fu(l){if(l!==Rl)return!1;if(!W)return Bs(l),W=!0,!1;var t=l.tag,a;if((a=t!==3&&t!==27)&&((a=t===5)&&(a=l.type,a=!(a!=="form"&&a!=="button")||tc(l.type,l.memoizedProps)),a=!a),a&&ol&&ua(l),Bs(l),t===13){if(l=l.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(h(317));ol=fo(l)}else if(t===31){if(l=l.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(h(317));ol=fo(l)}else t===27?(t=ol,Sa(l.type)?(l=fc,fc=null,ol=l):ol=t):ol=Rl?bt(l.stateNode.nextSibling):null;return!0}function Ra(){ol=Rl=null,W=!1}function Yf(){var l=aa;return l!==null&&(kl===null?kl=l:kl.push.apply(kl,l),aa=null),l}function Ju(l){aa===null?aa=[l]:aa.push(l)}var Gf=d(null),Na=null,Gt=null;function ea(l,t,a){_(Gf,t._currentValue),t._currentValue=a}function Xt(l){l._currentValue=Gf.current,T(Gf)}function Xf(l,t,a){for(;l!==null;){var u=l.alternate;if((l.childLanes&t)!==t?(l.childLanes|=t,u!==null&&(u.childLanes|=t)):u!==null&&(u.childLanes&t)!==t&&(u.childLanes|=t),l===a)break;l=l.return}}function Qf(l,t,a,u){var e=l.child;for(e!==null&&(e.return=l);e!==null;){var n=e.dependencies;if(n!==null){var f=e.child;n=n.firstContext;l:for(;n!==null;){var i=n;n=e;for(var c=0;c<t.length;c++)if(i.context===t[c]){n.lanes|=a,i=n.alternate,i!==null&&(i.lanes|=a),Xf(n.return,a,l),u||(f=null);break l}n=i.next}}else if(e.tag===18){if(f=e.return,f===null)throw Error(h(341));f.lanes|=a,n=f.alternate,n!==null&&(n.lanes|=a),Xf(f,a,l),f=null}else f=e.child;if(f!==null)f.return=e;else for(f=e;f!==null;){if(f===l){f=null;break}if(e=f.sibling,e!==null){e.return=f.return,f=e;break}f=f.return}e=f}}function iu(l,t,a,u){l=null;for(var e=t,n=!1;e!==null;){if(!n){if((e.flags&524288)!==0)n=!0;else if((e.flags&262144)!==0)break}if(e.tag===10){var f=e.alternate;if(f===null)throw Error(h(387));if(f=f.memoizedProps,f!==null){var i=e.type;ut(e.pendingProps.value,f.value)||(l!==null?l.push(i):l=[i])}}else if(e===tl.current){if(f=e.alternate,f===null)throw Error(h(387));f.memoizedState.memoizedState!==e.memoizedState.memoizedState&&(l!==null?l.push(be):l=[be])}e=e.return}l!==null&&Qf(t,l,a,u),t.flags|=262144}function Ke(l){for(l=l.firstContext;l!==null;){if(!ut(l.context._currentValue,l.memoizedValue))return!0;l=l.next}return!1}function Ca(l){Na=l,Gt=null,l=l.dependencies,l!==null&&(l.firstContext=null)}function Nl(l){return qs(Na,l)}function Je(l,t){return Na===null&&Ca(l),qs(l,t)}function qs(l,t){var a=t._currentValue;if(t={context:t,memoizedValue:a,next:null},Gt===null){if(l===null)throw Error(h(308));Gt=t,l.dependencies={lanes:0,firstContext:t},l.flags|=524288}else Gt=Gt.next=t;return a}var Iy=typeof AbortController<"u"?AbortController:function(){var l=[],t=this.signal={aborted:!1,addEventListener:function(a,u){l.push(u)}};this.abort=function(){t.aborted=!0,l.forEach(function(a){return a()})}},Py=p.unstable_scheduleCallback,lv=p.unstable_NormalPriority,El={$$typeof:Gl,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function Zf(){return{controller:new Iy,data:new Map,refCount:0}}function wu(l){l.refCount--,l.refCount===0&&Py(lv,function(){l.controller.abort()})}var Wu=null,Vf=0,cu=0,su=null;function tv(l,t){if(Wu===null){var a=Wu=[];Vf=0,cu=Ji(),su={status:"pending",value:void 0,then:function(u){a.push(u)}}}return Vf++,t.then(js,js),t}function js(){if(--Vf===0&&Wu!==null){su!==null&&(su.status="fulfilled");var l=Wu;Wu=null,cu=0,su=null;for(var t=0;t<l.length;t++)(0,l[t])()}}function av(l,t){var a=[],u={status:"pending",value:null,reason:null,then:function(e){a.push(e)}};return l.then(function(){u.status="fulfilled",u.value=t;for(var e=0;e<a.length;e++)(0,a[e])(t)},function(e){for(u.status="rejected",u.reason=e,e=0;e<a.length;e++)(0,a[e])(void 0)}),u}var Ys=r.S;r.S=function(l,t){Td=lt(),typeof t=="object"&&t!==null&&typeof t.then=="function"&&tv(l,t),Ys!==null&&Ys(l,t)};var Ba=d(null);function Lf(){var l=Ba.current;return l!==null?l:dl.pooledCache}function we(l,t){t===null?_(Ba,Ba.current):_(Ba,t.pool)}function Gs(){var l=Lf();return l===null?null:{parent:El._currentValue,pool:l}}var du=Error(h(460)),Kf=Error(h(474)),We=Error(h(542)),$e={then:function(){}};function Xs(l){return l=l.status,l==="fulfilled"||l==="rejected"}function Qs(l,t,a){switch(a=l[a],a===void 0?l.push(t):a!==t&&(t.then(Bt,Bt),t=a),t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,Vs(l),l;default:if(typeof t.status=="string")t.then(Bt,Bt);else{if(l=dl,l!==null&&100<l.shellSuspendCounter)throw Error(h(482));l=t,l.status="pending",l.then(function(u){if(t.status==="pending"){var e=t;e.status="fulfilled",e.value=u}},function(u){if(t.status==="pending"){var e=t;e.status="rejected",e.reason=u}})}switch(t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,Vs(l),l}throw ja=t,du}}function qa(l){try{var t=l._init;return t(l._payload)}catch(a){throw a!==null&&typeof a=="object"&&typeof a.then=="function"?(ja=a,du):a}}var ja=null;function Zs(){if(ja===null)throw Error(h(459));var l=ja;return ja=null,l}function Vs(l){if(l===du||l===We)throw Error(h(483))}var ou=null,$u=0;function ke(l){var t=$u;return $u+=1,ou===null&&(ou=[]),Qs(ou,l,t)}function ku(l,t){t=t.props.ref,l.ref=t!==void 0?t:null}function Fe(l,t){throw t.$$typeof===P?Error(h(525)):(l=Object.prototype.toString.call(t),Error(h(31,l==="[object Object]"?"object with keys {"+Object.keys(t).join(", ")+"}":l)))}function Ls(l){function t(o,s){if(l){var y=o.deletions;y===null?(o.deletions=[s],o.flags|=16):y.push(s)}}function a(o,s){if(!l)return null;for(;s!==null;)t(o,s),s=s.sibling;return null}function u(o){for(var s=new Map;o!==null;)o.key!==null?s.set(o.key,o):s.set(o.index,o),o=o.sibling;return s}function e(o,s){return o=jt(o,s),o.index=0,o.sibling=null,o}function n(o,s,y){return o.index=y,l?(y=o.alternate,y!==null?(y=y.index,y<s?(o.flags|=67108866,s):y):(o.flags|=67108866,s)):(o.flags|=1048576,s)}function f(o){return l&&o.alternate===null&&(o.flags|=67108866),o}function i(o,s,y,b){return s===null||s.tag!==6?(s=Nf(y,o.mode,b),s.return=o,s):(s=e(s,y),s.return=o,s)}function c(o,s,y,b){var x=y.type;return x===Ml?S(o,s,y.props.children,b,y.key):s!==null&&(s.elementType===x||typeof x=="object"&&x!==null&&x.$$typeof===Vl&&qa(x)===s.type)?(s=e(s,y.props),ku(s,y),s.return=o,s):(s=Ve(y.type,y.key,y.props,null,o.mode,b),ku(s,y),s.return=o,s)}function v(o,s,y,b){return s===null||s.tag!==4||s.stateNode.containerInfo!==y.containerInfo||s.stateNode.implementation!==y.implementation?(s=Cf(y,o.mode,b),s.return=o,s):(s=e(s,y.children||[]),s.return=o,s)}function S(o,s,y,b,x){return s===null||s.tag!==7?(s=Ha(y,o.mode,b,x),s.return=o,s):(s=e(s,y),s.return=o,s)}function z(o,s,y){if(typeof s=="string"&&s!==""||typeof s=="number"||typeof s=="bigint")return s=Nf(""+s,o.mode,y),s.return=o,s;if(typeof s=="object"&&s!==null){switch(s.$$typeof){case jl:return y=Ve(s.type,s.key,s.props,null,o.mode,y),ku(y,s),y.return=o,y;case Yl:return s=Cf(s,o.mode,y),s.return=o,s;case Vl:return s=qa(s),z(o,s,y)}if(Tt(s)||Ll(s))return s=Ha(s,o.mode,y,null),s.return=o,s;if(typeof s.then=="function")return z(o,ke(s),y);if(s.$$typeof===Gl)return z(o,Je(o,s),y);Fe(o,s)}return null}function m(o,s,y,b){var x=s!==null?s.key:null;if(typeof y=="string"&&y!==""||typeof y=="number"||typeof y=="bigint")return x!==null?null:i(o,s,""+y,b);if(typeof y=="object"&&y!==null){switch(y.$$typeof){case jl:return y.key===x?c(o,s,y,b):null;case Yl:return y.key===x?v(o,s,y,b):null;case Vl:return y=qa(y),m(o,s,y,b)}if(Tt(y)||Ll(y))return x!==null?null:S(o,s,y,b,null);if(typeof y.then=="function")return m(o,s,ke(y),b);if(y.$$typeof===Gl)return m(o,s,Je(o,y),b);Fe(o,y)}return null}function g(o,s,y,b,x){if(typeof b=="string"&&b!==""||typeof b=="number"||typeof b=="bigint")return o=o.get(y)||null,i(s,o,""+b,x);if(typeof b=="object"&&b!==null){switch(b.$$typeof){case jl:return o=o.get(b.key===null?y:b.key)||null,c(s,o,b,x);case Yl:return o=o.get(b.key===null?y:b.key)||null,v(s,o,b,x);case Vl:return b=qa(b),g(o,s,y,b,x)}if(Tt(b)||Ll(b))return o=o.get(y)||null,S(s,o,b,x,null);if(typeof b.then=="function")return g(o,s,y,ke(b),x);if(b.$$typeof===Gl)return g(o,s,y,Je(s,b),x);Fe(s,b)}return null}function M(o,s,y,b){for(var x=null,F=null,D=s,G=s=0,J=null;D!==null&&G<y.length;G++){D.index>G?(J=D,D=null):J=D.sibling;var I=m(o,D,y[G],b);if(I===null){D===null&&(D=J);break}l&&D&&I.alternate===null&&t(o,D),s=n(I,s,G),F===null?x=I:F.sibling=I,F=I,D=J}if(G===y.length)return a(o,D),W&&Yt(o,G),x;if(D===null){for(;G<y.length;G++)D=z(o,y[G],b),D!==null&&(s=n(D,s,G),F===null?x=D:F.sibling=D,F=D);return W&&Yt(o,G),x}for(D=u(D);G<y.length;G++)J=g(D,o,G,y[G],b),J!==null&&(l&&J.alternate!==null&&D.delete(J.key===null?G:J.key),s=n(J,s,G),F===null?x=J:F.sibling=J,F=J);return l&&D.forEach(function(Ea){return t(o,Ea)}),W&&Yt(o,G),x}function N(o,s,y,b){if(y==null)throw Error(h(151));for(var x=null,F=null,D=s,G=s=0,J=null,I=y.next();D!==null&&!I.done;G++,I=y.next()){D.index>G?(J=D,D=null):J=D.sibling;var Ea=m(o,D,I.value,b);if(Ea===null){D===null&&(D=J);break}l&&D&&Ea.alternate===null&&t(o,D),s=n(Ea,s,G),F===null?x=Ea:F.sibling=Ea,F=Ea,D=J}if(I.done)return a(o,D),W&&Yt(o,G),x;if(D===null){for(;!I.done;G++,I=y.next())I=z(o,I.value,b),I!==null&&(s=n(I,s,G),F===null?x=I:F.sibling=I,F=I);return W&&Yt(o,G),x}for(D=u(D);!I.done;G++,I=y.next())I=g(D,o,G,I.value,b),I!==null&&(l&&I.alternate!==null&&D.delete(I.key===null?G:I.key),s=n(I,s,G),F===null?x=I:F.sibling=I,F=I);return l&&D.forEach(function(vm){return t(o,vm)}),W&&Yt(o,G),x}function il(o,s,y,b){if(typeof y=="object"&&y!==null&&y.type===Ml&&y.key===null&&(y=y.props.children),typeof y=="object"&&y!==null){switch(y.$$typeof){case jl:l:{for(var x=y.key;s!==null;){if(s.key===x){if(x=y.type,x===Ml){if(s.tag===7){a(o,s.sibling),b=e(s,y.props.children),b.return=o,o=b;break l}}else if(s.elementType===x||typeof x=="object"&&x!==null&&x.$$typeof===Vl&&qa(x)===s.type){a(o,s.sibling),b=e(s,y.props),ku(b,y),b.return=o,o=b;break l}a(o,s);break}else t(o,s);s=s.sibling}y.type===Ml?(b=Ha(y.props.children,o.mode,b,y.key),b.return=o,o=b):(b=Ve(y.type,y.key,y.props,null,o.mode,b),ku(b,y),b.return=o,o=b)}return f(o);case Yl:l:{for(x=y.key;s!==null;){if(s.key===x)if(s.tag===4&&s.stateNode.containerInfo===y.containerInfo&&s.stateNode.implementation===y.implementation){a(o,s.sibling),b=e(s,y.children||[]),b.return=o,o=b;break l}else{a(o,s);break}else t(o,s);s=s.sibling}b=Cf(y,o.mode,b),b.return=o,o=b}return f(o);case Vl:return y=qa(y),il(o,s,y,b)}if(Tt(y))return M(o,s,y,b);if(Ll(y)){if(x=Ll(y),typeof x!="function")throw Error(h(150));return y=x.call(y),N(o,s,y,b)}if(typeof y.then=="function")return il(o,s,ke(y),b);if(y.$$typeof===Gl)return il(o,s,Je(o,y),b);Fe(o,y)}return typeof y=="string"&&y!==""||typeof y=="number"||typeof y=="bigint"?(y=""+y,s!==null&&s.tag===6?(a(o,s.sibling),b=e(s,y),b.return=o,o=b):(a(o,s),b=Nf(y,o.mode,b),b.return=o,o=b),f(o)):a(o,s)}return function(o,s,y,b){try{$u=0;var x=il(o,s,y,b);return ou=null,x}catch(D){if(D===du||D===We)throw D;var F=et(29,D,null,o.mode);return F.lanes=b,F.return=o,F}finally{}}}var Ya=Ls(!0),Ks=Ls(!1),na=!1;function Jf(l){l.updateQueue={baseState:l.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function wf(l,t){l=l.updateQueue,t.updateQueue===l&&(t.updateQueue={baseState:l.baseState,firstBaseUpdate:l.firstBaseUpdate,lastBaseUpdate:l.lastBaseUpdate,shared:l.shared,callbacks:null})}function fa(l){return{lane:l,tag:0,payload:null,callback:null,next:null}}function ia(l,t,a){var u=l.updateQueue;if(u===null)return null;if(u=u.shared,(ll&2)!==0){var e=u.pending;return e===null?t.next=t:(t.next=e.next,e.next=t),u.pending=t,t=Ze(l),Ds(l,null,a),t}return Qe(l,u,t,a),Ze(l)}function Fu(l,t,a){if(t=t.updateQueue,t!==null&&(t=t.shared,(a&4194048)!==0)){var u=t.lanes;u&=l.pendingLanes,a|=u,t.lanes=a,qc(l,a)}}function Wf(l,t){var a=l.updateQueue,u=l.alternate;if(u!==null&&(u=u.updateQueue,a===u)){var e=null,n=null;if(a=a.firstBaseUpdate,a!==null){do{var f={lane:a.lane,tag:a.tag,payload:a.payload,callback:null,next:null};n===null?e=n=f:n=n.next=f,a=a.next}while(a!==null);n===null?e=n=t:n=n.next=t}else e=n=t;a={baseState:u.baseState,firstBaseUpdate:e,lastBaseUpdate:n,shared:u.shared,callbacks:u.callbacks},l.updateQueue=a;return}l=a.lastBaseUpdate,l===null?a.firstBaseUpdate=t:l.next=t,a.lastBaseUpdate=t}var $f=!1;function Iu(){if($f){var l=su;if(l!==null)throw l}}function Pu(l,t,a,u){$f=!1;var e=l.updateQueue;na=!1;var n=e.firstBaseUpdate,f=e.lastBaseUpdate,i=e.shared.pending;if(i!==null){e.shared.pending=null;var c=i,v=c.next;c.next=null,f===null?n=v:f.next=v,f=c;var S=l.alternate;S!==null&&(S=S.updateQueue,i=S.lastBaseUpdate,i!==f&&(i===null?S.firstBaseUpdate=v:i.next=v,S.lastBaseUpdate=c))}if(n!==null){var z=e.baseState;f=0,S=v=c=null,i=n;do{var m=i.lane&-536870913,g=m!==i.lane;if(g?(K&m)===m:(u&m)===m){m!==0&&m===cu&&($f=!0),S!==null&&(S=S.next={lane:0,tag:i.tag,payload:i.payload,callback:null,next:null});l:{var M=l,N=i;m=t;var il=a;switch(N.tag){case 1:if(M=N.payload,typeof M=="function"){z=M.call(il,z,m);break l}z=M;break l;case 3:M.flags=M.flags&-65537|128;case 0:if(M=N.payload,m=typeof M=="function"?M.call(il,z,m):M,m==null)break l;z=R({},z,m);break l;case 2:na=!0}}m=i.callback,m!==null&&(l.flags|=64,g&&(l.flags|=8192),g=e.callbacks,g===null?e.callbacks=[m]:g.push(m))}else g={lane:m,tag:i.tag,payload:i.payload,callback:i.callback,next:null},S===null?(v=S=g,c=z):S=S.next=g,f|=m;if(i=i.next,i===null){if(i=e.shared.pending,i===null)break;g=i,i=g.next,g.next=null,e.lastBaseUpdate=g,e.shared.pending=null}}while(!0);S===null&&(c=z),e.baseState=c,e.firstBaseUpdate=v,e.lastBaseUpdate=S,n===null&&(e.shared.lanes=0),ya|=f,l.lanes=f,l.memoizedState=z}}function Js(l,t){if(typeof l!="function")throw Error(h(191,l));l.call(t)}function ws(l,t){var a=l.callbacks;if(a!==null)for(l.callbacks=null,l=0;l<a.length;l++)Js(a[l],t)}var yu=d(null),Ie=d(0);function Ws(l,t){l=$t,_(Ie,l),_(yu,t),$t=l|t.baseLanes}function kf(){_(Ie,$t),_(yu,yu.current)}function Ff(){$t=Ie.current,T(yu),T(Ie)}var nt=d(null),rt=null;function ca(l){var t=l.alternate;_(zl,zl.current&1),_(nt,l),rt===null&&(t===null||yu.current!==null||t.memoizedState!==null)&&(rt=l)}function If(l){_(zl,zl.current),_(nt,l),rt===null&&(rt=l)}function $s(l){l.tag===22?(_(zl,zl.current),_(nt,l),rt===null&&(rt=l)):sa()}function sa(){_(zl,zl.current),_(nt,nt.current)}function ft(l){T(nt),rt===l&&(rt=null),T(zl)}var zl=d(0);function Pe(l){for(var t=l;t!==null;){if(t.tag===13){var a=t.memoizedState;if(a!==null&&(a=a.dehydrated,a===null||ec(a)||nc(a)))return t}else if(t.tag===19&&(t.memoizedProps.revealOrder==="forwards"||t.memoizedProps.revealOrder==="backwards"||t.memoizedProps.revealOrder==="unstable_legacy-backwards"||t.memoizedProps.revealOrder==="together")){if((t.flags&128)!==0)return t}else if(t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return null;t=t.return}t.sibling.return=t.return,t=t.sibling}return null}var Qt=0,Y=null,nl=null,pl=null,ln=!1,vu=!1,Ga=!1,tn=0,le=0,mu=null,uv=0;function hl(){throw Error(h(321))}function Pf(l,t){if(t===null)return!1;for(var a=0;a<t.length&&a<l.length;a++)if(!ut(l[a],t[a]))return!1;return!0}function li(l,t,a,u,e,n){return Qt=n,Y=t,t.memoizedState=null,t.updateQueue=null,t.lanes=0,r.H=l===null||l.memoizedState===null?R0:hi,Ga=!1,n=a(u,e),Ga=!1,vu&&(n=Fs(t,a,u,e)),ks(l),n}function ks(l){r.H=ue;var t=nl!==null&&nl.next!==null;if(Qt=0,pl=nl=Y=null,ln=!1,le=0,mu=null,t)throw Error(h(300));l===null||Al||(l=l.dependencies,l!==null&&Ke(l)&&(Al=!0))}function Fs(l,t,a,u){Y=l;var e=0;do{if(vu&&(mu=null),le=0,vu=!1,25<=e)throw Error(h(301));if(e+=1,pl=nl=null,l.updateQueue!=null){var n=l.updateQueue;n.lastEffect=null,n.events=null,n.stores=null,n.memoCache!=null&&(n.memoCache.index=0)}r.H=N0,n=t(a,u)}while(vu);return n}function ev(){var l=r.H,t=l.useState()[0];return t=typeof t.then=="function"?te(t):t,l=l.useState()[0],(nl!==null?nl.memoizedState:null)!==l&&(Y.flags|=1024),t}function ti(){var l=tn!==0;return tn=0,l}function ai(l,t,a){t.updateQueue=l.updateQueue,t.flags&=-2053,l.lanes&=~a}function ui(l){if(ln){for(l=l.memoizedState;l!==null;){var t=l.queue;t!==null&&(t.pending=null),l=l.next}ln=!1}Qt=0,pl=nl=Y=null,vu=!1,le=tn=0,mu=null}function Ql(){var l={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return pl===null?Y.memoizedState=pl=l:pl=pl.next=l,pl}function Tl(){if(nl===null){var l=Y.alternate;l=l!==null?l.memoizedState:null}else l=nl.next;var t=pl===null?Y.memoizedState:pl.next;if(t!==null)pl=t,nl=l;else{if(l===null)throw Y.alternate===null?Error(h(467)):Error(h(310));nl=l,l={memoizedState:nl.memoizedState,baseState:nl.baseState,baseQueue:nl.baseQueue,queue:nl.queue,next:null},pl===null?Y.memoizedState=pl=l:pl=pl.next=l}return pl}function an(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function te(l){var t=le;return le+=1,mu===null&&(mu=[]),l=Qs(mu,l,t),t=Y,(pl===null?t.memoizedState:pl.next)===null&&(t=t.alternate,r.H=t===null||t.memoizedState===null?R0:hi),l}function un(l){if(l!==null&&typeof l=="object"){if(typeof l.then=="function")return te(l);if(l.$$typeof===Gl)return Nl(l)}throw Error(h(438,String(l)))}function ei(l){var t=null,a=Y.updateQueue;if(a!==null&&(t=a.memoCache),t==null){var u=Y.alternate;u!==null&&(u=u.updateQueue,u!==null&&(u=u.memoCache,u!=null&&(t={data:u.data.map(function(e){return e.slice()}),index:0})))}if(t==null&&(t={data:[],index:0}),a===null&&(a=an(),Y.updateQueue=a),a.memoCache=t,a=t.data[t.index],a===void 0)for(a=t.data[t.index]=Array(l),u=0;u<l;u++)a[u]=Va;return t.index++,a}function Zt(l,t){return typeof t=="function"?t(l):t}function en(l){var t=Tl();return ni(t,nl,l)}function ni(l,t,a){var u=l.queue;if(u===null)throw Error(h(311));u.lastRenderedReducer=a;var e=l.baseQueue,n=u.pending;if(n!==null){if(e!==null){var f=e.next;e.next=n.next,n.next=f}t.baseQueue=e=n,u.pending=null}if(n=l.baseState,e===null)l.memoizedState=n;else{t=e.next;var i=f=null,c=null,v=t,S=!1;do{var z=v.lane&-536870913;if(z!==v.lane?(K&z)===z:(Qt&z)===z){var m=v.revertLane;if(m===0)c!==null&&(c=c.next={lane:0,revertLane:0,gesture:null,action:v.action,hasEagerState:v.hasEagerState,eagerState:v.eagerState,next:null}),z===cu&&(S=!0);else if((Qt&m)===m){v=v.next,m===cu&&(S=!0);continue}else z={lane:0,revertLane:v.revertLane,gesture:null,action:v.action,hasEagerState:v.hasEagerState,eagerState:v.eagerState,next:null},c===null?(i=c=z,f=n):c=c.next=z,Y.lanes|=m,ya|=m;z=v.action,Ga&&a(n,z),n=v.hasEagerState?v.eagerState:a(n,z)}else m={lane:z,revertLane:v.revertLane,gesture:v.gesture,action:v.action,hasEagerState:v.hasEagerState,eagerState:v.eagerState,next:null},c===null?(i=c=m,f=n):c=c.next=m,Y.lanes|=z,ya|=z;v=v.next}while(v!==null&&v!==t);if(c===null?f=n:c.next=i,!ut(n,l.memoizedState)&&(Al=!0,S&&(a=su,a!==null)))throw a;l.memoizedState=n,l.baseState=f,l.baseQueue=c,u.lastRenderedState=n}return e===null&&(u.lanes=0),[l.memoizedState,u.dispatch]}function fi(l){var t=Tl(),a=t.queue;if(a===null)throw Error(h(311));a.lastRenderedReducer=l;var u=a.dispatch,e=a.pending,n=t.memoizedState;if(e!==null){a.pending=null;var f=e=e.next;do n=l(n,f.action),f=f.next;while(f!==e);ut(n,t.memoizedState)||(Al=!0),t.memoizedState=n,t.baseQueue===null&&(t.baseState=n),a.lastRenderedState=n}return[n,u]}function Is(l,t,a){var u=Y,e=Tl(),n=W;if(n){if(a===void 0)throw Error(h(407));a=a()}else a=t();var f=!ut((nl||e).memoizedState,a);if(f&&(e.memoizedState=a,Al=!0),e=e.queue,si(t0.bind(null,u,e,l),[l]),e.getSnapshot!==t||f||pl!==null&&pl.memoizedState.tag&1){if(u.flags|=2048,hu(9,{destroy:void 0},l0.bind(null,u,e,a,t),null),dl===null)throw Error(h(349));n||(Qt&127)!==0||Ps(u,t,a)}return a}function Ps(l,t,a){l.flags|=16384,l={getSnapshot:t,value:a},t=Y.updateQueue,t===null?(t=an(),Y.updateQueue=t,t.stores=[l]):(a=t.stores,a===null?t.stores=[l]:a.push(l))}function l0(l,t,a,u){t.value=a,t.getSnapshot=u,a0(t)&&u0(l)}function t0(l,t,a){return a(function(){a0(t)&&u0(l)})}function a0(l){var t=l.getSnapshot;l=l.value;try{var a=t();return!ut(l,a)}catch{return!0}}function u0(l){var t=xa(l,2);t!==null&&Fl(t,l,2)}function ii(l){var t=Ql();if(typeof l=="function"){var a=l;if(l=a(),Ga){It(!0);try{a()}finally{It(!1)}}}return t.memoizedState=t.baseState=l,t.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Zt,lastRenderedState:l},t}function e0(l,t,a,u){return l.baseState=a,ni(l,nl,typeof u=="function"?u:Zt)}function nv(l,t,a,u,e){if(cn(l))throw Error(h(485));if(l=t.action,l!==null){var n={payload:e,action:l,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(f){n.listeners.push(f)}};r.T!==null?a(!0):n.isTransition=!1,u(n),a=t.pending,a===null?(n.next=t.pending=n,n0(t,n)):(n.next=a.next,t.pending=a.next=n)}}function n0(l,t){var a=t.action,u=t.payload,e=l.state;if(t.isTransition){var n=r.T,f={};r.T=f;try{var i=a(e,u),c=r.S;c!==null&&c(f,i),f0(l,t,i)}catch(v){ci(l,t,v)}finally{n!==null&&f.types!==null&&(n.types=f.types),r.T=n}}else try{n=a(e,u),f0(l,t,n)}catch(v){ci(l,t,v)}}function f0(l,t,a){a!==null&&typeof a=="object"&&typeof a.then=="function"?a.then(function(u){i0(l,t,u)},function(u){return ci(l,t,u)}):i0(l,t,a)}function i0(l,t,a){t.status="fulfilled",t.value=a,c0(t),l.state=a,t=l.pending,t!==null&&(a=t.next,a===t?l.pending=null:(a=a.next,t.next=a,n0(l,a)))}function ci(l,t,a){var u=l.pending;if(l.pending=null,u!==null){u=u.next;do t.status="rejected",t.reason=a,c0(t),t=t.next;while(t!==u)}l.action=null}function c0(l){l=l.listeners;for(var t=0;t<l.length;t++)(0,l[t])()}function s0(l,t){return t}function d0(l,t){if(W){var a=dl.formState;if(a!==null){l:{var u=Y;if(W){if(ol){t:{for(var e=ol,n=St;e.nodeType!==8;){if(!n){e=null;break t}if(e=bt(e.nextSibling),e===null){e=null;break t}}n=e.data,e=n==="F!"||n==="F"?e:null}if(e){ol=bt(e.nextSibling),u=e.data==="F!";break l}}ua(u)}u=!1}u&&(t=a[0])}}return a=Ql(),a.memoizedState=a.baseState=t,u={pending:null,lanes:0,dispatch:null,lastRenderedReducer:s0,lastRenderedState:t},a.queue=u,a=U0.bind(null,Y,u),u.dispatch=a,u=ii(!1),n=mi.bind(null,Y,!1,u.queue),u=Ql(),e={state:t,dispatch:null,action:l,pending:null},u.queue=e,a=nv.bind(null,Y,e,n,a),e.dispatch=a,u.memoizedState=l,[t,a,!1]}function o0(l){var t=Tl();return y0(t,nl,l)}function y0(l,t,a){if(t=ni(l,t,s0)[0],l=en(Zt)[0],typeof t=="object"&&t!==null&&typeof t.then=="function")try{var u=te(t)}catch(f){throw f===du?We:f}else u=t;t=Tl();var e=t.queue,n=e.dispatch;return a!==t.memoizedState&&(Y.flags|=2048,hu(9,{destroy:void 0},fv.bind(null,e,a),null)),[u,n,l]}function fv(l,t){l.action=t}function v0(l){var t=Tl(),a=nl;if(a!==null)return y0(t,a,l);Tl(),t=t.memoizedState,a=Tl();var u=a.queue.dispatch;return a.memoizedState=l,[t,u,!1]}function hu(l,t,a,u){return l={tag:l,create:a,deps:u,inst:t,next:null},t=Y.updateQueue,t===null&&(t=an(),Y.updateQueue=t),a=t.lastEffect,a===null?t.lastEffect=l.next=l:(u=a.next,a.next=l,l.next=u,t.lastEffect=l),l}function m0(){return Tl().memoizedState}function nn(l,t,a,u){var e=Ql();Y.flags|=l,e.memoizedState=hu(1|t,{destroy:void 0},a,u===void 0?null:u)}function fn(l,t,a,u){var e=Tl();u=u===void 0?null:u;var n=e.memoizedState.inst;nl!==null&&u!==null&&Pf(u,nl.memoizedState.deps)?e.memoizedState=hu(t,n,a,u):(Y.flags|=l,e.memoizedState=hu(1|t,n,a,u))}function h0(l,t){nn(8390656,8,l,t)}function si(l,t){fn(2048,8,l,t)}function iv(l){Y.flags|=4;var t=Y.updateQueue;if(t===null)t=an(),Y.updateQueue=t,t.events=[l];else{var a=t.events;a===null?t.events=[l]:a.push(l)}}function g0(l){var t=Tl().memoizedState;return iv({ref:t,nextImpl:l}),function(){if((ll&2)!==0)throw Error(h(440));return t.impl.apply(void 0,arguments)}}function S0(l,t){return fn(4,2,l,t)}function r0(l,t){return fn(4,4,l,t)}function b0(l,t){if(typeof t=="function"){l=l();var a=t(l);return function(){typeof a=="function"?a():t(null)}}if(t!=null)return l=l(),t.current=l,function(){t.current=null}}function z0(l,t,a){a=a!=null?a.concat([l]):null,fn(4,4,b0.bind(null,t,l),a)}function di(){}function T0(l,t){var a=Tl();t=t===void 0?null:t;var u=a.memoizedState;return t!==null&&Pf(t,u[1])?u[0]:(a.memoizedState=[l,t],l)}function E0(l,t){var a=Tl();t=t===void 0?null:t;var u=a.memoizedState;if(t!==null&&Pf(t,u[1]))return u[0];if(u=l(),Ga){It(!0);try{l()}finally{It(!1)}}return a.memoizedState=[u,t],u}function oi(l,t,a){return a===void 0||(Qt&1073741824)!==0&&(K&261930)===0?l.memoizedState=t:(l.memoizedState=a,l=pd(),Y.lanes|=l,ya|=l,a)}function p0(l,t,a,u){return ut(a,t)?a:yu.current!==null?(l=oi(l,a,u),ut(l,t)||(Al=!0),l):(Qt&42)===0||(Qt&1073741824)!==0&&(K&261930)===0?(Al=!0,l.memoizedState=a):(l=pd(),Y.lanes|=l,ya|=l,t)}function A0(l,t,a,u,e){var n=A.p;A.p=n!==0&&8>n?n:8;var f=r.T,i={};r.T=i,mi(l,!1,t,a);try{var c=e(),v=r.S;if(v!==null&&v(i,c),c!==null&&typeof c=="object"&&typeof c.then=="function"){var S=av(c,u);ae(l,t,S,st(l))}else ae(l,t,u,st(l))}catch(z){ae(l,t,{then:function(){},status:"rejected",reason:z},st())}finally{A.p=n,f!==null&&i.types!==null&&(f.types=i.types),r.T=f}}function cv(){}function yi(l,t,a,u){if(l.tag!==5)throw Error(h(476));var e=_0(l).queue;A0(l,e,t,C,a===null?cv:function(){return M0(l),a(u)})}function _0(l){var t=l.memoizedState;if(t!==null)return t;t={memoizedState:C,baseState:C,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Zt,lastRenderedState:C},next:null};var a={};return t.next={memoizedState:a,baseState:a,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Zt,lastRenderedState:a},next:null},l.memoizedState=t,l=l.alternate,l!==null&&(l.memoizedState=t),t}function M0(l){var t=_0(l);t.next===null&&(t=l.alternate.memoizedState),ae(l,t.next.queue,{},st())}function vi(){return Nl(be)}function O0(){return Tl().memoizedState}function D0(){return Tl().memoizedState}function sv(l){for(var t=l.return;t!==null;){switch(t.tag){case 24:case 3:var a=st();l=fa(a);var u=ia(t,l,a);u!==null&&(Fl(u,t,a),Fu(u,t,a)),t={cache:Zf()},l.payload=t;return}t=t.return}}function dv(l,t,a){var u=st();a={lane:u,revertLane:0,gesture:null,action:a,hasEagerState:!1,eagerState:null,next:null},cn(l)?x0(t,a):(a=Hf(l,t,a,u),a!==null&&(Fl(a,l,u),H0(a,t,u)))}function U0(l,t,a){var u=st();ae(l,t,a,u)}function ae(l,t,a,u){var e={lane:u,revertLane:0,gesture:null,action:a,hasEagerState:!1,eagerState:null,next:null};if(cn(l))x0(t,e);else{var n=l.alternate;if(l.lanes===0&&(n===null||n.lanes===0)&&(n=t.lastRenderedReducer,n!==null))try{var f=t.lastRenderedState,i=n(f,a);if(e.hasEagerState=!0,e.eagerState=i,ut(i,f))return Qe(l,t,e,0),dl===null&&Xe(),!1}catch{}finally{}if(a=Hf(l,t,e,u),a!==null)return Fl(a,l,u),H0(a,t,u),!0}return!1}function mi(l,t,a,u){if(u={lane:2,revertLane:Ji(),gesture:null,action:u,hasEagerState:!1,eagerState:null,next:null},cn(l)){if(t)throw Error(h(479))}else t=Hf(l,a,u,2),t!==null&&Fl(t,l,2)}function cn(l){var t=l.alternate;return l===Y||t!==null&&t===Y}function x0(l,t){vu=ln=!0;var a=l.pending;a===null?t.next=t:(t.next=a.next,a.next=t),l.pending=t}function H0(l,t,a){if((a&4194048)!==0){var u=t.lanes;u&=l.pendingLanes,a|=u,t.lanes=a,qc(l,a)}}var ue={readContext:Nl,use:un,useCallback:hl,useContext:hl,useEffect:hl,useImperativeHandle:hl,useLayoutEffect:hl,useInsertionEffect:hl,useMemo:hl,useReducer:hl,useRef:hl,useState:hl,useDebugValue:hl,useDeferredValue:hl,useTransition:hl,useSyncExternalStore:hl,useId:hl,useHostTransitionStatus:hl,useFormState:hl,useActionState:hl,useOptimistic:hl,useMemoCache:hl,useCacheRefresh:hl};ue.useEffectEvent=hl;var R0={readContext:Nl,use:un,useCallback:function(l,t){return Ql().memoizedState=[l,t===void 0?null:t],l},useContext:Nl,useEffect:h0,useImperativeHandle:function(l,t,a){a=a!=null?a.concat([l]):null,nn(4194308,4,b0.bind(null,t,l),a)},useLayoutEffect:function(l,t){return nn(4194308,4,l,t)},useInsertionEffect:function(l,t){nn(4,2,l,t)},useMemo:function(l,t){var a=Ql();t=t===void 0?null:t;var u=l();if(Ga){It(!0);try{l()}finally{It(!1)}}return a.memoizedState=[u,t],u},useReducer:function(l,t,a){var u=Ql();if(a!==void 0){var e=a(t);if(Ga){It(!0);try{a(t)}finally{It(!1)}}}else e=t;return u.memoizedState=u.baseState=e,l={pending:null,lanes:0,dispatch:null,lastRenderedReducer:l,lastRenderedState:e},u.queue=l,l=l.dispatch=dv.bind(null,Y,l),[u.memoizedState,l]},useRef:function(l){var t=Ql();return l={current:l},t.memoizedState=l},useState:function(l){l=ii(l);var t=l.queue,a=U0.bind(null,Y,t);return t.dispatch=a,[l.memoizedState,a]},useDebugValue:di,useDeferredValue:function(l,t){var a=Ql();return oi(a,l,t)},useTransition:function(){var l=ii(!1);return l=A0.bind(null,Y,l.queue,!0,!1),Ql().memoizedState=l,[!1,l]},useSyncExternalStore:function(l,t,a){var u=Y,e=Ql();if(W){if(a===void 0)throw Error(h(407));a=a()}else{if(a=t(),dl===null)throw Error(h(349));(K&127)!==0||Ps(u,t,a)}e.memoizedState=a;var n={value:a,getSnapshot:t};return e.queue=n,h0(t0.bind(null,u,n,l),[l]),u.flags|=2048,hu(9,{destroy:void 0},l0.bind(null,u,n,a,t),null),a},useId:function(){var l=Ql(),t=dl.identifierPrefix;if(W){var a=Ut,u=Dt;a=(u&~(1<<32-at(u)-1)).toString(32)+a,t="_"+t+"R_"+a,a=tn++,0<a&&(t+="H"+a.toString(32)),t+="_"}else a=uv++,t="_"+t+"r_"+a.toString(32)+"_";return l.memoizedState=t},useHostTransitionStatus:vi,useFormState:d0,useActionState:d0,useOptimistic:function(l){var t=Ql();t.memoizedState=t.baseState=l;var a={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return t.queue=a,t=mi.bind(null,Y,!0,a),a.dispatch=t,[l,t]},useMemoCache:ei,useCacheRefresh:function(){return Ql().memoizedState=sv.bind(null,Y)},useEffectEvent:function(l){var t=Ql(),a={impl:l};return t.memoizedState=a,function(){if((ll&2)!==0)throw Error(h(440));return a.impl.apply(void 0,arguments)}}},hi={readContext:Nl,use:un,useCallback:T0,useContext:Nl,useEffect:si,useImperativeHandle:z0,useInsertionEffect:S0,useLayoutEffect:r0,useMemo:E0,useReducer:en,useRef:m0,useState:function(){return en(Zt)},useDebugValue:di,useDeferredValue:function(l,t){var a=Tl();return p0(a,nl.memoizedState,l,t)},useTransition:function(){var l=en(Zt)[0],t=Tl().memoizedState;return[typeof l=="boolean"?l:te(l),t]},useSyncExternalStore:Is,useId:O0,useHostTransitionStatus:vi,useFormState:o0,useActionState:o0,useOptimistic:function(l,t){var a=Tl();return e0(a,nl,l,t)},useMemoCache:ei,useCacheRefresh:D0};hi.useEffectEvent=g0;var N0={readContext:Nl,use:un,useCallback:T0,useContext:Nl,useEffect:si,useImperativeHandle:z0,useInsertionEffect:S0,useLayoutEffect:r0,useMemo:E0,useReducer:fi,useRef:m0,useState:function(){return fi(Zt)},useDebugValue:di,useDeferredValue:function(l,t){var a=Tl();return nl===null?oi(a,l,t):p0(a,nl.memoizedState,l,t)},useTransition:function(){var l=fi(Zt)[0],t=Tl().memoizedState;return[typeof l=="boolean"?l:te(l),t]},useSyncExternalStore:Is,useId:O0,useHostTransitionStatus:vi,useFormState:v0,useActionState:v0,useOptimistic:function(l,t){var a=Tl();return nl!==null?e0(a,nl,l,t):(a.baseState=l,[l,a.queue.dispatch])},useMemoCache:ei,useCacheRefresh:D0};N0.useEffectEvent=g0;function gi(l,t,a,u){t=l.memoizedState,a=a(u,t),a=a==null?t:R({},t,a),l.memoizedState=a,l.lanes===0&&(l.updateQueue.baseState=a)}var Si={enqueueSetState:function(l,t,a){l=l._reactInternals;var u=st(),e=fa(u);e.payload=t,a!=null&&(e.callback=a),t=ia(l,e,u),t!==null&&(Fl(t,l,u),Fu(t,l,u))},enqueueReplaceState:function(l,t,a){l=l._reactInternals;var u=st(),e=fa(u);e.tag=1,e.payload=t,a!=null&&(e.callback=a),t=ia(l,e,u),t!==null&&(Fl(t,l,u),Fu(t,l,u))},enqueueForceUpdate:function(l,t){l=l._reactInternals;var a=st(),u=fa(a);u.tag=2,t!=null&&(u.callback=t),t=ia(l,u,a),t!==null&&(Fl(t,l,a),Fu(t,l,a))}};function C0(l,t,a,u,e,n,f){return l=l.stateNode,typeof l.shouldComponentUpdate=="function"?l.shouldComponentUpdate(u,n,f):t.prototype&&t.prototype.isPureReactComponent?!Vu(a,u)||!Vu(e,n):!0}function B0(l,t,a,u){l=t.state,typeof t.componentWillReceiveProps=="function"&&t.componentWillReceiveProps(a,u),typeof t.UNSAFE_componentWillReceiveProps=="function"&&t.UNSAFE_componentWillReceiveProps(a,u),t.state!==l&&Si.enqueueReplaceState(t,t.state,null)}function Xa(l,t){var a=t;if("ref"in t){a={};for(var u in t)u!=="ref"&&(a[u]=t[u])}if(l=l.defaultProps){a===t&&(a=R({},a));for(var e in l)a[e]===void 0&&(a[e]=l[e])}return a}function q0(l){Ge(l)}function j0(l){console.error(l)}function Y0(l){Ge(l)}function sn(l,t){try{var a=l.onUncaughtError;a(t.value,{componentStack:t.stack})}catch(u){setTimeout(function(){throw u})}}function G0(l,t,a){try{var u=l.onCaughtError;u(a.value,{componentStack:a.stack,errorBoundary:t.tag===1?t.stateNode:null})}catch(e){setTimeout(function(){throw e})}}function ri(l,t,a){return a=fa(a),a.tag=3,a.payload={element:null},a.callback=function(){sn(l,t)},a}function X0(l){return l=fa(l),l.tag=3,l}function Q0(l,t,a,u){var e=a.type.getDerivedStateFromError;if(typeof e=="function"){var n=u.value;l.payload=function(){return e(n)},l.callback=function(){G0(t,a,u)}}var f=a.stateNode;f!==null&&typeof f.componentDidCatch=="function"&&(l.callback=function(){G0(t,a,u),typeof e!="function"&&(va===null?va=new Set([this]):va.add(this));var i=u.stack;this.componentDidCatch(u.value,{componentStack:i!==null?i:""})})}function ov(l,t,a,u,e){if(a.flags|=32768,u!==null&&typeof u=="object"&&typeof u.then=="function"){if(t=a.alternate,t!==null&&iu(t,a,e,!0),a=nt.current,a!==null){switch(a.tag){case 31:case 13:return rt===null?Tn():a.alternate===null&&gl===0&&(gl=3),a.flags&=-257,a.flags|=65536,a.lanes=e,u===$e?a.flags|=16384:(t=a.updateQueue,t===null?a.updateQueue=new Set([u]):t.add(u),Vi(l,u,e)),!1;case 22:return a.flags|=65536,u===$e?a.flags|=16384:(t=a.updateQueue,t===null?(t={transitions:null,markerInstances:null,retryQueue:new Set([u])},a.updateQueue=t):(a=t.retryQueue,a===null?t.retryQueue=new Set([u]):a.add(u)),Vi(l,u,e)),!1}throw Error(h(435,a.tag))}return Vi(l,u,e),Tn(),!1}if(W)return t=nt.current,t!==null?((t.flags&65536)===0&&(t.flags|=256),t.flags|=65536,t.lanes=e,u!==jf&&(l=Error(h(422),{cause:u}),Ju(mt(l,a)))):(u!==jf&&(t=Error(h(423),{cause:u}),Ju(mt(t,a))),l=l.current.alternate,l.flags|=65536,e&=-e,l.lanes|=e,u=mt(u,a),e=ri(l.stateNode,u,e),Wf(l,e),gl!==4&&(gl=2)),!1;var n=Error(h(520),{cause:u});if(n=mt(n,a),oe===null?oe=[n]:oe.push(n),gl!==4&&(gl=2),t===null)return!0;u=mt(u,a),a=t;do{switch(a.tag){case 3:return a.flags|=65536,l=e&-e,a.lanes|=l,l=ri(a.stateNode,u,l),Wf(a,l),!1;case 1:if(t=a.type,n=a.stateNode,(a.flags&128)===0&&(typeof t.getDerivedStateFromError=="function"||n!==null&&typeof n.componentDidCatch=="function"&&(va===null||!va.has(n))))return a.flags|=65536,e&=-e,a.lanes|=e,e=X0(e),Q0(e,l,a,u),Wf(a,e),!1}a=a.return}while(a!==null);return!1}var bi=Error(h(461)),Al=!1;function Cl(l,t,a,u){t.child=l===null?Ks(t,null,a,u):Ya(t,l.child,a,u)}function Z0(l,t,a,u,e){a=a.render;var n=t.ref;if("ref"in u){var f={};for(var i in u)i!=="ref"&&(f[i]=u[i])}else f=u;return Ca(t),u=li(l,t,a,f,n,e),i=ti(),l!==null&&!Al?(ai(l,t,e),Vt(l,t,e)):(W&&i&&Bf(t),t.flags|=1,Cl(l,t,u,e),t.child)}function V0(l,t,a,u,e){if(l===null){var n=a.type;return typeof n=="function"&&!Rf(n)&&n.defaultProps===void 0&&a.compare===null?(t.tag=15,t.type=n,L0(l,t,n,u,e)):(l=Ve(a.type,null,u,t,t.mode,e),l.ref=t.ref,l.return=t,t.child=l)}if(n=l.child,!Oi(l,e)){var f=n.memoizedProps;if(a=a.compare,a=a!==null?a:Vu,a(f,u)&&l.ref===t.ref)return Vt(l,t,e)}return t.flags|=1,l=jt(n,u),l.ref=t.ref,l.return=t,t.child=l}function L0(l,t,a,u,e){if(l!==null){var n=l.memoizedProps;if(Vu(n,u)&&l.ref===t.ref)if(Al=!1,t.pendingProps=u=n,Oi(l,e))(l.flags&131072)!==0&&(Al=!0);else return t.lanes=l.lanes,Vt(l,t,e)}return zi(l,t,a,u,e)}function K0(l,t,a,u){var e=u.children,n=l!==null?l.memoizedState:null;if(l===null&&t.stateNode===null&&(t.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),u.mode==="hidden"){if((t.flags&128)!==0){if(n=n!==null?n.baseLanes|a:a,l!==null){for(u=t.child=l.child,e=0;u!==null;)e=e|u.lanes|u.childLanes,u=u.sibling;u=e&~n}else u=0,t.child=null;return J0(l,t,n,a,u)}if((a&536870912)!==0)t.memoizedState={baseLanes:0,cachePool:null},l!==null&&we(t,n!==null?n.cachePool:null),n!==null?Ws(t,n):kf(),$s(t);else return u=t.lanes=536870912,J0(l,t,n!==null?n.baseLanes|a:a,a,u)}else n!==null?(we(t,n.cachePool),Ws(t,n),sa(),t.memoizedState=null):(l!==null&&we(t,null),kf(),sa());return Cl(l,t,e,a),t.child}function ee(l,t){return l!==null&&l.tag===22||t.stateNode!==null||(t.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),t.sibling}function J0(l,t,a,u,e){var n=Lf();return n=n===null?null:{parent:El._currentValue,pool:n},t.memoizedState={baseLanes:a,cachePool:n},l!==null&&we(t,null),kf(),$s(t),l!==null&&iu(l,t,u,!0),t.childLanes=e,null}function dn(l,t){return t=yn({mode:t.mode,children:t.children},l.mode),t.ref=l.ref,l.child=t,t.return=l,t}function w0(l,t,a){return Ya(t,l.child,null,a),l=dn(t,t.pendingProps),l.flags|=2,ft(t),t.memoizedState=null,l}function yv(l,t,a){var u=t.pendingProps,e=(t.flags&128)!==0;if(t.flags&=-129,l===null){if(W){if(u.mode==="hidden")return l=dn(t,u),t.lanes=536870912,ee(null,l);if(If(t),(l=ol)?(l=no(l,St),l=l!==null&&l.data==="&"?l:null,l!==null&&(t.memoizedState={dehydrated:l,treeContext:ta!==null?{id:Dt,overflow:Ut}:null,retryLane:536870912,hydrationErrors:null},a=xs(l),a.return=t,t.child=a,Rl=t,ol=null)):l=null,l===null)throw ua(t);return t.lanes=536870912,null}return dn(t,u)}var n=l.memoizedState;if(n!==null){var f=n.dehydrated;if(If(t),e)if(t.flags&256)t.flags&=-257,t=w0(l,t,a);else if(t.memoizedState!==null)t.child=l.child,t.flags|=128,t=null;else throw Error(h(558));else if(Al||iu(l,t,a,!1),e=(a&l.childLanes)!==0,Al||e){if(u=dl,u!==null&&(f=jc(u,a),f!==0&&f!==n.retryLane))throw n.retryLane=f,xa(l,f),Fl(u,l,f),bi;Tn(),t=w0(l,t,a)}else l=n.treeContext,ol=bt(f.nextSibling),Rl=t,W=!0,aa=null,St=!1,l!==null&&Ns(t,l),t=dn(t,u),t.flags|=4096;return t}return l=jt(l.child,{mode:u.mode,children:u.children}),l.ref=t.ref,t.child=l,l.return=t,l}function on(l,t){var a=t.ref;if(a===null)l!==null&&l.ref!==null&&(t.flags|=4194816);else{if(typeof a!="function"&&typeof a!="object")throw Error(h(284));(l===null||l.ref!==a)&&(t.flags|=4194816)}}function zi(l,t,a,u,e){return Ca(t),a=li(l,t,a,u,void 0,e),u=ti(),l!==null&&!Al?(ai(l,t,e),Vt(l,t,e)):(W&&u&&Bf(t),t.flags|=1,Cl(l,t,a,e),t.child)}function W0(l,t,a,u,e,n){return Ca(t),t.updateQueue=null,a=Fs(t,u,a,e),ks(l),u=ti(),l!==null&&!Al?(ai(l,t,n),Vt(l,t,n)):(W&&u&&Bf(t),t.flags|=1,Cl(l,t,a,n),t.child)}function $0(l,t,a,u,e){if(Ca(t),t.stateNode===null){var n=uu,f=a.contextType;typeof f=="object"&&f!==null&&(n=Nl(f)),n=new a(u,n),t.memoizedState=n.state!==null&&n.state!==void 0?n.state:null,n.updater=Si,t.stateNode=n,n._reactInternals=t,n=t.stateNode,n.props=u,n.state=t.memoizedState,n.refs={},Jf(t),f=a.contextType,n.context=typeof f=="object"&&f!==null?Nl(f):uu,n.state=t.memoizedState,f=a.getDerivedStateFromProps,typeof f=="function"&&(gi(t,a,f,u),n.state=t.memoizedState),typeof a.getDerivedStateFromProps=="function"||typeof n.getSnapshotBeforeUpdate=="function"||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(f=n.state,typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount(),f!==n.state&&Si.enqueueReplaceState(n,n.state,null),Pu(t,u,n,e),Iu(),n.state=t.memoizedState),typeof n.componentDidMount=="function"&&(t.flags|=4194308),u=!0}else if(l===null){n=t.stateNode;var i=t.memoizedProps,c=Xa(a,i);n.props=c;var v=n.context,S=a.contextType;f=uu,typeof S=="object"&&S!==null&&(f=Nl(S));var z=a.getDerivedStateFromProps;S=typeof z=="function"||typeof n.getSnapshotBeforeUpdate=="function",i=t.pendingProps!==i,S||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(i||v!==f)&&B0(t,n,u,f),na=!1;var m=t.memoizedState;n.state=m,Pu(t,u,n,e),Iu(),v=t.memoizedState,i||m!==v||na?(typeof z=="function"&&(gi(t,a,z,u),v=t.memoizedState),(c=na||C0(t,a,c,u,m,v,f))?(S||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount()),typeof n.componentDidMount=="function"&&(t.flags|=4194308)):(typeof n.componentDidMount=="function"&&(t.flags|=4194308),t.memoizedProps=u,t.memoizedState=v),n.props=u,n.state=v,n.context=f,u=c):(typeof n.componentDidMount=="function"&&(t.flags|=4194308),u=!1)}else{n=t.stateNode,wf(l,t),f=t.memoizedProps,S=Xa(a,f),n.props=S,z=t.pendingProps,m=n.context,v=a.contextType,c=uu,typeof v=="object"&&v!==null&&(c=Nl(v)),i=a.getDerivedStateFromProps,(v=typeof i=="function"||typeof n.getSnapshotBeforeUpdate=="function")||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(f!==z||m!==c)&&B0(t,n,u,c),na=!1,m=t.memoizedState,n.state=m,Pu(t,u,n,e),Iu();var g=t.memoizedState;f!==z||m!==g||na||l!==null&&l.dependencies!==null&&Ke(l.dependencies)?(typeof i=="function"&&(gi(t,a,i,u),g=t.memoizedState),(S=na||C0(t,a,S,u,m,g,c)||l!==null&&l.dependencies!==null&&Ke(l.dependencies))?(v||typeof n.UNSAFE_componentWillUpdate!="function"&&typeof n.componentWillUpdate!="function"||(typeof n.componentWillUpdate=="function"&&n.componentWillUpdate(u,g,c),typeof n.UNSAFE_componentWillUpdate=="function"&&n.UNSAFE_componentWillUpdate(u,g,c)),typeof n.componentDidUpdate=="function"&&(t.flags|=4),typeof n.getSnapshotBeforeUpdate=="function"&&(t.flags|=1024)):(typeof n.componentDidUpdate!="function"||f===l.memoizedProps&&m===l.memoizedState||(t.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||f===l.memoizedProps&&m===l.memoizedState||(t.flags|=1024),t.memoizedProps=u,t.memoizedState=g),n.props=u,n.state=g,n.context=c,u=S):(typeof n.componentDidUpdate!="function"||f===l.memoizedProps&&m===l.memoizedState||(t.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||f===l.memoizedProps&&m===l.memoizedState||(t.flags|=1024),u=!1)}return n=u,on(l,t),u=(t.flags&128)!==0,n||u?(n=t.stateNode,a=u&&typeof a.getDerivedStateFromError!="function"?null:n.render(),t.flags|=1,l!==null&&u?(t.child=Ya(t,l.child,null,e),t.child=Ya(t,null,a,e)):Cl(l,t,a,e),t.memoizedState=n.state,l=t.child):l=Vt(l,t,e),l}function k0(l,t,a,u){return Ra(),t.flags|=256,Cl(l,t,a,u),t.child}var Ti={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function Ei(l){return{baseLanes:l,cachePool:Gs()}}function pi(l,t,a){return l=l!==null?l.childLanes&~a:0,t&&(l|=ct),l}function F0(l,t,a){var u=t.pendingProps,e=!1,n=(t.flags&128)!==0,f;if((f=n)||(f=l!==null&&l.memoizedState===null?!1:(zl.current&2)!==0),f&&(e=!0,t.flags&=-129),f=(t.flags&32)!==0,t.flags&=-33,l===null){if(W){if(e?ca(t):sa(),(l=ol)?(l=no(l,St),l=l!==null&&l.data!=="&"?l:null,l!==null&&(t.memoizedState={dehydrated:l,treeContext:ta!==null?{id:Dt,overflow:Ut}:null,retryLane:536870912,hydrationErrors:null},a=xs(l),a.return=t,t.child=a,Rl=t,ol=null)):l=null,l===null)throw ua(t);return nc(l)?t.lanes=32:t.lanes=536870912,null}var i=u.children;return u=u.fallback,e?(sa(),e=t.mode,i=yn({mode:"hidden",children:i},e),u=Ha(u,e,a,null),i.return=t,u.return=t,i.sibling=u,t.child=i,u=t.child,u.memoizedState=Ei(a),u.childLanes=pi(l,f,a),t.memoizedState=Ti,ee(null,u)):(ca(t),Ai(t,i))}var c=l.memoizedState;if(c!==null&&(i=c.dehydrated,i!==null)){if(n)t.flags&256?(ca(t),t.flags&=-257,t=_i(l,t,a)):t.memoizedState!==null?(sa(),t.child=l.child,t.flags|=128,t=null):(sa(),i=u.fallback,e=t.mode,u=yn({mode:"visible",children:u.children},e),i=Ha(i,e,a,null),i.flags|=2,u.return=t,i.return=t,u.sibling=i,t.child=u,Ya(t,l.child,null,a),u=t.child,u.memoizedState=Ei(a),u.childLanes=pi(l,f,a),t.memoizedState=Ti,t=ee(null,u));else if(ca(t),nc(i)){if(f=i.nextSibling&&i.nextSibling.dataset,f)var v=f.dgst;f=v,u=Error(h(419)),u.stack="",u.digest=f,Ju({value:u,source:null,stack:null}),t=_i(l,t,a)}else if(Al||iu(l,t,a,!1),f=(a&l.childLanes)!==0,Al||f){if(f=dl,f!==null&&(u=jc(f,a),u!==0&&u!==c.retryLane))throw c.retryLane=u,xa(l,u),Fl(f,l,u),bi;ec(i)||Tn(),t=_i(l,t,a)}else ec(i)?(t.flags|=192,t.child=l.child,t=null):(l=c.treeContext,ol=bt(i.nextSibling),Rl=t,W=!0,aa=null,St=!1,l!==null&&Ns(t,l),t=Ai(t,u.children),t.flags|=4096);return t}return e?(sa(),i=u.fallback,e=t.mode,c=l.child,v=c.sibling,u=jt(c,{mode:"hidden",children:u.children}),u.subtreeFlags=c.subtreeFlags&65011712,v!==null?i=jt(v,i):(i=Ha(i,e,a,null),i.flags|=2),i.return=t,u.return=t,u.sibling=i,t.child=u,ee(null,u),u=t.child,i=l.child.memoizedState,i===null?i=Ei(a):(e=i.cachePool,e!==null?(c=El._currentValue,e=e.parent!==c?{parent:c,pool:c}:e):e=Gs(),i={baseLanes:i.baseLanes|a,cachePool:e}),u.memoizedState=i,u.childLanes=pi(l,f,a),t.memoizedState=Ti,ee(l.child,u)):(ca(t),a=l.child,l=a.sibling,a=jt(a,{mode:"visible",children:u.children}),a.return=t,a.sibling=null,l!==null&&(f=t.deletions,f===null?(t.deletions=[l],t.flags|=16):f.push(l)),t.child=a,t.memoizedState=null,a)}function Ai(l,t){return t=yn({mode:"visible",children:t},l.mode),t.return=l,l.child=t}function yn(l,t){return l=et(22,l,null,t),l.lanes=0,l}function _i(l,t,a){return Ya(t,l.child,null,a),l=Ai(t,t.pendingProps.children),l.flags|=2,t.memoizedState=null,l}function I0(l,t,a){l.lanes|=t;var u=l.alternate;u!==null&&(u.lanes|=t),Xf(l.return,t,a)}function Mi(l,t,a,u,e,n){var f=l.memoizedState;f===null?l.memoizedState={isBackwards:t,rendering:null,renderingStartTime:0,last:u,tail:a,tailMode:e,treeForkCount:n}:(f.isBackwards=t,f.rendering=null,f.renderingStartTime=0,f.last=u,f.tail=a,f.tailMode=e,f.treeForkCount=n)}function P0(l,t,a){var u=t.pendingProps,e=u.revealOrder,n=u.tail;u=u.children;var f=zl.current,i=(f&2)!==0;if(i?(f=f&1|2,t.flags|=128):f&=1,_(zl,f),Cl(l,t,u,a),u=W?Ku:0,!i&&l!==null&&(l.flags&128)!==0)l:for(l=t.child;l!==null;){if(l.tag===13)l.memoizedState!==null&&I0(l,a,t);else if(l.tag===19)I0(l,a,t);else if(l.child!==null){l.child.return=l,l=l.child;continue}if(l===t)break l;for(;l.sibling===null;){if(l.return===null||l.return===t)break l;l=l.return}l.sibling.return=l.return,l=l.sibling}switch(e){case"forwards":for(a=t.child,e=null;a!==null;)l=a.alternate,l!==null&&Pe(l)===null&&(e=a),a=a.sibling;a=e,a===null?(e=t.child,t.child=null):(e=a.sibling,a.sibling=null),Mi(t,!1,e,a,n,u);break;case"backwards":case"unstable_legacy-backwards":for(a=null,e=t.child,t.child=null;e!==null;){if(l=e.alternate,l!==null&&Pe(l)===null){t.child=e;break}l=e.sibling,e.sibling=a,a=e,e=l}Mi(t,!0,a,null,n,u);break;case"together":Mi(t,!1,null,null,void 0,u);break;default:t.memoizedState=null}return t.child}function Vt(l,t,a){if(l!==null&&(t.dependencies=l.dependencies),ya|=t.lanes,(a&t.childLanes)===0)if(l!==null){if(iu(l,t,a,!1),(a&t.childLanes)===0)return null}else return null;if(l!==null&&t.child!==l.child)throw Error(h(153));if(t.child!==null){for(l=t.child,a=jt(l,l.pendingProps),t.child=a,a.return=t;l.sibling!==null;)l=l.sibling,a=a.sibling=jt(l,l.pendingProps),a.return=t;a.sibling=null}return t.child}function Oi(l,t){return(l.lanes&t)!==0?!0:(l=l.dependencies,!!(l!==null&&Ke(l)))}function vv(l,t,a){switch(t.tag){case 3:Xl(t,t.stateNode.containerInfo),ea(t,El,l.memoizedState.cache),Ra();break;case 27:case 5:xu(t);break;case 4:Xl(t,t.stateNode.containerInfo);break;case 10:ea(t,t.type,t.memoizedProps.value);break;case 31:if(t.memoizedState!==null)return t.flags|=128,If(t),null;break;case 13:var u=t.memoizedState;if(u!==null)return u.dehydrated!==null?(ca(t),t.flags|=128,null):(a&t.child.childLanes)!==0?F0(l,t,a):(ca(t),l=Vt(l,t,a),l!==null?l.sibling:null);ca(t);break;case 19:var e=(l.flags&128)!==0;if(u=(a&t.childLanes)!==0,u||(iu(l,t,a,!1),u=(a&t.childLanes)!==0),e){if(u)return P0(l,t,a);t.flags|=128}if(e=t.memoizedState,e!==null&&(e.rendering=null,e.tail=null,e.lastEffect=null),_(zl,zl.current),u)break;return null;case 22:return t.lanes=0,K0(l,t,a,t.pendingProps);case 24:ea(t,El,l.memoizedState.cache)}return Vt(l,t,a)}function ld(l,t,a){if(l!==null)if(l.memoizedProps!==t.pendingProps)Al=!0;else{if(!Oi(l,a)&&(t.flags&128)===0)return Al=!1,vv(l,t,a);Al=(l.flags&131072)!==0}else Al=!1,W&&(t.flags&1048576)!==0&&Rs(t,Ku,t.index);switch(t.lanes=0,t.tag){case 16:l:{var u=t.pendingProps;if(l=qa(t.elementType),t.type=l,typeof l=="function")Rf(l)?(u=Xa(l,u),t.tag=1,t=$0(null,t,l,u,a)):(t.tag=0,t=zi(null,t,l,u,a));else{if(l!=null){var e=l.$$typeof;if(e===dt){t.tag=11,t=Z0(null,t,l,u,a);break l}else if(e===w){t.tag=14,t=V0(null,t,l,u,a);break l}}throw t=Nt(l)||l,Error(h(306,t,""))}}return t;case 0:return zi(l,t,t.type,t.pendingProps,a);case 1:return u=t.type,e=Xa(u,t.pendingProps),$0(l,t,u,e,a);case 3:l:{if(Xl(t,t.stateNode.containerInfo),l===null)throw Error(h(387));u=t.pendingProps;var n=t.memoizedState;e=n.element,wf(l,t),Pu(t,u,null,a);var f=t.memoizedState;if(u=f.cache,ea(t,El,u),u!==n.cache&&Qf(t,[El],a,!0),Iu(),u=f.element,n.isDehydrated)if(n={element:u,isDehydrated:!1,cache:f.cache},t.updateQueue.baseState=n,t.memoizedState=n,t.flags&256){t=k0(l,t,u,a);break l}else if(u!==e){e=mt(Error(h(424)),t),Ju(e),t=k0(l,t,u,a);break l}else{switch(l=t.stateNode.containerInfo,l.nodeType){case 9:l=l.body;break;default:l=l.nodeName==="HTML"?l.ownerDocument.body:l}for(ol=bt(l.firstChild),Rl=t,W=!0,aa=null,St=!0,a=Ks(t,null,u,a),t.child=a;a;)a.flags=a.flags&-3|4096,a=a.sibling}else{if(Ra(),u===e){t=Vt(l,t,a);break l}Cl(l,t,u,a)}t=t.child}return t;case 26:return on(l,t),l===null?(a=yo(t.type,null,t.pendingProps,null))?t.memoizedState=a:W||(a=t.type,l=t.pendingProps,u=Dn(Q.current).createElement(a),u[Hl]=t,u[Kl]=l,Bl(u,a,l),Ul(u),t.stateNode=u):t.memoizedState=yo(t.type,l.memoizedProps,t.pendingProps,l.memoizedState),null;case 27:return xu(t),l===null&&W&&(u=t.stateNode=co(t.type,t.pendingProps,Q.current),Rl=t,St=!0,e=ol,Sa(t.type)?(fc=e,ol=bt(u.firstChild)):ol=e),Cl(l,t,t.pendingProps.children,a),on(l,t),l===null&&(t.flags|=4194304),t.child;case 5:return l===null&&W&&((e=u=ol)&&(u=Vv(u,t.type,t.pendingProps,St),u!==null?(t.stateNode=u,Rl=t,ol=bt(u.firstChild),St=!1,e=!0):e=!1),e||ua(t)),xu(t),e=t.type,n=t.pendingProps,f=l!==null?l.memoizedProps:null,u=n.children,tc(e,n)?u=null:f!==null&&tc(e,f)&&(t.flags|=32),t.memoizedState!==null&&(e=li(l,t,ev,null,null,a),be._currentValue=e),on(l,t),Cl(l,t,u,a),t.child;case 6:return l===null&&W&&((l=a=ol)&&(a=Lv(a,t.pendingProps,St),a!==null?(t.stateNode=a,Rl=t,ol=null,l=!0):l=!1),l||ua(t)),null;case 13:return F0(l,t,a);case 4:return Xl(t,t.stateNode.containerInfo),u=t.pendingProps,l===null?t.child=Ya(t,null,u,a):Cl(l,t,u,a),t.child;case 11:return Z0(l,t,t.type,t.pendingProps,a);case 7:return Cl(l,t,t.pendingProps,a),t.child;case 8:return Cl(l,t,t.pendingProps.children,a),t.child;case 12:return Cl(l,t,t.pendingProps.children,a),t.child;case 10:return u=t.pendingProps,ea(t,t.type,u.value),Cl(l,t,u.children,a),t.child;case 9:return e=t.type._context,u=t.pendingProps.children,Ca(t),e=Nl(e),u=u(e),t.flags|=1,Cl(l,t,u,a),t.child;case 14:return V0(l,t,t.type,t.pendingProps,a);case 15:return L0(l,t,t.type,t.pendingProps,a);case 19:return P0(l,t,a);case 31:return yv(l,t,a);case 22:return K0(l,t,a,t.pendingProps);case 24:return Ca(t),u=Nl(El),l===null?(e=Lf(),e===null&&(e=dl,n=Zf(),e.pooledCache=n,n.refCount++,n!==null&&(e.pooledCacheLanes|=a),e=n),t.memoizedState={parent:u,cache:e},Jf(t),ea(t,El,e)):((l.lanes&a)!==0&&(wf(l,t),Pu(t,null,null,a),Iu()),e=l.memoizedState,n=t.memoizedState,e.parent!==u?(e={parent:u,cache:u},t.memoizedState=e,t.lanes===0&&(t.memoizedState=t.updateQueue.baseState=e),ea(t,El,u)):(u=n.cache,ea(t,El,u),u!==e.cache&&Qf(t,[El],a,!0))),Cl(l,t,t.pendingProps.children,a),t.child;case 29:throw t.pendingProps}throw Error(h(156,t.tag))}function Lt(l){l.flags|=4}function Di(l,t,a,u,e){if((t=(l.mode&32)!==0)&&(t=!1),t){if(l.flags|=16777216,(e&335544128)===e)if(l.stateNode.complete)l.flags|=8192;else if(Od())l.flags|=8192;else throw ja=$e,Kf}else l.flags&=-16777217}function td(l,t){if(t.type!=="stylesheet"||(t.state.loading&4)!==0)l.flags&=-16777217;else if(l.flags|=16777216,!So(t))if(Od())l.flags|=8192;else throw ja=$e,Kf}function vn(l,t){t!==null&&(l.flags|=4),l.flags&16384&&(t=l.tag!==22?Cc():536870912,l.lanes|=t,bu|=t)}function ne(l,t){if(!W)switch(l.tailMode){case"hidden":t=l.tail;for(var a=null;t!==null;)t.alternate!==null&&(a=t),t=t.sibling;a===null?l.tail=null:a.sibling=null;break;case"collapsed":a=l.tail;for(var u=null;a!==null;)a.alternate!==null&&(u=a),a=a.sibling;u===null?t||l.tail===null?l.tail=null:l.tail.sibling=null:u.sibling=null}}function yl(l){var t=l.alternate!==null&&l.alternate.child===l.child,a=0,u=0;if(t)for(var e=l.child;e!==null;)a|=e.lanes|e.childLanes,u|=e.subtreeFlags&65011712,u|=e.flags&65011712,e.return=l,e=e.sibling;else for(e=l.child;e!==null;)a|=e.lanes|e.childLanes,u|=e.subtreeFlags,u|=e.flags,e.return=l,e=e.sibling;return l.subtreeFlags|=u,l.childLanes=a,t}function mv(l,t,a){var u=t.pendingProps;switch(qf(t),t.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return yl(t),null;case 1:return yl(t),null;case 3:return a=t.stateNode,u=null,l!==null&&(u=l.memoizedState.cache),t.memoizedState.cache!==u&&(t.flags|=2048),Xt(El),bl(),a.pendingContext&&(a.context=a.pendingContext,a.pendingContext=null),(l===null||l.child===null)&&(fu(t)?Lt(t):l===null||l.memoizedState.isDehydrated&&(t.flags&256)===0||(t.flags|=1024,Yf())),yl(t),null;case 26:var e=t.type,n=t.memoizedState;return l===null?(Lt(t),n!==null?(yl(t),td(t,n)):(yl(t),Di(t,e,null,u,a))):n?n!==l.memoizedState?(Lt(t),yl(t),td(t,n)):(yl(t),t.flags&=-16777217):(l=l.memoizedProps,l!==u&&Lt(t),yl(t),Di(t,e,l,u,a)),null;case 27:if(pe(t),a=Q.current,e=t.type,l!==null&&t.stateNode!=null)l.memoizedProps!==u&&Lt(t);else{if(!u){if(t.stateNode===null)throw Error(h(166));return yl(t),null}l=O.current,fu(t)?Cs(t):(l=co(e,u,a),t.stateNode=l,Lt(t))}return yl(t),null;case 5:if(pe(t),e=t.type,l!==null&&t.stateNode!=null)l.memoizedProps!==u&&Lt(t);else{if(!u){if(t.stateNode===null)throw Error(h(166));return yl(t),null}if(n=O.current,fu(t))Cs(t);else{var f=Dn(Q.current);switch(n){case 1:n=f.createElementNS("http://www.w3.org/2000/svg",e);break;case 2:n=f.createElementNS("http://www.w3.org/1998/Math/MathML",e);break;default:switch(e){case"svg":n=f.createElementNS("http://www.w3.org/2000/svg",e);break;case"math":n=f.createElementNS("http://www.w3.org/1998/Math/MathML",e);break;case"script":n=f.createElement("div"),n.innerHTML="<script><\/script>",n=n.removeChild(n.firstChild);break;case"select":n=typeof u.is=="string"?f.createElement("select",{is:u.is}):f.createElement("select"),u.multiple?n.multiple=!0:u.size&&(n.size=u.size);break;default:n=typeof u.is=="string"?f.createElement(e,{is:u.is}):f.createElement(e)}}n[Hl]=t,n[Kl]=u;l:for(f=t.child;f!==null;){if(f.tag===5||f.tag===6)n.appendChild(f.stateNode);else if(f.tag!==4&&f.tag!==27&&f.child!==null){f.child.return=f,f=f.child;continue}if(f===t)break l;for(;f.sibling===null;){if(f.return===null||f.return===t)break l;f=f.return}f.sibling.return=f.return,f=f.sibling}t.stateNode=n;l:switch(Bl(n,e,u),e){case"button":case"input":case"select":case"textarea":u=!!u.autoFocus;break l;case"img":u=!0;break l;default:u=!1}u&&Lt(t)}}return yl(t),Di(t,t.type,l===null?null:l.memoizedProps,t.pendingProps,a),null;case 6:if(l&&t.stateNode!=null)l.memoizedProps!==u&&Lt(t);else{if(typeof u!="string"&&t.stateNode===null)throw Error(h(166));if(l=Q.current,fu(t)){if(l=t.stateNode,a=t.memoizedProps,u=null,e=Rl,e!==null)switch(e.tag){case 27:case 5:u=e.memoizedProps}l[Hl]=t,l=!!(l.nodeValue===a||u!==null&&u.suppressHydrationWarning===!0||Fd(l.nodeValue,a)),l||ua(t,!0)}else l=Dn(l).createTextNode(u),l[Hl]=t,t.stateNode=l}return yl(t),null;case 31:if(a=t.memoizedState,l===null||l.memoizedState!==null){if(u=fu(t),a!==null){if(l===null){if(!u)throw Error(h(318));if(l=t.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(h(557));l[Hl]=t}else Ra(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;yl(t),l=!1}else a=Yf(),l!==null&&l.memoizedState!==null&&(l.memoizedState.hydrationErrors=a),l=!0;if(!l)return t.flags&256?(ft(t),t):(ft(t),null);if((t.flags&128)!==0)throw Error(h(558))}return yl(t),null;case 13:if(u=t.memoizedState,l===null||l.memoizedState!==null&&l.memoizedState.dehydrated!==null){if(e=fu(t),u!==null&&u.dehydrated!==null){if(l===null){if(!e)throw Error(h(318));if(e=t.memoizedState,e=e!==null?e.dehydrated:null,!e)throw Error(h(317));e[Hl]=t}else Ra(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;yl(t),e=!1}else e=Yf(),l!==null&&l.memoizedState!==null&&(l.memoizedState.hydrationErrors=e),e=!0;if(!e)return t.flags&256?(ft(t),t):(ft(t),null)}return ft(t),(t.flags&128)!==0?(t.lanes=a,t):(a=u!==null,l=l!==null&&l.memoizedState!==null,a&&(u=t.child,e=null,u.alternate!==null&&u.alternate.memoizedState!==null&&u.alternate.memoizedState.cachePool!==null&&(e=u.alternate.memoizedState.cachePool.pool),n=null,u.memoizedState!==null&&u.memoizedState.cachePool!==null&&(n=u.memoizedState.cachePool.pool),n!==e&&(u.flags|=2048)),a!==l&&a&&(t.child.flags|=8192),vn(t,t.updateQueue),yl(t),null);case 4:return bl(),l===null&&ki(t.stateNode.containerInfo),yl(t),null;case 10:return Xt(t.type),yl(t),null;case 19:if(T(zl),u=t.memoizedState,u===null)return yl(t),null;if(e=(t.flags&128)!==0,n=u.rendering,n===null)if(e)ne(u,!1);else{if(gl!==0||l!==null&&(l.flags&128)!==0)for(l=t.child;l!==null;){if(n=Pe(l),n!==null){for(t.flags|=128,ne(u,!1),l=n.updateQueue,t.updateQueue=l,vn(t,l),t.subtreeFlags=0,l=a,a=t.child;a!==null;)Us(a,l),a=a.sibling;return _(zl,zl.current&1|2),W&&Yt(t,u.treeForkCount),t.child}l=l.sibling}u.tail!==null&&lt()>rn&&(t.flags|=128,e=!0,ne(u,!1),t.lanes=4194304)}else{if(!e)if(l=Pe(n),l!==null){if(t.flags|=128,e=!0,l=l.updateQueue,t.updateQueue=l,vn(t,l),ne(u,!0),u.tail===null&&u.tailMode==="hidden"&&!n.alternate&&!W)return yl(t),null}else 2*lt()-u.renderingStartTime>rn&&a!==536870912&&(t.flags|=128,e=!0,ne(u,!1),t.lanes=4194304);u.isBackwards?(n.sibling=t.child,t.child=n):(l=u.last,l!==null?l.sibling=n:t.child=n,u.last=n)}return u.tail!==null?(l=u.tail,u.rendering=l,u.tail=l.sibling,u.renderingStartTime=lt(),l.sibling=null,a=zl.current,_(zl,e?a&1|2:a&1),W&&Yt(t,u.treeForkCount),l):(yl(t),null);case 22:case 23:return ft(t),Ff(),u=t.memoizedState!==null,l!==null?l.memoizedState!==null!==u&&(t.flags|=8192):u&&(t.flags|=8192),u?(a&536870912)!==0&&(t.flags&128)===0&&(yl(t),t.subtreeFlags&6&&(t.flags|=8192)):yl(t),a=t.updateQueue,a!==null&&vn(t,a.retryQueue),a=null,l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(a=l.memoizedState.cachePool.pool),u=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(u=t.memoizedState.cachePool.pool),u!==a&&(t.flags|=2048),l!==null&&T(Ba),null;case 24:return a=null,l!==null&&(a=l.memoizedState.cache),t.memoizedState.cache!==a&&(t.flags|=2048),Xt(El),yl(t),null;case 25:return null;case 30:return null}throw Error(h(156,t.tag))}function hv(l,t){switch(qf(t),t.tag){case 1:return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 3:return Xt(El),bl(),l=t.flags,(l&65536)!==0&&(l&128)===0?(t.flags=l&-65537|128,t):null;case 26:case 27:case 5:return pe(t),null;case 31:if(t.memoizedState!==null){if(ft(t),t.alternate===null)throw Error(h(340));Ra()}return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 13:if(ft(t),l=t.memoizedState,l!==null&&l.dehydrated!==null){if(t.alternate===null)throw Error(h(340));Ra()}return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 19:return T(zl),null;case 4:return bl(),null;case 10:return Xt(t.type),null;case 22:case 23:return ft(t),Ff(),l!==null&&T(Ba),l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 24:return Xt(El),null;case 25:return null;default:return null}}function ad(l,t){switch(qf(t),t.tag){case 3:Xt(El),bl();break;case 26:case 27:case 5:pe(t);break;case 4:bl();break;case 31:t.memoizedState!==null&&ft(t);break;case 13:ft(t);break;case 19:T(zl);break;case 10:Xt(t.type);break;case 22:case 23:ft(t),Ff(),l!==null&&T(Ba);break;case 24:Xt(El)}}function fe(l,t){try{var a=t.updateQueue,u=a!==null?a.lastEffect:null;if(u!==null){var e=u.next;a=e;do{if((a.tag&l)===l){u=void 0;var n=a.create,f=a.inst;u=n(),f.destroy=u}a=a.next}while(a!==e)}}catch(i){ul(t,t.return,i)}}function da(l,t,a){try{var u=t.updateQueue,e=u!==null?u.lastEffect:null;if(e!==null){var n=e.next;u=n;do{if((u.tag&l)===l){var f=u.inst,i=f.destroy;if(i!==void 0){f.destroy=void 0,e=t;var c=a,v=i;try{v()}catch(S){ul(e,c,S)}}}u=u.next}while(u!==n)}}catch(S){ul(t,t.return,S)}}function ud(l){var t=l.updateQueue;if(t!==null){var a=l.stateNode;try{ws(t,a)}catch(u){ul(l,l.return,u)}}}function ed(l,t,a){a.props=Xa(l.type,l.memoizedProps),a.state=l.memoizedState;try{a.componentWillUnmount()}catch(u){ul(l,t,u)}}function ie(l,t){try{var a=l.ref;if(a!==null){switch(l.tag){case 26:case 27:case 5:var u=l.stateNode;break;case 30:u=l.stateNode;break;default:u=l.stateNode}typeof a=="function"?l.refCleanup=a(u):a.current=u}}catch(e){ul(l,t,e)}}function xt(l,t){var a=l.ref,u=l.refCleanup;if(a!==null)if(typeof u=="function")try{u()}catch(e){ul(l,t,e)}finally{l.refCleanup=null,l=l.alternate,l!=null&&(l.refCleanup=null)}else if(typeof a=="function")try{a(null)}catch(e){ul(l,t,e)}else a.current=null}function nd(l){var t=l.type,a=l.memoizedProps,u=l.stateNode;try{l:switch(t){case"button":case"input":case"select":case"textarea":a.autoFocus&&u.focus();break l;case"img":a.src?u.src=a.src:a.srcSet&&(u.srcset=a.srcSet)}}catch(e){ul(l,l.return,e)}}function Ui(l,t,a){try{var u=l.stateNode;jv(u,l.type,a,t),u[Kl]=t}catch(e){ul(l,l.return,e)}}function fd(l){return l.tag===5||l.tag===3||l.tag===26||l.tag===27&&Sa(l.type)||l.tag===4}function xi(l){l:for(;;){for(;l.sibling===null;){if(l.return===null||fd(l.return))return null;l=l.return}for(l.sibling.return=l.return,l=l.sibling;l.tag!==5&&l.tag!==6&&l.tag!==18;){if(l.tag===27&&Sa(l.type)||l.flags&2||l.child===null||l.tag===4)continue l;l.child.return=l,l=l.child}if(!(l.flags&2))return l.stateNode}}function Hi(l,t,a){var u=l.tag;if(u===5||u===6)l=l.stateNode,t?(a.nodeType===9?a.body:a.nodeName==="HTML"?a.ownerDocument.body:a).insertBefore(l,t):(t=a.nodeType===9?a.body:a.nodeName==="HTML"?a.ownerDocument.body:a,t.appendChild(l),a=a._reactRootContainer,a!=null||t.onclick!==null||(t.onclick=Bt));else if(u!==4&&(u===27&&Sa(l.type)&&(a=l.stateNode,t=null),l=l.child,l!==null))for(Hi(l,t,a),l=l.sibling;l!==null;)Hi(l,t,a),l=l.sibling}function mn(l,t,a){var u=l.tag;if(u===5||u===6)l=l.stateNode,t?a.insertBefore(l,t):a.appendChild(l);else if(u!==4&&(u===27&&Sa(l.type)&&(a=l.stateNode),l=l.child,l!==null))for(mn(l,t,a),l=l.sibling;l!==null;)mn(l,t,a),l=l.sibling}function id(l){var t=l.stateNode,a=l.memoizedProps;try{for(var u=l.type,e=t.attributes;e.length;)t.removeAttributeNode(e[0]);Bl(t,u,a),t[Hl]=l,t[Kl]=a}catch(n){ul(l,l.return,n)}}var Kt=!1,_l=!1,Ri=!1,cd=typeof WeakSet=="function"?WeakSet:Set,xl=null;function gv(l,t){if(l=l.containerInfo,Pi=Bn,l=zs(l),_f(l)){if("selectionStart"in l)var a={start:l.selectionStart,end:l.selectionEnd};else l:{a=(a=l.ownerDocument)&&a.defaultView||window;var u=a.getSelection&&a.getSelection();if(u&&u.rangeCount!==0){a=u.anchorNode;var e=u.anchorOffset,n=u.focusNode;u=u.focusOffset;try{a.nodeType,n.nodeType}catch{a=null;break l}var f=0,i=-1,c=-1,v=0,S=0,z=l,m=null;t:for(;;){for(var g;z!==a||e!==0&&z.nodeType!==3||(i=f+e),z!==n||u!==0&&z.nodeType!==3||(c=f+u),z.nodeType===3&&(f+=z.nodeValue.length),(g=z.firstChild)!==null;)m=z,z=g;for(;;){if(z===l)break t;if(m===a&&++v===e&&(i=f),m===n&&++S===u&&(c=f),(g=z.nextSibling)!==null)break;z=m,m=z.parentNode}z=g}a=i===-1||c===-1?null:{start:i,end:c}}else a=null}a=a||{start:0,end:0}}else a=null;for(lc={focusedElem:l,selectionRange:a},Bn=!1,xl=t;xl!==null;)if(t=xl,l=t.child,(t.subtreeFlags&1028)!==0&&l!==null)l.return=t,xl=l;else for(;xl!==null;){switch(t=xl,n=t.alternate,l=t.flags,t.tag){case 0:if((l&4)!==0&&(l=t.updateQueue,l=l!==null?l.events:null,l!==null))for(a=0;a<l.length;a++)e=l[a],e.ref.impl=e.nextImpl;break;case 11:case 15:break;case 1:if((l&1024)!==0&&n!==null){l=void 0,a=t,e=n.memoizedProps,n=n.memoizedState,u=a.stateNode;try{var M=Xa(a.type,e);l=u.getSnapshotBeforeUpdate(M,n),u.__reactInternalSnapshotBeforeUpdate=l}catch(N){ul(a,a.return,N)}}break;case 3:if((l&1024)!==0){if(l=t.stateNode.containerInfo,a=l.nodeType,a===9)uc(l);else if(a===1)switch(l.nodeName){case"HEAD":case"HTML":case"BODY":uc(l);break;default:l.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((l&1024)!==0)throw Error(h(163))}if(l=t.sibling,l!==null){l.return=t.return,xl=l;break}xl=t.return}}function sd(l,t,a){var u=a.flags;switch(a.tag){case 0:case 11:case 15:wt(l,a),u&4&&fe(5,a);break;case 1:if(wt(l,a),u&4)if(l=a.stateNode,t===null)try{l.componentDidMount()}catch(f){ul(a,a.return,f)}else{var e=Xa(a.type,t.memoizedProps);t=t.memoizedState;try{l.componentDidUpdate(e,t,l.__reactInternalSnapshotBeforeUpdate)}catch(f){ul(a,a.return,f)}}u&64&&ud(a),u&512&&ie(a,a.return);break;case 3:if(wt(l,a),u&64&&(l=a.updateQueue,l!==null)){if(t=null,a.child!==null)switch(a.child.tag){case 27:case 5:t=a.child.stateNode;break;case 1:t=a.child.stateNode}try{ws(l,t)}catch(f){ul(a,a.return,f)}}break;case 27:t===null&&u&4&&id(a);case 26:case 5:wt(l,a),t===null&&u&4&&nd(a),u&512&&ie(a,a.return);break;case 12:wt(l,a);break;case 31:wt(l,a),u&4&&yd(l,a);break;case 13:wt(l,a),u&4&&vd(l,a),u&64&&(l=a.memoizedState,l!==null&&(l=l.dehydrated,l!==null&&(a=_v.bind(null,a),Kv(l,a))));break;case 22:if(u=a.memoizedState!==null||Kt,!u){t=t!==null&&t.memoizedState!==null||_l,e=Kt;var n=_l;Kt=u,(_l=t)&&!n?Wt(l,a,(a.subtreeFlags&8772)!==0):wt(l,a),Kt=e,_l=n}break;case 30:break;default:wt(l,a)}}function dd(l){var t=l.alternate;t!==null&&(l.alternate=null,dd(t)),l.child=null,l.deletions=null,l.sibling=null,l.tag===5&&(t=l.stateNode,t!==null&&cf(t)),l.stateNode=null,l.return=null,l.dependencies=null,l.memoizedProps=null,l.memoizedState=null,l.pendingProps=null,l.stateNode=null,l.updateQueue=null}var ml=null,wl=!1;function Jt(l,t,a){for(a=a.child;a!==null;)od(l,t,a),a=a.sibling}function od(l,t,a){if(tt&&typeof tt.onCommitFiberUnmount=="function")try{tt.onCommitFiberUnmount(Hu,a)}catch{}switch(a.tag){case 26:_l||xt(a,t),Jt(l,t,a),a.memoizedState?a.memoizedState.count--:a.stateNode&&(a=a.stateNode,a.parentNode.removeChild(a));break;case 27:_l||xt(a,t);var u=ml,e=wl;Sa(a.type)&&(ml=a.stateNode,wl=!1),Jt(l,t,a),ge(a.stateNode),ml=u,wl=e;break;case 5:_l||xt(a,t);case 6:if(u=ml,e=wl,ml=null,Jt(l,t,a),ml=u,wl=e,ml!==null)if(wl)try{(ml.nodeType===9?ml.body:ml.nodeName==="HTML"?ml.ownerDocument.body:ml).removeChild(a.stateNode)}catch(n){ul(a,t,n)}else try{ml.removeChild(a.stateNode)}catch(n){ul(a,t,n)}break;case 18:ml!==null&&(wl?(l=ml,uo(l.nodeType===9?l.body:l.nodeName==="HTML"?l.ownerDocument.body:l,a.stateNode),Ou(l)):uo(ml,a.stateNode));break;case 4:u=ml,e=wl,ml=a.stateNode.containerInfo,wl=!0,Jt(l,t,a),ml=u,wl=e;break;case 0:case 11:case 14:case 15:da(2,a,t),_l||da(4,a,t),Jt(l,t,a);break;case 1:_l||(xt(a,t),u=a.stateNode,typeof u.componentWillUnmount=="function"&&ed(a,t,u)),Jt(l,t,a);break;case 21:Jt(l,t,a);break;case 22:_l=(u=_l)||a.memoizedState!==null,Jt(l,t,a),_l=u;break;default:Jt(l,t,a)}}function yd(l,t){if(t.memoizedState===null&&(l=t.alternate,l!==null&&(l=l.memoizedState,l!==null))){l=l.dehydrated;try{Ou(l)}catch(a){ul(t,t.return,a)}}}function vd(l,t){if(t.memoizedState===null&&(l=t.alternate,l!==null&&(l=l.memoizedState,l!==null&&(l=l.dehydrated,l!==null))))try{Ou(l)}catch(a){ul(t,t.return,a)}}function Sv(l){switch(l.tag){case 31:case 13:case 19:var t=l.stateNode;return t===null&&(t=l.stateNode=new cd),t;case 22:return l=l.stateNode,t=l._retryCache,t===null&&(t=l._retryCache=new cd),t;default:throw Error(h(435,l.tag))}}function hn(l,t){var a=Sv(l);t.forEach(function(u){if(!a.has(u)){a.add(u);var e=Mv.bind(null,l,u);u.then(e,e)}})}function Wl(l,t){var a=t.deletions;if(a!==null)for(var u=0;u<a.length;u++){var e=a[u],n=l,f=t,i=f;l:for(;i!==null;){switch(i.tag){case 27:if(Sa(i.type)){ml=i.stateNode,wl=!1;break l}break;case 5:ml=i.stateNode,wl=!1;break l;case 3:case 4:ml=i.stateNode.containerInfo,wl=!0;break l}i=i.return}if(ml===null)throw Error(h(160));od(n,f,e),ml=null,wl=!1,n=e.alternate,n!==null&&(n.return=null),e.return=null}if(t.subtreeFlags&13886)for(t=t.child;t!==null;)md(t,l),t=t.sibling}var pt=null;function md(l,t){var a=l.alternate,u=l.flags;switch(l.tag){case 0:case 11:case 14:case 15:Wl(t,l),$l(l),u&4&&(da(3,l,l.return),fe(3,l),da(5,l,l.return));break;case 1:Wl(t,l),$l(l),u&512&&(_l||a===null||xt(a,a.return)),u&64&&Kt&&(l=l.updateQueue,l!==null&&(u=l.callbacks,u!==null&&(a=l.shared.hiddenCallbacks,l.shared.hiddenCallbacks=a===null?u:a.concat(u))));break;case 26:var e=pt;if(Wl(t,l),$l(l),u&512&&(_l||a===null||xt(a,a.return)),u&4){var n=a!==null?a.memoizedState:null;if(u=l.memoizedState,a===null)if(u===null)if(l.stateNode===null){l:{u=l.type,a=l.memoizedProps,e=e.ownerDocument||e;t:switch(u){case"title":n=e.getElementsByTagName("title")[0],(!n||n[Cu]||n[Hl]||n.namespaceURI==="http://www.w3.org/2000/svg"||n.hasAttribute("itemprop"))&&(n=e.createElement(u),e.head.insertBefore(n,e.querySelector("head > title"))),Bl(n,u,a),n[Hl]=l,Ul(n),u=n;break l;case"link":var f=ho("link","href",e).get(u+(a.href||""));if(f){for(var i=0;i<f.length;i++)if(n=f[i],n.getAttribute("href")===(a.href==null||a.href===""?null:a.href)&&n.getAttribute("rel")===(a.rel==null?null:a.rel)&&n.getAttribute("title")===(a.title==null?null:a.title)&&n.getAttribute("crossorigin")===(a.crossOrigin==null?null:a.crossOrigin)){f.splice(i,1);break t}}n=e.createElement(u),Bl(n,u,a),e.head.appendChild(n);break;case"meta":if(f=ho("meta","content",e).get(u+(a.content||""))){for(i=0;i<f.length;i++)if(n=f[i],n.getAttribute("content")===(a.content==null?null:""+a.content)&&n.getAttribute("name")===(a.name==null?null:a.name)&&n.getAttribute("property")===(a.property==null?null:a.property)&&n.getAttribute("http-equiv")===(a.httpEquiv==null?null:a.httpEquiv)&&n.getAttribute("charset")===(a.charSet==null?null:a.charSet)){f.splice(i,1);break t}}n=e.createElement(u),Bl(n,u,a),e.head.appendChild(n);break;default:throw Error(h(468,u))}n[Hl]=l,Ul(n),u=n}l.stateNode=u}else go(e,l.type,l.stateNode);else l.stateNode=mo(e,u,l.memoizedProps);else n!==u?(n===null?a.stateNode!==null&&(a=a.stateNode,a.parentNode.removeChild(a)):n.count--,u===null?go(e,l.type,l.stateNode):mo(e,u,l.memoizedProps)):u===null&&l.stateNode!==null&&Ui(l,l.memoizedProps,a.memoizedProps)}break;case 27:Wl(t,l),$l(l),u&512&&(_l||a===null||xt(a,a.return)),a!==null&&u&4&&Ui(l,l.memoizedProps,a.memoizedProps);break;case 5:if(Wl(t,l),$l(l),u&512&&(_l||a===null||xt(a,a.return)),l.flags&32){e=l.stateNode;try{ka(e,"")}catch(M){ul(l,l.return,M)}}u&4&&l.stateNode!=null&&(e=l.memoizedProps,Ui(l,e,a!==null?a.memoizedProps:e)),u&1024&&(Ri=!0);break;case 6:if(Wl(t,l),$l(l),u&4){if(l.stateNode===null)throw Error(h(162));u=l.memoizedProps,a=l.stateNode;try{a.nodeValue=u}catch(M){ul(l,l.return,M)}}break;case 3:if(Hn=null,e=pt,pt=Un(t.containerInfo),Wl(t,l),pt=e,$l(l),u&4&&a!==null&&a.memoizedState.isDehydrated)try{Ou(t.containerInfo)}catch(M){ul(l,l.return,M)}Ri&&(Ri=!1,hd(l));break;case 4:u=pt,pt=Un(l.stateNode.containerInfo),Wl(t,l),$l(l),pt=u;break;case 12:Wl(t,l),$l(l);break;case 31:Wl(t,l),$l(l),u&4&&(u=l.updateQueue,u!==null&&(l.updateQueue=null,hn(l,u)));break;case 13:Wl(t,l),$l(l),l.child.flags&8192&&l.memoizedState!==null!=(a!==null&&a.memoizedState!==null)&&(Sn=lt()),u&4&&(u=l.updateQueue,u!==null&&(l.updateQueue=null,hn(l,u)));break;case 22:e=l.memoizedState!==null;var c=a!==null&&a.memoizedState!==null,v=Kt,S=_l;if(Kt=v||e,_l=S||c,Wl(t,l),_l=S,Kt=v,$l(l),u&8192)l:for(t=l.stateNode,t._visibility=e?t._visibility&-2:t._visibility|1,e&&(a===null||c||Kt||_l||Qa(l)),a=null,t=l;;){if(t.tag===5||t.tag===26){if(a===null){c=a=t;try{if(n=c.stateNode,e)f=n.style,typeof f.setProperty=="function"?f.setProperty("display","none","important"):f.display="none";else{i=c.stateNode;var z=c.memoizedProps.style,m=z!=null&&z.hasOwnProperty("display")?z.display:null;i.style.display=m==null||typeof m=="boolean"?"":(""+m).trim()}}catch(M){ul(c,c.return,M)}}}else if(t.tag===6){if(a===null){c=t;try{c.stateNode.nodeValue=e?"":c.memoizedProps}catch(M){ul(c,c.return,M)}}}else if(t.tag===18){if(a===null){c=t;try{var g=c.stateNode;e?eo(g,!0):eo(c.stateNode,!1)}catch(M){ul(c,c.return,M)}}}else if((t.tag!==22&&t.tag!==23||t.memoizedState===null||t===l)&&t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break l;for(;t.sibling===null;){if(t.return===null||t.return===l)break l;a===t&&(a=null),t=t.return}a===t&&(a=null),t.sibling.return=t.return,t=t.sibling}u&4&&(u=l.updateQueue,u!==null&&(a=u.retryQueue,a!==null&&(u.retryQueue=null,hn(l,a))));break;case 19:Wl(t,l),$l(l),u&4&&(u=l.updateQueue,u!==null&&(l.updateQueue=null,hn(l,u)));break;case 30:break;case 21:break;default:Wl(t,l),$l(l)}}function $l(l){var t=l.flags;if(t&2){try{for(var a,u=l.return;u!==null;){if(fd(u)){a=u;break}u=u.return}if(a==null)throw Error(h(160));switch(a.tag){case 27:var e=a.stateNode,n=xi(l);mn(l,n,e);break;case 5:var f=a.stateNode;a.flags&32&&(ka(f,""),a.flags&=-33);var i=xi(l);mn(l,i,f);break;case 3:case 4:var c=a.stateNode.containerInfo,v=xi(l);Hi(l,v,c);break;default:throw Error(h(161))}}catch(S){ul(l,l.return,S)}l.flags&=-3}t&4096&&(l.flags&=-4097)}function hd(l){if(l.subtreeFlags&1024)for(l=l.child;l!==null;){var t=l;hd(t),t.tag===5&&t.flags&1024&&t.stateNode.reset(),l=l.sibling}}function wt(l,t){if(t.subtreeFlags&8772)for(t=t.child;t!==null;)sd(l,t.alternate,t),t=t.sibling}function Qa(l){for(l=l.child;l!==null;){var t=l;switch(t.tag){case 0:case 11:case 14:case 15:da(4,t,t.return),Qa(t);break;case 1:xt(t,t.return);var a=t.stateNode;typeof a.componentWillUnmount=="function"&&ed(t,t.return,a),Qa(t);break;case 27:ge(t.stateNode);case 26:case 5:xt(t,t.return),Qa(t);break;case 22:t.memoizedState===null&&Qa(t);break;case 30:Qa(t);break;default:Qa(t)}l=l.sibling}}function Wt(l,t,a){for(a=a&&(t.subtreeFlags&8772)!==0,t=t.child;t!==null;){var u=t.alternate,e=l,n=t,f=n.flags;switch(n.tag){case 0:case 11:case 15:Wt(e,n,a),fe(4,n);break;case 1:if(Wt(e,n,a),u=n,e=u.stateNode,typeof e.componentDidMount=="function")try{e.componentDidMount()}catch(v){ul(u,u.return,v)}if(u=n,e=u.updateQueue,e!==null){var i=u.stateNode;try{var c=e.shared.hiddenCallbacks;if(c!==null)for(e.shared.hiddenCallbacks=null,e=0;e<c.length;e++)Js(c[e],i)}catch(v){ul(u,u.return,v)}}a&&f&64&&ud(n),ie(n,n.return);break;case 27:id(n);case 26:case 5:Wt(e,n,a),a&&u===null&&f&4&&nd(n),ie(n,n.return);break;case 12:Wt(e,n,a);break;case 31:Wt(e,n,a),a&&f&4&&yd(e,n);break;case 13:Wt(e,n,a),a&&f&4&&vd(e,n);break;case 22:n.memoizedState===null&&Wt(e,n,a),ie(n,n.return);break;case 30:break;default:Wt(e,n,a)}t=t.sibling}}function Ni(l,t){var a=null;l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(a=l.memoizedState.cachePool.pool),l=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(l=t.memoizedState.cachePool.pool),l!==a&&(l!=null&&l.refCount++,a!=null&&wu(a))}function Ci(l,t){l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&wu(l))}function At(l,t,a,u){if(t.subtreeFlags&10256)for(t=t.child;t!==null;)gd(l,t,a,u),t=t.sibling}function gd(l,t,a,u){var e=t.flags;switch(t.tag){case 0:case 11:case 15:At(l,t,a,u),e&2048&&fe(9,t);break;case 1:At(l,t,a,u);break;case 3:At(l,t,a,u),e&2048&&(l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&wu(l)));break;case 12:if(e&2048){At(l,t,a,u),l=t.stateNode;try{var n=t.memoizedProps,f=n.id,i=n.onPostCommit;typeof i=="function"&&i(f,t.alternate===null?"mount":"update",l.passiveEffectDuration,-0)}catch(c){ul(t,t.return,c)}}else At(l,t,a,u);break;case 31:At(l,t,a,u);break;case 13:At(l,t,a,u);break;case 23:break;case 22:n=t.stateNode,f=t.alternate,t.memoizedState!==null?n._visibility&2?At(l,t,a,u):ce(l,t):n._visibility&2?At(l,t,a,u):(n._visibility|=2,gu(l,t,a,u,(t.subtreeFlags&10256)!==0||!1)),e&2048&&Ni(f,t);break;case 24:At(l,t,a,u),e&2048&&Ci(t.alternate,t);break;default:At(l,t,a,u)}}function gu(l,t,a,u,e){for(e=e&&((t.subtreeFlags&10256)!==0||!1),t=t.child;t!==null;){var n=l,f=t,i=a,c=u,v=f.flags;switch(f.tag){case 0:case 11:case 15:gu(n,f,i,c,e),fe(8,f);break;case 23:break;case 22:var S=f.stateNode;f.memoizedState!==null?S._visibility&2?gu(n,f,i,c,e):ce(n,f):(S._visibility|=2,gu(n,f,i,c,e)),e&&v&2048&&Ni(f.alternate,f);break;case 24:gu(n,f,i,c,e),e&&v&2048&&Ci(f.alternate,f);break;default:gu(n,f,i,c,e)}t=t.sibling}}function ce(l,t){if(t.subtreeFlags&10256)for(t=t.child;t!==null;){var a=l,u=t,e=u.flags;switch(u.tag){case 22:ce(a,u),e&2048&&Ni(u.alternate,u);break;case 24:ce(a,u),e&2048&&Ci(u.alternate,u);break;default:ce(a,u)}t=t.sibling}}var se=8192;function Su(l,t,a){if(l.subtreeFlags&se)for(l=l.child;l!==null;)Sd(l,t,a),l=l.sibling}function Sd(l,t,a){switch(l.tag){case 26:Su(l,t,a),l.flags&se&&l.memoizedState!==null&&um(a,pt,l.memoizedState,l.memoizedProps);break;case 5:Su(l,t,a);break;case 3:case 4:var u=pt;pt=Un(l.stateNode.containerInfo),Su(l,t,a),pt=u;break;case 22:l.memoizedState===null&&(u=l.alternate,u!==null&&u.memoizedState!==null?(u=se,se=16777216,Su(l,t,a),se=u):Su(l,t,a));break;default:Su(l,t,a)}}function rd(l){var t=l.alternate;if(t!==null&&(l=t.child,l!==null)){t.child=null;do t=l.sibling,l.sibling=null,l=t;while(l!==null)}}function de(l){var t=l.deletions;if((l.flags&16)!==0){if(t!==null)for(var a=0;a<t.length;a++){var u=t[a];xl=u,zd(u,l)}rd(l)}if(l.subtreeFlags&10256)for(l=l.child;l!==null;)bd(l),l=l.sibling}function bd(l){switch(l.tag){case 0:case 11:case 15:de(l),l.flags&2048&&da(9,l,l.return);break;case 3:de(l);break;case 12:de(l);break;case 22:var t=l.stateNode;l.memoizedState!==null&&t._visibility&2&&(l.return===null||l.return.tag!==13)?(t._visibility&=-3,gn(l)):de(l);break;default:de(l)}}function gn(l){var t=l.deletions;if((l.flags&16)!==0){if(t!==null)for(var a=0;a<t.length;a++){var u=t[a];xl=u,zd(u,l)}rd(l)}for(l=l.child;l!==null;){switch(t=l,t.tag){case 0:case 11:case 15:da(8,t,t.return),gn(t);break;case 22:a=t.stateNode,a._visibility&2&&(a._visibility&=-3,gn(t));break;default:gn(t)}l=l.sibling}}function zd(l,t){for(;xl!==null;){var a=xl;switch(a.tag){case 0:case 11:case 15:da(8,a,t);break;case 23:case 22:if(a.memoizedState!==null&&a.memoizedState.cachePool!==null){var u=a.memoizedState.cachePool.pool;u!=null&&u.refCount++}break;case 24:wu(a.memoizedState.cache)}if(u=a.child,u!==null)u.return=a,xl=u;else l:for(a=l;xl!==null;){u=xl;var e=u.sibling,n=u.return;if(dd(u),u===a){xl=null;break l}if(e!==null){e.return=n,xl=e;break l}xl=n}}}var rv={getCacheForType:function(l){var t=Nl(El),a=t.data.get(l);return a===void 0&&(a=l(),t.data.set(l,a)),a},cacheSignal:function(){return Nl(El).controller.signal}},bv=typeof WeakMap=="function"?WeakMap:Map,ll=0,dl=null,Z=null,K=0,al=0,it=null,oa=!1,ru=!1,Bi=!1,$t=0,gl=0,ya=0,Za=0,qi=0,ct=0,bu=0,oe=null,kl=null,ji=!1,Sn=0,Td=0,rn=1/0,bn=null,va=null,Ol=0,ma=null,zu=null,kt=0,Yi=0,Gi=null,Ed=null,ye=0,Xi=null;function st(){return(ll&2)!==0&&K!==0?K&-K:r.T!==null?Ji():Yc()}function pd(){if(ct===0)if((K&536870912)===0||W){var l=Me;Me<<=1,(Me&3932160)===0&&(Me=262144),ct=l}else ct=536870912;return l=nt.current,l!==null&&(l.flags|=32),ct}function Fl(l,t,a){(l===dl&&(al===2||al===9)||l.cancelPendingCommit!==null)&&(Tu(l,0),ha(l,K,ct,!1)),Nu(l,a),((ll&2)===0||l!==dl)&&(l===dl&&((ll&2)===0&&(Za|=a),gl===4&&ha(l,K,ct,!1)),Ht(l))}function Ad(l,t,a){if((ll&6)!==0)throw Error(h(327));var u=!a&&(t&127)===0&&(t&l.expiredLanes)===0||Ru(l,t),e=u?Ev(l,t):Zi(l,t,!0),n=u;do{if(e===0){ru&&!u&&ha(l,t,0,!1);break}else{if(a=l.current.alternate,n&&!zv(a)){e=Zi(l,t,!1),n=!1;continue}if(e===2){if(n=t,l.errorRecoveryDisabledLanes&n)var f=0;else f=l.pendingLanes&-536870913,f=f!==0?f:f&536870912?536870912:0;if(f!==0){t=f;l:{var i=l;e=oe;var c=i.current.memoizedState.isDehydrated;if(c&&(Tu(i,f).flags|=256),f=Zi(i,f,!1),f!==2){if(Bi&&!c){i.errorRecoveryDisabledLanes|=n,Za|=n,e=4;break l}n=kl,kl=e,n!==null&&(kl===null?kl=n:kl.push.apply(kl,n))}e=f}if(n=!1,e!==2)continue}}if(e===1){Tu(l,0),ha(l,t,0,!0);break}l:{switch(u=l,n=e,n){case 0:case 1:throw Error(h(345));case 4:if((t&4194048)!==t)break;case 6:ha(u,t,ct,!oa);break l;case 2:kl=null;break;case 3:case 5:break;default:throw Error(h(329))}if((t&62914560)===t&&(e=Sn+300-lt(),10<e)){if(ha(u,t,ct,!oa),De(u,0,!0)!==0)break l;kt=t,u.timeoutHandle=to(_d.bind(null,u,a,kl,bn,ji,t,ct,Za,bu,oa,n,"Throttled",-0,0),e);break l}_d(u,a,kl,bn,ji,t,ct,Za,bu,oa,n,null,-0,0)}}break}while(!0);Ht(l)}function _d(l,t,a,u,e,n,f,i,c,v,S,z,m,g){if(l.timeoutHandle=-1,z=t.subtreeFlags,z&8192||(z&16785408)===16785408){z={stylesheets:null,count:0,imgCount:0,imgBytes:0,suspenseyImages:[],waitingForImages:!0,waitingForViewTransition:!1,unsuspend:Bt},Sd(t,n,z);var M=(n&62914560)===n?Sn-lt():(n&4194048)===n?Td-lt():0;if(M=em(z,M),M!==null){kt=n,l.cancelPendingCommit=M(Nd.bind(null,l,t,n,a,u,e,f,i,c,S,z,null,m,g)),ha(l,n,f,!v);return}}Nd(l,t,n,a,u,e,f,i,c)}function zv(l){for(var t=l;;){var a=t.tag;if((a===0||a===11||a===15)&&t.flags&16384&&(a=t.updateQueue,a!==null&&(a=a.stores,a!==null)))for(var u=0;u<a.length;u++){var e=a[u],n=e.getSnapshot;e=e.value;try{if(!ut(n(),e))return!1}catch{return!1}}if(a=t.child,t.subtreeFlags&16384&&a!==null)a.return=t,t=a;else{if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return!0;t=t.return}t.sibling.return=t.return,t=t.sibling}}return!0}function ha(l,t,a,u){t&=~qi,t&=~Za,l.suspendedLanes|=t,l.pingedLanes&=~t,u&&(l.warmLanes|=t),u=l.expirationTimes;for(var e=t;0<e;){var n=31-at(e),f=1<<n;u[n]=-1,e&=~f}a!==0&&Bc(l,a,t)}function zn(){return(ll&6)===0?(ve(0),!1):!0}function Qi(){if(Z!==null){if(al===0)var l=Z.return;else l=Z,Gt=Na=null,ui(l),ou=null,$u=0,l=Z;for(;l!==null;)ad(l.alternate,l),l=l.return;Z=null}}function Tu(l,t){var a=l.timeoutHandle;a!==-1&&(l.timeoutHandle=-1,Xv(a)),a=l.cancelPendingCommit,a!==null&&(l.cancelPendingCommit=null,a()),kt=0,Qi(),dl=l,Z=a=jt(l.current,null),K=t,al=0,it=null,oa=!1,ru=Ru(l,t),Bi=!1,bu=ct=qi=Za=ya=gl=0,kl=oe=null,ji=!1,(t&8)!==0&&(t|=t&32);var u=l.entangledLanes;if(u!==0)for(l=l.entanglements,u&=t;0<u;){var e=31-at(u),n=1<<e;t|=l[e],u&=~n}return $t=t,Xe(),a}function Md(l,t){Y=null,r.H=ue,t===du||t===We?(t=Zs(),al=3):t===Kf?(t=Zs(),al=4):al=t===bi?8:t!==null&&typeof t=="object"&&typeof t.then=="function"?6:1,it=t,Z===null&&(gl=1,sn(l,mt(t,l.current)))}function Od(){var l=nt.current;return l===null?!0:(K&4194048)===K?rt===null:(K&62914560)===K||(K&536870912)!==0?l===rt:!1}function Dd(){var l=r.H;return r.H=ue,l===null?ue:l}function Ud(){var l=r.A;return r.A=rv,l}function Tn(){gl=4,oa||(K&4194048)!==K&&nt.current!==null||(ru=!0),(ya&134217727)===0&&(Za&134217727)===0||dl===null||ha(dl,K,ct,!1)}function Zi(l,t,a){var u=ll;ll|=2;var e=Dd(),n=Ud();(dl!==l||K!==t)&&(bn=null,Tu(l,t)),t=!1;var f=gl;l:do try{if(al!==0&&Z!==null){var i=Z,c=it;switch(al){case 8:Qi(),f=6;break l;case 3:case 2:case 9:case 6:nt.current===null&&(t=!0);var v=al;if(al=0,it=null,Eu(l,i,c,v),a&&ru){f=0;break l}break;default:v=al,al=0,it=null,Eu(l,i,c,v)}}Tv(),f=gl;break}catch(S){Md(l,S)}while(!0);return t&&l.shellSuspendCounter++,Gt=Na=null,ll=u,r.H=e,r.A=n,Z===null&&(dl=null,K=0,Xe()),f}function Tv(){for(;Z!==null;)xd(Z)}function Ev(l,t){var a=ll;ll|=2;var u=Dd(),e=Ud();dl!==l||K!==t?(bn=null,rn=lt()+500,Tu(l,t)):ru=Ru(l,t);l:do try{if(al!==0&&Z!==null){t=Z;var n=it;t:switch(al){case 1:al=0,it=null,Eu(l,t,n,1);break;case 2:case 9:if(Xs(n)){al=0,it=null,Hd(t);break}t=function(){al!==2&&al!==9||dl!==l||(al=7),Ht(l)},n.then(t,t);break l;case 3:al=7;break l;case 4:al=5;break l;case 7:Xs(n)?(al=0,it=null,Hd(t)):(al=0,it=null,Eu(l,t,n,7));break;case 5:var f=null;switch(Z.tag){case 26:f=Z.memoizedState;case 5:case 27:var i=Z;if(f?So(f):i.stateNode.complete){al=0,it=null;var c=i.sibling;if(c!==null)Z=c;else{var v=i.return;v!==null?(Z=v,En(v)):Z=null}break t}}al=0,it=null,Eu(l,t,n,5);break;case 6:al=0,it=null,Eu(l,t,n,6);break;case 8:Qi(),gl=6;break l;default:throw Error(h(462))}}pv();break}catch(S){Md(l,S)}while(!0);return Gt=Na=null,r.H=u,r.A=e,ll=a,Z!==null?0:(dl=null,K=0,Xe(),gl)}function pv(){for(;Z!==null&&!Jo();)xd(Z)}function xd(l){var t=ld(l.alternate,l,$t);l.memoizedProps=l.pendingProps,t===null?En(l):Z=t}function Hd(l){var t=l,a=t.alternate;switch(t.tag){case 15:case 0:t=W0(a,t,t.pendingProps,t.type,void 0,K);break;case 11:t=W0(a,t,t.pendingProps,t.type.render,t.ref,K);break;case 5:ui(t);default:ad(a,t),t=Z=Us(t,$t),t=ld(a,t,$t)}l.memoizedProps=l.pendingProps,t===null?En(l):Z=t}function Eu(l,t,a,u){Gt=Na=null,ui(t),ou=null,$u=0;var e=t.return;try{if(ov(l,e,t,a,K)){gl=1,sn(l,mt(a,l.current)),Z=null;return}}catch(n){if(e!==null)throw Z=e,n;gl=1,sn(l,mt(a,l.current)),Z=null;return}t.flags&32768?(W||u===1?l=!0:ru||(K&536870912)!==0?l=!1:(oa=l=!0,(u===2||u===9||u===3||u===6)&&(u=nt.current,u!==null&&u.tag===13&&(u.flags|=16384))),Rd(t,l)):En(t)}function En(l){var t=l;do{if((t.flags&32768)!==0){Rd(t,oa);return}l=t.return;var a=mv(t.alternate,t,$t);if(a!==null){Z=a;return}if(t=t.sibling,t!==null){Z=t;return}Z=t=l}while(t!==null);gl===0&&(gl=5)}function Rd(l,t){do{var a=hv(l.alternate,l);if(a!==null){a.flags&=32767,Z=a;return}if(a=l.return,a!==null&&(a.flags|=32768,a.subtreeFlags=0,a.deletions=null),!t&&(l=l.sibling,l!==null)){Z=l;return}Z=l=a}while(l!==null);gl=6,Z=null}function Nd(l,t,a,u,e,n,f,i,c){l.cancelPendingCommit=null;do pn();while(Ol!==0);if((ll&6)!==0)throw Error(h(327));if(t!==null){if(t===l.current)throw Error(h(177));if(n=t.lanes|t.childLanes,n|=xf,ay(l,a,n,f,i,c),l===dl&&(Z=dl=null,K=0),zu=t,ma=l,kt=a,Yi=n,Gi=e,Ed=u,(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?(l.callbackNode=null,l.callbackPriority=0,Ov(Ae,function(){return Yd(),null})):(l.callbackNode=null,l.callbackPriority=0),u=(t.flags&13878)!==0,(t.subtreeFlags&13878)!==0||u){u=r.T,r.T=null,e=A.p,A.p=2,f=ll,ll|=4;try{gv(l,t,a)}finally{ll=f,A.p=e,r.T=u}}Ol=1,Cd(),Bd(),qd()}}function Cd(){if(Ol===1){Ol=0;var l=ma,t=zu,a=(t.flags&13878)!==0;if((t.subtreeFlags&13878)!==0||a){a=r.T,r.T=null;var u=A.p;A.p=2;var e=ll;ll|=4;try{md(t,l);var n=lc,f=zs(l.containerInfo),i=n.focusedElem,c=n.selectionRange;if(f!==i&&i&&i.ownerDocument&&bs(i.ownerDocument.documentElement,i)){if(c!==null&&_f(i)){var v=c.start,S=c.end;if(S===void 0&&(S=v),"selectionStart"in i)i.selectionStart=v,i.selectionEnd=Math.min(S,i.value.length);else{var z=i.ownerDocument||document,m=z&&z.defaultView||window;if(m.getSelection){var g=m.getSelection(),M=i.textContent.length,N=Math.min(c.start,M),il=c.end===void 0?N:Math.min(c.end,M);!g.extend&&N>il&&(f=il,il=N,N=f);var o=rs(i,N),s=rs(i,il);if(o&&s&&(g.rangeCount!==1||g.anchorNode!==o.node||g.anchorOffset!==o.offset||g.focusNode!==s.node||g.focusOffset!==s.offset)){var y=z.createRange();y.setStart(o.node,o.offset),g.removeAllRanges(),N>il?(g.addRange(y),g.extend(s.node,s.offset)):(y.setEnd(s.node,s.offset),g.addRange(y))}}}}for(z=[],g=i;g=g.parentNode;)g.nodeType===1&&z.push({element:g,left:g.scrollLeft,top:g.scrollTop});for(typeof i.focus=="function"&&i.focus(),i=0;i<z.length;i++){var b=z[i];b.element.scrollLeft=b.left,b.element.scrollTop=b.top}}Bn=!!Pi,lc=Pi=null}finally{ll=e,A.p=u,r.T=a}}l.current=t,Ol=2}}function Bd(){if(Ol===2){Ol=0;var l=ma,t=zu,a=(t.flags&8772)!==0;if((t.subtreeFlags&8772)!==0||a){a=r.T,r.T=null;var u=A.p;A.p=2;var e=ll;ll|=4;try{sd(l,t.alternate,t)}finally{ll=e,A.p=u,r.T=a}}Ol=3}}function qd(){if(Ol===4||Ol===3){Ol=0,wo();var l=ma,t=zu,a=kt,u=Ed;(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?Ol=5:(Ol=0,zu=ma=null,jd(l,l.pendingLanes));var e=l.pendingLanes;if(e===0&&(va=null),nf(a),t=t.stateNode,tt&&typeof tt.onCommitFiberRoot=="function")try{tt.onCommitFiberRoot(Hu,t,void 0,(t.current.flags&128)===128)}catch{}if(u!==null){t=r.T,e=A.p,A.p=2,r.T=null;try{for(var n=l.onRecoverableError,f=0;f<u.length;f++){var i=u[f];n(i.value,{componentStack:i.stack})}}finally{r.T=t,A.p=e}}(kt&3)!==0&&pn(),Ht(l),e=l.pendingLanes,(a&261930)!==0&&(e&42)!==0?l===Xi?ye++:(ye=0,Xi=l):ye=0,ve(0)}}function jd(l,t){(l.pooledCacheLanes&=t)===0&&(t=l.pooledCache,t!=null&&(l.pooledCache=null,wu(t)))}function pn(){return Cd(),Bd(),qd(),Yd()}function Yd(){if(Ol!==5)return!1;var l=ma,t=Yi;Yi=0;var a=nf(kt),u=r.T,e=A.p;try{A.p=32>a?32:a,r.T=null,a=Gi,Gi=null;var n=ma,f=kt;if(Ol=0,zu=ma=null,kt=0,(ll&6)!==0)throw Error(h(331));var i=ll;if(ll|=4,bd(n.current),gd(n,n.current,f,a),ll=i,ve(0,!1),tt&&typeof tt.onPostCommitFiberRoot=="function")try{tt.onPostCommitFiberRoot(Hu,n)}catch{}return!0}finally{A.p=e,r.T=u,jd(l,t)}}function Gd(l,t,a){t=mt(a,t),t=ri(l.stateNode,t,2),l=ia(l,t,2),l!==null&&(Nu(l,2),Ht(l))}function ul(l,t,a){if(l.tag===3)Gd(l,l,a);else for(;t!==null;){if(t.tag===3){Gd(t,l,a);break}else if(t.tag===1){var u=t.stateNode;if(typeof t.type.getDerivedStateFromError=="function"||typeof u.componentDidCatch=="function"&&(va===null||!va.has(u))){l=mt(a,l),a=X0(2),u=ia(t,a,2),u!==null&&(Q0(a,u,t,l),Nu(u,2),Ht(u));break}}t=t.return}}function Vi(l,t,a){var u=l.pingCache;if(u===null){u=l.pingCache=new bv;var e=new Set;u.set(t,e)}else e=u.get(t),e===void 0&&(e=new Set,u.set(t,e));e.has(a)||(Bi=!0,e.add(a),l=Av.bind(null,l,t,a),t.then(l,l))}function Av(l,t,a){var u=l.pingCache;u!==null&&u.delete(t),l.pingedLanes|=l.suspendedLanes&a,l.warmLanes&=~a,dl===l&&(K&a)===a&&(gl===4||gl===3&&(K&62914560)===K&&300>lt()-Sn?(ll&2)===0&&Tu(l,0):qi|=a,bu===K&&(bu=0)),Ht(l)}function Xd(l,t){t===0&&(t=Cc()),l=xa(l,t),l!==null&&(Nu(l,t),Ht(l))}function _v(l){var t=l.memoizedState,a=0;t!==null&&(a=t.retryLane),Xd(l,a)}function Mv(l,t){var a=0;switch(l.tag){case 31:case 13:var u=l.stateNode,e=l.memoizedState;e!==null&&(a=e.retryLane);break;case 19:u=l.stateNode;break;case 22:u=l.stateNode._retryCache;break;default:throw Error(h(314))}u!==null&&u.delete(t),Xd(l,a)}function Ov(l,t){return tf(l,t)}var An=null,pu=null,Li=!1,_n=!1,Ki=!1,ga=0;function Ht(l){l!==pu&&l.next===null&&(pu===null?An=pu=l:pu=pu.next=l),_n=!0,Li||(Li=!0,Uv())}function ve(l,t){if(!Ki&&_n){Ki=!0;do for(var a=!1,u=An;u!==null;){if(l!==0){var e=u.pendingLanes;if(e===0)var n=0;else{var f=u.suspendedLanes,i=u.pingedLanes;n=(1<<31-at(42|l)+1)-1,n&=e&~(f&~i),n=n&201326741?n&201326741|1:n?n|2:0}n!==0&&(a=!0,Ld(u,n))}else n=K,n=De(u,u===dl?n:0,u.cancelPendingCommit!==null||u.timeoutHandle!==-1),(n&3)===0||Ru(u,n)||(a=!0,Ld(u,n));u=u.next}while(a);Ki=!1}}function Dv(){Qd()}function Qd(){_n=Li=!1;var l=0;ga!==0&&Gv()&&(l=ga);for(var t=lt(),a=null,u=An;u!==null;){var e=u.next,n=Zd(u,t);n===0?(u.next=null,a===null?An=e:a.next=e,e===null&&(pu=a)):(a=u,(l!==0||(n&3)!==0)&&(_n=!0)),u=e}Ol!==0&&Ol!==5||ve(l),ga!==0&&(ga=0)}function Zd(l,t){for(var a=l.suspendedLanes,u=l.pingedLanes,e=l.expirationTimes,n=l.pendingLanes&-62914561;0<n;){var f=31-at(n),i=1<<f,c=e[f];c===-1?((i&a)===0||(i&u)!==0)&&(e[f]=ty(i,t)):c<=t&&(l.expiredLanes|=i),n&=~i}if(t=dl,a=K,a=De(l,l===t?a:0,l.cancelPendingCommit!==null||l.timeoutHandle!==-1),u=l.callbackNode,a===0||l===t&&(al===2||al===9)||l.cancelPendingCommit!==null)return u!==null&&u!==null&&af(u),l.callbackNode=null,l.callbackPriority=0;if((a&3)===0||Ru(l,a)){if(t=a&-a,t===l.callbackPriority)return t;switch(u!==null&&af(u),nf(a)){case 2:case 8:a=Rc;break;case 32:a=Ae;break;case 268435456:a=Nc;break;default:a=Ae}return u=Vd.bind(null,l),a=tf(a,u),l.callbackPriority=t,l.callbackNode=a,t}return u!==null&&u!==null&&af(u),l.callbackPriority=2,l.callbackNode=null,2}function Vd(l,t){if(Ol!==0&&Ol!==5)return l.callbackNode=null,l.callbackPriority=0,null;var a=l.callbackNode;if(pn()&&l.callbackNode!==a)return null;var u=K;return u=De(l,l===dl?u:0,l.cancelPendingCommit!==null||l.timeoutHandle!==-1),u===0?null:(Ad(l,u,t),Zd(l,lt()),l.callbackNode!=null&&l.callbackNode===a?Vd.bind(null,l):null)}function Ld(l,t){if(pn())return null;Ad(l,t,!0)}function Uv(){Qv(function(){(ll&6)!==0?tf(Hc,Dv):Qd()})}function Ji(){if(ga===0){var l=cu;l===0&&(l=_e,_e<<=1,(_e&261888)===0&&(_e=256)),ga=l}return ga}function Kd(l){return l==null||typeof l=="symbol"||typeof l=="boolean"?null:typeof l=="function"?l:Re(""+l)}function Jd(l,t){var a=t.ownerDocument.createElement("input");return a.name=t.name,a.value=t.value,l.id&&a.setAttribute("form",l.id),t.parentNode.insertBefore(a,t),l=new FormData(l),a.parentNode.removeChild(a),l}function xv(l,t,a,u,e){if(t==="submit"&&a&&a.stateNode===e){var n=Kd((e[Kl]||null).action),f=u.submitter;f&&(t=(t=f[Kl]||null)?Kd(t.formAction):f.getAttribute("formAction"),t!==null&&(n=t,f=null));var i=new qe("action","action",null,u,e);l.push({event:i,listeners:[{instance:null,listener:function(){if(u.defaultPrevented){if(ga!==0){var c=f?Jd(e,f):new FormData(e);yi(a,{pending:!0,data:c,method:e.method,action:n},null,c)}}else typeof n=="function"&&(i.preventDefault(),c=f?Jd(e,f):new FormData(e),yi(a,{pending:!0,data:c,method:e.method,action:n},n,c))},currentTarget:e}]})}}for(var wi=0;wi<Uf.length;wi++){var Wi=Uf[wi],Hv=Wi.toLowerCase(),Rv=Wi[0].toUpperCase()+Wi.slice(1);Et(Hv,"on"+Rv)}Et(ps,"onAnimationEnd"),Et(As,"onAnimationIteration"),Et(_s,"onAnimationStart"),Et("dblclick","onDoubleClick"),Et("focusin","onFocus"),Et("focusout","onBlur"),Et(Wy,"onTransitionRun"),Et($y,"onTransitionStart"),Et(ky,"onTransitionCancel"),Et(Ms,"onTransitionEnd"),Wa("onMouseEnter",["mouseout","mouseover"]),Wa("onMouseLeave",["mouseout","mouseover"]),Wa("onPointerEnter",["pointerout","pointerover"]),Wa("onPointerLeave",["pointerout","pointerover"]),Ma("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),Ma("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),Ma("onBeforeInput",["compositionend","keypress","textInput","paste"]),Ma("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),Ma("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),Ma("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var me="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),Nv=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(me));function wd(l,t){t=(t&4)!==0;for(var a=0;a<l.length;a++){var u=l[a],e=u.event;u=u.listeners;l:{var n=void 0;if(t)for(var f=u.length-1;0<=f;f--){var i=u[f],c=i.instance,v=i.currentTarget;if(i=i.listener,c!==n&&e.isPropagationStopped())break l;n=i,e.currentTarget=v;try{n(e)}catch(S){Ge(S)}e.currentTarget=null,n=c}else for(f=0;f<u.length;f++){if(i=u[f],c=i.instance,v=i.currentTarget,i=i.listener,c!==n&&e.isPropagationStopped())break l;n=i,e.currentTarget=v;try{n(e)}catch(S){Ge(S)}e.currentTarget=null,n=c}}}}function V(l,t){var a=t[ff];a===void 0&&(a=t[ff]=new Set);var u=l+"__bubble";a.has(u)||(Wd(t,l,2,!1),a.add(u))}function $i(l,t,a){var u=0;t&&(u|=4),Wd(a,l,u,t)}var Mn="_reactListening"+Math.random().toString(36).slice(2);function ki(l){if(!l[Mn]){l[Mn]=!0,Qc.forEach(function(a){a!=="selectionchange"&&(Nv.has(a)||$i(a,!1,l),$i(a,!0,l))});var t=l.nodeType===9?l:l.ownerDocument;t===null||t[Mn]||(t[Mn]=!0,$i("selectionchange",!1,t))}}function Wd(l,t,a,u){switch(Ao(t)){case 2:var e=im;break;case 8:e=cm;break;default:e=oc}a=e.bind(null,t,a,l),e=void 0,!gf||t!=="touchstart"&&t!=="touchmove"&&t!=="wheel"||(e=!0),u?e!==void 0?l.addEventListener(t,a,{capture:!0,passive:e}):l.addEventListener(t,a,!0):e!==void 0?l.addEventListener(t,a,{passive:e}):l.addEventListener(t,a,!1)}function Fi(l,t,a,u,e){var n=u;if((t&1)===0&&(t&2)===0&&u!==null)l:for(;;){if(u===null)return;var f=u.tag;if(f===3||f===4){var i=u.stateNode.containerInfo;if(i===e)break;if(f===4)for(f=u.return;f!==null;){var c=f.tag;if((c===3||c===4)&&f.stateNode.containerInfo===e)return;f=f.return}for(;i!==null;){if(f=Ka(i),f===null)return;if(c=f.tag,c===5||c===6||c===26||c===27){u=n=f;continue l}i=i.parentNode}}u=u.return}Pc(function(){var v=n,S=mf(a),z=[];l:{var m=Os.get(l);if(m!==void 0){var g=qe,M=l;switch(l){case"keypress":if(Ce(a)===0)break l;case"keydown":case"keyup":g=My;break;case"focusin":M="focus",g=zf;break;case"focusout":M="blur",g=zf;break;case"beforeblur":case"afterblur":g=zf;break;case"click":if(a.button===2)break l;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":g=as;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":g=my;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":g=Uy;break;case ps:case As:case _s:g=Sy;break;case Ms:g=Hy;break;case"scroll":case"scrollend":g=yy;break;case"wheel":g=Ny;break;case"copy":case"cut":case"paste":g=by;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":g=es;break;case"toggle":case"beforetoggle":g=By}var N=(t&4)!==0,il=!N&&(l==="scroll"||l==="scrollend"),o=N?m!==null?m+"Capture":null:m;N=[];for(var s=v,y;s!==null;){var b=s;if(y=b.stateNode,b=b.tag,b!==5&&b!==26&&b!==27||y===null||o===null||(b=qu(s,o),b!=null&&N.push(he(s,b,y))),il)break;s=s.return}0<N.length&&(m=new g(m,M,null,a,S),z.push({event:m,listeners:N}))}}if((t&7)===0){l:{if(m=l==="mouseover"||l==="pointerover",g=l==="mouseout"||l==="pointerout",m&&a!==vf&&(M=a.relatedTarget||a.fromElement)&&(Ka(M)||M[La]))break l;if((g||m)&&(m=S.window===S?S:(m=S.ownerDocument)?m.defaultView||m.parentWindow:window,g?(M=a.relatedTarget||a.toElement,g=v,M=M?Ka(M):null,M!==null&&(il=Sl(M),N=M.tag,M!==il||N!==5&&N!==27&&N!==6)&&(M=null)):(g=null,M=v),g!==M)){if(N=as,b="onMouseLeave",o="onMouseEnter",s="mouse",(l==="pointerout"||l==="pointerover")&&(N=es,b="onPointerLeave",o="onPointerEnter",s="pointer"),il=g==null?m:Bu(g),y=M==null?m:Bu(M),m=new N(b,s+"leave",g,a,S),m.target=il,m.relatedTarget=y,b=null,Ka(S)===v&&(N=new N(o,s+"enter",M,a,S),N.target=y,N.relatedTarget=il,b=N),il=b,g&&M)t:{for(N=Cv,o=g,s=M,y=0,b=o;b;b=N(b))y++;b=0;for(var x=s;x;x=N(x))b++;for(;0<y-b;)o=N(o),y--;for(;0<b-y;)s=N(s),b--;for(;y--;){if(o===s||s!==null&&o===s.alternate){N=o;break t}o=N(o),s=N(s)}N=null}else N=null;g!==null&&$d(z,m,g,N,!1),M!==null&&il!==null&&$d(z,il,M,N,!0)}}l:{if(m=v?Bu(v):window,g=m.nodeName&&m.nodeName.toLowerCase(),g==="select"||g==="input"&&m.type==="file")var F=ys;else if(ds(m))if(vs)F=Ky;else{F=Vy;var D=Zy}else g=m.nodeName,!g||g.toLowerCase()!=="input"||m.type!=="checkbox"&&m.type!=="radio"?v&&yf(v.elementType)&&(F=ys):F=Ly;if(F&&(F=F(l,v))){os(z,F,a,S);break l}D&&D(l,m,v),l==="focusout"&&v&&m.type==="number"&&v.memoizedProps.value!=null&&of(m,"number",m.value)}switch(D=v?Bu(v):window,l){case"focusin":(ds(D)||D.contentEditable==="true")&&(lu=D,Mf=v,Lu=null);break;case"focusout":Lu=Mf=lu=null;break;case"mousedown":Of=!0;break;case"contextmenu":case"mouseup":case"dragend":Of=!1,Ts(z,a,S);break;case"selectionchange":if(wy)break;case"keydown":case"keyup":Ts(z,a,S)}var G;if(Ef)l:{switch(l){case"compositionstart":var J="onCompositionStart";break l;case"compositionend":J="onCompositionEnd";break l;case"compositionupdate":J="onCompositionUpdate";break l}J=void 0}else Pa?cs(l,a)&&(J="onCompositionEnd"):l==="keydown"&&a.keyCode===229&&(J="onCompositionStart");J&&(ns&&a.locale!=="ko"&&(Pa||J!=="onCompositionStart"?J==="onCompositionEnd"&&Pa&&(G=ls()):(la=S,Sf="value"in la?la.value:la.textContent,Pa=!0)),D=On(v,J),0<D.length&&(J=new us(J,l,null,a,S),z.push({event:J,listeners:D}),G?J.data=G:(G=ss(a),G!==null&&(J.data=G)))),(G=jy?Yy(l,a):Gy(l,a))&&(J=On(v,"onBeforeInput"),0<J.length&&(D=new us("onBeforeInput","beforeinput",null,a,S),z.push({event:D,listeners:J}),D.data=G)),xv(z,l,v,a,S)}wd(z,t)})}function he(l,t,a){return{instance:l,listener:t,currentTarget:a}}function On(l,t){for(var a=t+"Capture",u=[];l!==null;){var e=l,n=e.stateNode;if(e=e.tag,e!==5&&e!==26&&e!==27||n===null||(e=qu(l,a),e!=null&&u.unshift(he(l,e,n)),e=qu(l,t),e!=null&&u.push(he(l,e,n))),l.tag===3)return u;l=l.return}return[]}function Cv(l){if(l===null)return null;do l=l.return;while(l&&l.tag!==5&&l.tag!==27);return l||null}function $d(l,t,a,u,e){for(var n=t._reactName,f=[];a!==null&&a!==u;){var i=a,c=i.alternate,v=i.stateNode;if(i=i.tag,c!==null&&c===u)break;i!==5&&i!==26&&i!==27||v===null||(c=v,e?(v=qu(a,n),v!=null&&f.unshift(he(a,v,c))):e||(v=qu(a,n),v!=null&&f.push(he(a,v,c)))),a=a.return}f.length!==0&&l.push({event:t,listeners:f})}var Bv=/\r\n?/g,qv=/\u0000|\uFFFD/g;function kd(l){return(typeof l=="string"?l:""+l).replace(Bv,`
`).replace(qv,"")}function Fd(l,t){return t=kd(t),kd(l)===t}function fl(l,t,a,u,e,n){switch(a){case"children":typeof u=="string"?t==="body"||t==="textarea"&&u===""||ka(l,u):(typeof u=="number"||typeof u=="bigint")&&t!=="body"&&ka(l,""+u);break;case"className":xe(l,"class",u);break;case"tabIndex":xe(l,"tabindex",u);break;case"dir":case"role":case"viewBox":case"width":case"height":xe(l,a,u);break;case"style":Fc(l,u,n);break;case"data":if(t!=="object"){xe(l,"data",u);break}case"src":case"href":if(u===""&&(t!=="a"||a!=="href")){l.removeAttribute(a);break}if(u==null||typeof u=="function"||typeof u=="symbol"||typeof u=="boolean"){l.removeAttribute(a);break}u=Re(""+u),l.setAttribute(a,u);break;case"action":case"formAction":if(typeof u=="function"){l.setAttribute(a,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof n=="function"&&(a==="formAction"?(t!=="input"&&fl(l,t,"name",e.name,e,null),fl(l,t,"formEncType",e.formEncType,e,null),fl(l,t,"formMethod",e.formMethod,e,null),fl(l,t,"formTarget",e.formTarget,e,null)):(fl(l,t,"encType",e.encType,e,null),fl(l,t,"method",e.method,e,null),fl(l,t,"target",e.target,e,null)));if(u==null||typeof u=="symbol"||typeof u=="boolean"){l.removeAttribute(a);break}u=Re(""+u),l.setAttribute(a,u);break;case"onClick":u!=null&&(l.onclick=Bt);break;case"onScroll":u!=null&&V("scroll",l);break;case"onScrollEnd":u!=null&&V("scrollend",l);break;case"dangerouslySetInnerHTML":if(u!=null){if(typeof u!="object"||!("__html"in u))throw Error(h(61));if(a=u.__html,a!=null){if(e.children!=null)throw Error(h(60));l.innerHTML=a}}break;case"multiple":l.multiple=u&&typeof u!="function"&&typeof u!="symbol";break;case"muted":l.muted=u&&typeof u!="function"&&typeof u!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(u==null||typeof u=="function"||typeof u=="boolean"||typeof u=="symbol"){l.removeAttribute("xlink:href");break}a=Re(""+u),l.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",a);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":u!=null&&typeof u!="function"&&typeof u!="symbol"?l.setAttribute(a,""+u):l.removeAttribute(a);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":u&&typeof u!="function"&&typeof u!="symbol"?l.setAttribute(a,""):l.removeAttribute(a);break;case"capture":case"download":u===!0?l.setAttribute(a,""):u!==!1&&u!=null&&typeof u!="function"&&typeof u!="symbol"?l.setAttribute(a,u):l.removeAttribute(a);break;case"cols":case"rows":case"size":case"span":u!=null&&typeof u!="function"&&typeof u!="symbol"&&!isNaN(u)&&1<=u?l.setAttribute(a,u):l.removeAttribute(a);break;case"rowSpan":case"start":u==null||typeof u=="function"||typeof u=="symbol"||isNaN(u)?l.removeAttribute(a):l.setAttribute(a,u);break;case"popover":V("beforetoggle",l),V("toggle",l),Ue(l,"popover",u);break;case"xlinkActuate":Ct(l,"http://www.w3.org/1999/xlink","xlink:actuate",u);break;case"xlinkArcrole":Ct(l,"http://www.w3.org/1999/xlink","xlink:arcrole",u);break;case"xlinkRole":Ct(l,"http://www.w3.org/1999/xlink","xlink:role",u);break;case"xlinkShow":Ct(l,"http://www.w3.org/1999/xlink","xlink:show",u);break;case"xlinkTitle":Ct(l,"http://www.w3.org/1999/xlink","xlink:title",u);break;case"xlinkType":Ct(l,"http://www.w3.org/1999/xlink","xlink:type",u);break;case"xmlBase":Ct(l,"http://www.w3.org/XML/1998/namespace","xml:base",u);break;case"xmlLang":Ct(l,"http://www.w3.org/XML/1998/namespace","xml:lang",u);break;case"xmlSpace":Ct(l,"http://www.w3.org/XML/1998/namespace","xml:space",u);break;case"is":Ue(l,"is",u);break;case"innerText":case"textContent":break;default:(!(2<a.length)||a[0]!=="o"&&a[0]!=="O"||a[1]!=="n"&&a[1]!=="N")&&(a=dy.get(a)||a,Ue(l,a,u))}}function Ii(l,t,a,u,e,n){switch(a){case"style":Fc(l,u,n);break;case"dangerouslySetInnerHTML":if(u!=null){if(typeof u!="object"||!("__html"in u))throw Error(h(61));if(a=u.__html,a!=null){if(e.children!=null)throw Error(h(60));l.innerHTML=a}}break;case"children":typeof u=="string"?ka(l,u):(typeof u=="number"||typeof u=="bigint")&&ka(l,""+u);break;case"onScroll":u!=null&&V("scroll",l);break;case"onScrollEnd":u!=null&&V("scrollend",l);break;case"onClick":u!=null&&(l.onclick=Bt);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!Zc.hasOwnProperty(a))l:{if(a[0]==="o"&&a[1]==="n"&&(e=a.endsWith("Capture"),t=a.slice(2,e?a.length-7:void 0),n=l[Kl]||null,n=n!=null?n[a]:null,typeof n=="function"&&l.removeEventListener(t,n,e),typeof u=="function")){typeof n!="function"&&n!==null&&(a in l?l[a]=null:l.hasAttribute(a)&&l.removeAttribute(a)),l.addEventListener(t,u,e);break l}a in l?l[a]=u:u===!0?l.setAttribute(a,""):Ue(l,a,u)}}}function Bl(l,t,a){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":V("error",l),V("load",l);var u=!1,e=!1,n;for(n in a)if(a.hasOwnProperty(n)){var f=a[n];if(f!=null)switch(n){case"src":u=!0;break;case"srcSet":e=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(h(137,t));default:fl(l,t,n,f,a,null)}}e&&fl(l,t,"srcSet",a.srcSet,a,null),u&&fl(l,t,"src",a.src,a,null);return;case"input":V("invalid",l);var i=n=f=e=null,c=null,v=null;for(u in a)if(a.hasOwnProperty(u)){var S=a[u];if(S!=null)switch(u){case"name":e=S;break;case"type":f=S;break;case"checked":c=S;break;case"defaultChecked":v=S;break;case"value":n=S;break;case"defaultValue":i=S;break;case"children":case"dangerouslySetInnerHTML":if(S!=null)throw Error(h(137,t));break;default:fl(l,t,u,S,a,null)}}wc(l,n,i,c,v,f,e,!1);return;case"select":V("invalid",l),u=f=n=null;for(e in a)if(a.hasOwnProperty(e)&&(i=a[e],i!=null))switch(e){case"value":n=i;break;case"defaultValue":f=i;break;case"multiple":u=i;default:fl(l,t,e,i,a,null)}t=n,a=f,l.multiple=!!u,t!=null?$a(l,!!u,t,!1):a!=null&&$a(l,!!u,a,!0);return;case"textarea":V("invalid",l),n=e=u=null;for(f in a)if(a.hasOwnProperty(f)&&(i=a[f],i!=null))switch(f){case"value":u=i;break;case"defaultValue":e=i;break;case"children":n=i;break;case"dangerouslySetInnerHTML":if(i!=null)throw Error(h(91));break;default:fl(l,t,f,i,a,null)}$c(l,u,e,n);return;case"option":for(c in a)if(a.hasOwnProperty(c)&&(u=a[c],u!=null))switch(c){case"selected":l.selected=u&&typeof u!="function"&&typeof u!="symbol";break;default:fl(l,t,c,u,a,null)}return;case"dialog":V("beforetoggle",l),V("toggle",l),V("cancel",l),V("close",l);break;case"iframe":case"object":V("load",l);break;case"video":case"audio":for(u=0;u<me.length;u++)V(me[u],l);break;case"image":V("error",l),V("load",l);break;case"details":V("toggle",l);break;case"embed":case"source":case"link":V("error",l),V("load",l);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(v in a)if(a.hasOwnProperty(v)&&(u=a[v],u!=null))switch(v){case"children":case"dangerouslySetInnerHTML":throw Error(h(137,t));default:fl(l,t,v,u,a,null)}return;default:if(yf(t)){for(S in a)a.hasOwnProperty(S)&&(u=a[S],u!==void 0&&Ii(l,t,S,u,a,void 0));return}}for(i in a)a.hasOwnProperty(i)&&(u=a[i],u!=null&&fl(l,t,i,u,a,null))}function jv(l,t,a,u){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var e=null,n=null,f=null,i=null,c=null,v=null,S=null;for(g in a){var z=a[g];if(a.hasOwnProperty(g)&&z!=null)switch(g){case"checked":break;case"value":break;case"defaultValue":c=z;default:u.hasOwnProperty(g)||fl(l,t,g,null,u,z)}}for(var m in u){var g=u[m];if(z=a[m],u.hasOwnProperty(m)&&(g!=null||z!=null))switch(m){case"type":n=g;break;case"name":e=g;break;case"checked":v=g;break;case"defaultChecked":S=g;break;case"value":f=g;break;case"defaultValue":i=g;break;case"children":case"dangerouslySetInnerHTML":if(g!=null)throw Error(h(137,t));break;default:g!==z&&fl(l,t,m,g,u,z)}}df(l,f,i,c,v,S,n,e);return;case"select":g=f=i=m=null;for(n in a)if(c=a[n],a.hasOwnProperty(n)&&c!=null)switch(n){case"value":break;case"multiple":g=c;default:u.hasOwnProperty(n)||fl(l,t,n,null,u,c)}for(e in u)if(n=u[e],c=a[e],u.hasOwnProperty(e)&&(n!=null||c!=null))switch(e){case"value":m=n;break;case"defaultValue":i=n;break;case"multiple":f=n;default:n!==c&&fl(l,t,e,n,u,c)}t=i,a=f,u=g,m!=null?$a(l,!!a,m,!1):!!u!=!!a&&(t!=null?$a(l,!!a,t,!0):$a(l,!!a,a?[]:"",!1));return;case"textarea":g=m=null;for(i in a)if(e=a[i],a.hasOwnProperty(i)&&e!=null&&!u.hasOwnProperty(i))switch(i){case"value":break;case"children":break;default:fl(l,t,i,null,u,e)}for(f in u)if(e=u[f],n=a[f],u.hasOwnProperty(f)&&(e!=null||n!=null))switch(f){case"value":m=e;break;case"defaultValue":g=e;break;case"children":break;case"dangerouslySetInnerHTML":if(e!=null)throw Error(h(91));break;default:e!==n&&fl(l,t,f,e,u,n)}Wc(l,m,g);return;case"option":for(var M in a)if(m=a[M],a.hasOwnProperty(M)&&m!=null&&!u.hasOwnProperty(M))switch(M){case"selected":l.selected=!1;break;default:fl(l,t,M,null,u,m)}for(c in u)if(m=u[c],g=a[c],u.hasOwnProperty(c)&&m!==g&&(m!=null||g!=null))switch(c){case"selected":l.selected=m&&typeof m!="function"&&typeof m!="symbol";break;default:fl(l,t,c,m,u,g)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var N in a)m=a[N],a.hasOwnProperty(N)&&m!=null&&!u.hasOwnProperty(N)&&fl(l,t,N,null,u,m);for(v in u)if(m=u[v],g=a[v],u.hasOwnProperty(v)&&m!==g&&(m!=null||g!=null))switch(v){case"children":case"dangerouslySetInnerHTML":if(m!=null)throw Error(h(137,t));break;default:fl(l,t,v,m,u,g)}return;default:if(yf(t)){for(var il in a)m=a[il],a.hasOwnProperty(il)&&m!==void 0&&!u.hasOwnProperty(il)&&Ii(l,t,il,void 0,u,m);for(S in u)m=u[S],g=a[S],!u.hasOwnProperty(S)||m===g||m===void 0&&g===void 0||Ii(l,t,S,m,u,g);return}}for(var o in a)m=a[o],a.hasOwnProperty(o)&&m!=null&&!u.hasOwnProperty(o)&&fl(l,t,o,null,u,m);for(z in u)m=u[z],g=a[z],!u.hasOwnProperty(z)||m===g||m==null&&g==null||fl(l,t,z,m,u,g)}function Id(l){switch(l){case"css":case"script":case"font":case"img":case"image":case"input":case"link":return!0;default:return!1}}function Yv(){if(typeof performance.getEntriesByType=="function"){for(var l=0,t=0,a=performance.getEntriesByType("resource"),u=0;u<a.length;u++){var e=a[u],n=e.transferSize,f=e.initiatorType,i=e.duration;if(n&&i&&Id(f)){for(f=0,i=e.responseEnd,u+=1;u<a.length;u++){var c=a[u],v=c.startTime;if(v>i)break;var S=c.transferSize,z=c.initiatorType;S&&Id(z)&&(c=c.responseEnd,f+=S*(c<i?1:(i-v)/(c-v)))}if(--u,t+=8*(n+f)/(e.duration/1e3),l++,10<l)break}}if(0<l)return t/l/1e6}return navigator.connection&&(l=navigator.connection.downlink,typeof l=="number")?l:5}var Pi=null,lc=null;function Dn(l){return l.nodeType===9?l:l.ownerDocument}function Pd(l){switch(l){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function lo(l,t){if(l===0)switch(t){case"svg":return 1;case"math":return 2;default:return 0}return l===1&&t==="foreignObject"?0:l}function tc(l,t){return l==="textarea"||l==="noscript"||typeof t.children=="string"||typeof t.children=="number"||typeof t.children=="bigint"||typeof t.dangerouslySetInnerHTML=="object"&&t.dangerouslySetInnerHTML!==null&&t.dangerouslySetInnerHTML.__html!=null}var ac=null;function Gv(){var l=window.event;return l&&l.type==="popstate"?l===ac?!1:(ac=l,!0):(ac=null,!1)}var to=typeof setTimeout=="function"?setTimeout:void 0,Xv=typeof clearTimeout=="function"?clearTimeout:void 0,ao=typeof Promise=="function"?Promise:void 0,Qv=typeof queueMicrotask=="function"?queueMicrotask:typeof ao<"u"?function(l){return ao.resolve(null).then(l).catch(Zv)}:to;function Zv(l){setTimeout(function(){throw l})}function Sa(l){return l==="head"}function uo(l,t){var a=t,u=0;do{var e=a.nextSibling;if(l.removeChild(a),e&&e.nodeType===8)if(a=e.data,a==="/$"||a==="/&"){if(u===0){l.removeChild(e),Ou(t);return}u--}else if(a==="$"||a==="$?"||a==="$~"||a==="$!"||a==="&")u++;else if(a==="html")ge(l.ownerDocument.documentElement);else if(a==="head"){a=l.ownerDocument.head,ge(a);for(var n=a.firstChild;n;){var f=n.nextSibling,i=n.nodeName;n[Cu]||i==="SCRIPT"||i==="STYLE"||i==="LINK"&&n.rel.toLowerCase()==="stylesheet"||a.removeChild(n),n=f}}else a==="body"&&ge(l.ownerDocument.body);a=e}while(a);Ou(t)}function eo(l,t){var a=l;l=0;do{var u=a.nextSibling;if(a.nodeType===1?t?(a._stashedDisplay=a.style.display,a.style.display="none"):(a.style.display=a._stashedDisplay||"",a.getAttribute("style")===""&&a.removeAttribute("style")):a.nodeType===3&&(t?(a._stashedText=a.nodeValue,a.nodeValue=""):a.nodeValue=a._stashedText||""),u&&u.nodeType===8)if(a=u.data,a==="/$"){if(l===0)break;l--}else a!=="$"&&a!=="$?"&&a!=="$~"&&a!=="$!"||l++;a=u}while(a)}function uc(l){var t=l.firstChild;for(t&&t.nodeType===10&&(t=t.nextSibling);t;){var a=t;switch(t=t.nextSibling,a.nodeName){case"HTML":case"HEAD":case"BODY":uc(a),cf(a);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(a.rel.toLowerCase()==="stylesheet")continue}l.removeChild(a)}}function Vv(l,t,a,u){for(;l.nodeType===1;){var e=a;if(l.nodeName.toLowerCase()!==t.toLowerCase()){if(!u&&(l.nodeName!=="INPUT"||l.type!=="hidden"))break}else if(u){if(!l[Cu])switch(t){case"meta":if(!l.hasAttribute("itemprop"))break;return l;case"link":if(n=l.getAttribute("rel"),n==="stylesheet"&&l.hasAttribute("data-precedence"))break;if(n!==e.rel||l.getAttribute("href")!==(e.href==null||e.href===""?null:e.href)||l.getAttribute("crossorigin")!==(e.crossOrigin==null?null:e.crossOrigin)||l.getAttribute("title")!==(e.title==null?null:e.title))break;return l;case"style":if(l.hasAttribute("data-precedence"))break;return l;case"script":if(n=l.getAttribute("src"),(n!==(e.src==null?null:e.src)||l.getAttribute("type")!==(e.type==null?null:e.type)||l.getAttribute("crossorigin")!==(e.crossOrigin==null?null:e.crossOrigin))&&n&&l.hasAttribute("async")&&!l.hasAttribute("itemprop"))break;return l;default:return l}}else if(t==="input"&&l.type==="hidden"){var n=e.name==null?null:""+e.name;if(e.type==="hidden"&&l.getAttribute("name")===n)return l}else return l;if(l=bt(l.nextSibling),l===null)break}return null}function Lv(l,t,a){if(t==="")return null;for(;l.nodeType!==3;)if((l.nodeType!==1||l.nodeName!=="INPUT"||l.type!=="hidden")&&!a||(l=bt(l.nextSibling),l===null))return null;return l}function no(l,t){for(;l.nodeType!==8;)if((l.nodeType!==1||l.nodeName!=="INPUT"||l.type!=="hidden")&&!t||(l=bt(l.nextSibling),l===null))return null;return l}function ec(l){return l.data==="$?"||l.data==="$~"}function nc(l){return l.data==="$!"||l.data==="$?"&&l.ownerDocument.readyState!=="loading"}function Kv(l,t){var a=l.ownerDocument;if(l.data==="$~")l._reactRetry=t;else if(l.data!=="$?"||a.readyState!=="loading")t();else{var u=function(){t(),a.removeEventListener("DOMContentLoaded",u)};a.addEventListener("DOMContentLoaded",u),l._reactRetry=u}}function bt(l){for(;l!=null;l=l.nextSibling){var t=l.nodeType;if(t===1||t===3)break;if(t===8){if(t=l.data,t==="$"||t==="$!"||t==="$?"||t==="$~"||t==="&"||t==="F!"||t==="F")break;if(t==="/$"||t==="/&")return null}}return l}var fc=null;function fo(l){l=l.nextSibling;for(var t=0;l;){if(l.nodeType===8){var a=l.data;if(a==="/$"||a==="/&"){if(t===0)return bt(l.nextSibling);t--}else a!=="$"&&a!=="$!"&&a!=="$?"&&a!=="$~"&&a!=="&"||t++}l=l.nextSibling}return null}function io(l){l=l.previousSibling;for(var t=0;l;){if(l.nodeType===8){var a=l.data;if(a==="$"||a==="$!"||a==="$?"||a==="$~"||a==="&"){if(t===0)return l;t--}else a!=="/$"&&a!=="/&"||t++}l=l.previousSibling}return null}function co(l,t,a){switch(t=Dn(a),l){case"html":if(l=t.documentElement,!l)throw Error(h(452));return l;case"head":if(l=t.head,!l)throw Error(h(453));return l;case"body":if(l=t.body,!l)throw Error(h(454));return l;default:throw Error(h(451))}}function ge(l){for(var t=l.attributes;t.length;)l.removeAttributeNode(t[0]);cf(l)}var zt=new Map,so=new Set;function Un(l){return typeof l.getRootNode=="function"?l.getRootNode():l.nodeType===9?l:l.ownerDocument}var Ft=A.d;A.d={f:Jv,r:wv,D:Wv,C:$v,L:kv,m:Fv,X:Pv,S:Iv,M:lm};function Jv(){var l=Ft.f(),t=zn();return l||t}function wv(l){var t=Ja(l);t!==null&&t.tag===5&&t.type==="form"?M0(t):Ft.r(l)}var Au=typeof document>"u"?null:document;function oo(l,t,a){var u=Au;if(u&&typeof t=="string"&&t){var e=yt(t);e='link[rel="'+l+'"][href="'+e+'"]',typeof a=="string"&&(e+='[crossorigin="'+a+'"]'),so.has(e)||(so.add(e),l={rel:l,crossOrigin:a,href:t},u.querySelector(e)===null&&(t=u.createElement("link"),Bl(t,"link",l),Ul(t),u.head.appendChild(t)))}}function Wv(l){Ft.D(l),oo("dns-prefetch",l,null)}function $v(l,t){Ft.C(l,t),oo("preconnect",l,t)}function kv(l,t,a){Ft.L(l,t,a);var u=Au;if(u&&l&&t){var e='link[rel="preload"][as="'+yt(t)+'"]';t==="image"&&a&&a.imageSrcSet?(e+='[imagesrcset="'+yt(a.imageSrcSet)+'"]',typeof a.imageSizes=="string"&&(e+='[imagesizes="'+yt(a.imageSizes)+'"]')):e+='[href="'+yt(l)+'"]';var n=e;switch(t){case"style":n=_u(l);break;case"script":n=Mu(l)}zt.has(n)||(l=R({rel:"preload",href:t==="image"&&a&&a.imageSrcSet?void 0:l,as:t},a),zt.set(n,l),u.querySelector(e)!==null||t==="style"&&u.querySelector(Se(n))||t==="script"&&u.querySelector(re(n))||(t=u.createElement("link"),Bl(t,"link",l),Ul(t),u.head.appendChild(t)))}}function Fv(l,t){Ft.m(l,t);var a=Au;if(a&&l){var u=t&&typeof t.as=="string"?t.as:"script",e='link[rel="modulepreload"][as="'+yt(u)+'"][href="'+yt(l)+'"]',n=e;switch(u){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":n=Mu(l)}if(!zt.has(n)&&(l=R({rel:"modulepreload",href:l},t),zt.set(n,l),a.querySelector(e)===null)){switch(u){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(a.querySelector(re(n)))return}u=a.createElement("link"),Bl(u,"link",l),Ul(u),a.head.appendChild(u)}}}function Iv(l,t,a){Ft.S(l,t,a);var u=Au;if(u&&l){var e=wa(u).hoistableStyles,n=_u(l);t=t||"default";var f=e.get(n);if(!f){var i={loading:0,preload:null};if(f=u.querySelector(Se(n)))i.loading=5;else{l=R({rel:"stylesheet",href:l,"data-precedence":t},a),(a=zt.get(n))&&ic(l,a);var c=f=u.createElement("link");Ul(c),Bl(c,"link",l),c._p=new Promise(function(v,S){c.onload=v,c.onerror=S}),c.addEventListener("load",function(){i.loading|=1}),c.addEventListener("error",function(){i.loading|=2}),i.loading|=4,xn(f,t,u)}f={type:"stylesheet",instance:f,count:1,state:i},e.set(n,f)}}}function Pv(l,t){Ft.X(l,t);var a=Au;if(a&&l){var u=wa(a).hoistableScripts,e=Mu(l),n=u.get(e);n||(n=a.querySelector(re(e)),n||(l=R({src:l,async:!0},t),(t=zt.get(e))&&cc(l,t),n=a.createElement("script"),Ul(n),Bl(n,"link",l),a.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},u.set(e,n))}}function lm(l,t){Ft.M(l,t);var a=Au;if(a&&l){var u=wa(a).hoistableScripts,e=Mu(l),n=u.get(e);n||(n=a.querySelector(re(e)),n||(l=R({src:l,async:!0,type:"module"},t),(t=zt.get(e))&&cc(l,t),n=a.createElement("script"),Ul(n),Bl(n,"link",l),a.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},u.set(e,n))}}function yo(l,t,a,u){var e=(e=Q.current)?Un(e):null;if(!e)throw Error(h(446));switch(l){case"meta":case"title":return null;case"style":return typeof a.precedence=="string"&&typeof a.href=="string"?(t=_u(a.href),a=wa(e).hoistableStyles,u=a.get(t),u||(u={type:"style",instance:null,count:0,state:null},a.set(t,u)),u):{type:"void",instance:null,count:0,state:null};case"link":if(a.rel==="stylesheet"&&typeof a.href=="string"&&typeof a.precedence=="string"){l=_u(a.href);var n=wa(e).hoistableStyles,f=n.get(l);if(f||(e=e.ownerDocument||e,f={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},n.set(l,f),(n=e.querySelector(Se(l)))&&!n._p&&(f.instance=n,f.state.loading=5),zt.has(l)||(a={rel:"preload",as:"style",href:a.href,crossOrigin:a.crossOrigin,integrity:a.integrity,media:a.media,hrefLang:a.hrefLang,referrerPolicy:a.referrerPolicy},zt.set(l,a),n||tm(e,l,a,f.state))),t&&u===null)throw Error(h(528,""));return f}if(t&&u!==null)throw Error(h(529,""));return null;case"script":return t=a.async,a=a.src,typeof a=="string"&&t&&typeof t!="function"&&typeof t!="symbol"?(t=Mu(a),a=wa(e).hoistableScripts,u=a.get(t),u||(u={type:"script",instance:null,count:0,state:null},a.set(t,u)),u):{type:"void",instance:null,count:0,state:null};default:throw Error(h(444,l))}}function _u(l){return'href="'+yt(l)+'"'}function Se(l){return'link[rel="stylesheet"]['+l+"]"}function vo(l){return R({},l,{"data-precedence":l.precedence,precedence:null})}function tm(l,t,a,u){l.querySelector('link[rel="preload"][as="style"]['+t+"]")?u.loading=1:(t=l.createElement("link"),u.preload=t,t.addEventListener("load",function(){return u.loading|=1}),t.addEventListener("error",function(){return u.loading|=2}),Bl(t,"link",a),Ul(t),l.head.appendChild(t))}function Mu(l){return'[src="'+yt(l)+'"]'}function re(l){return"script[async]"+l}function mo(l,t,a){if(t.count++,t.instance===null)switch(t.type){case"style":var u=l.querySelector('style[data-href~="'+yt(a.href)+'"]');if(u)return t.instance=u,Ul(u),u;var e=R({},a,{"data-href":a.href,"data-precedence":a.precedence,href:null,precedence:null});return u=(l.ownerDocument||l).createElement("style"),Ul(u),Bl(u,"style",e),xn(u,a.precedence,l),t.instance=u;case"stylesheet":e=_u(a.href);var n=l.querySelector(Se(e));if(n)return t.state.loading|=4,t.instance=n,Ul(n),n;u=vo(a),(e=zt.get(e))&&ic(u,e),n=(l.ownerDocument||l).createElement("link"),Ul(n);var f=n;return f._p=new Promise(function(i,c){f.onload=i,f.onerror=c}),Bl(n,"link",u),t.state.loading|=4,xn(n,a.precedence,l),t.instance=n;case"script":return n=Mu(a.src),(e=l.querySelector(re(n)))?(t.instance=e,Ul(e),e):(u=a,(e=zt.get(n))&&(u=R({},a),cc(u,e)),l=l.ownerDocument||l,e=l.createElement("script"),Ul(e),Bl(e,"link",u),l.head.appendChild(e),t.instance=e);case"void":return null;default:throw Error(h(443,t.type))}else t.type==="stylesheet"&&(t.state.loading&4)===0&&(u=t.instance,t.state.loading|=4,xn(u,a.precedence,l));return t.instance}function xn(l,t,a){for(var u=a.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),e=u.length?u[u.length-1]:null,n=e,f=0;f<u.length;f++){var i=u[f];if(i.dataset.precedence===t)n=i;else if(n!==e)break}n?n.parentNode.insertBefore(l,n.nextSibling):(t=a.nodeType===9?a.head:a,t.insertBefore(l,t.firstChild))}function ic(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.title==null&&(l.title=t.title)}function cc(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.integrity==null&&(l.integrity=t.integrity)}var Hn=null;function ho(l,t,a){if(Hn===null){var u=new Map,e=Hn=new Map;e.set(a,u)}else e=Hn,u=e.get(a),u||(u=new Map,e.set(a,u));if(u.has(l))return u;for(u.set(l,null),a=a.getElementsByTagName(l),e=0;e<a.length;e++){var n=a[e];if(!(n[Cu]||n[Hl]||l==="link"&&n.getAttribute("rel")==="stylesheet")&&n.namespaceURI!=="http://www.w3.org/2000/svg"){var f=n.getAttribute(t)||"";f=l+f;var i=u.get(f);i?i.push(n):u.set(f,[n])}}return u}function go(l,t,a){l=l.ownerDocument||l,l.head.insertBefore(a,t==="title"?l.querySelector("head > title"):null)}function am(l,t,a){if(a===1||t.itemProp!=null)return!1;switch(l){case"meta":case"title":return!0;case"style":if(typeof t.precedence!="string"||typeof t.href!="string"||t.href==="")break;return!0;case"link":if(typeof t.rel!="string"||typeof t.href!="string"||t.href===""||t.onLoad||t.onError)break;switch(t.rel){case"stylesheet":return l=t.disabled,typeof t.precedence=="string"&&l==null;default:return!0}case"script":if(t.async&&typeof t.async!="function"&&typeof t.async!="symbol"&&!t.onLoad&&!t.onError&&t.src&&typeof t.src=="string")return!0}return!1}function So(l){return!(l.type==="stylesheet"&&(l.state.loading&3)===0)}function um(l,t,a,u){if(a.type==="stylesheet"&&(typeof u.media!="string"||matchMedia(u.media).matches!==!1)&&(a.state.loading&4)===0){if(a.instance===null){var e=_u(u.href),n=t.querySelector(Se(e));if(n){t=n._p,t!==null&&typeof t=="object"&&typeof t.then=="function"&&(l.count++,l=Rn.bind(l),t.then(l,l)),a.state.loading|=4,a.instance=n,Ul(n);return}n=t.ownerDocument||t,u=vo(u),(e=zt.get(e))&&ic(u,e),n=n.createElement("link"),Ul(n);var f=n;f._p=new Promise(function(i,c){f.onload=i,f.onerror=c}),Bl(n,"link",u),a.instance=n}l.stylesheets===null&&(l.stylesheets=new Map),l.stylesheets.set(a,t),(t=a.state.preload)&&(a.state.loading&3)===0&&(l.count++,a=Rn.bind(l),t.addEventListener("load",a),t.addEventListener("error",a))}}var sc=0;function em(l,t){return l.stylesheets&&l.count===0&&Cn(l,l.stylesheets),0<l.count||0<l.imgCount?function(a){var u=setTimeout(function(){if(l.stylesheets&&Cn(l,l.stylesheets),l.unsuspend){var n=l.unsuspend;l.unsuspend=null,n()}},6e4+t);0<l.imgBytes&&sc===0&&(sc=62500*Yv());var e=setTimeout(function(){if(l.waitingForImages=!1,l.count===0&&(l.stylesheets&&Cn(l,l.stylesheets),l.unsuspend)){var n=l.unsuspend;l.unsuspend=null,n()}},(l.imgBytes>sc?50:800)+t);return l.unsuspend=a,function(){l.unsuspend=null,clearTimeout(u),clearTimeout(e)}}:null}function Rn(){if(this.count--,this.count===0&&(this.imgCount===0||!this.waitingForImages)){if(this.stylesheets)Cn(this,this.stylesheets);else if(this.unsuspend){var l=this.unsuspend;this.unsuspend=null,l()}}}var Nn=null;function Cn(l,t){l.stylesheets=null,l.unsuspend!==null&&(l.count++,Nn=new Map,t.forEach(nm,l),Nn=null,Rn.call(l))}function nm(l,t){if(!(t.state.loading&4)){var a=Nn.get(l);if(a)var u=a.get(null);else{a=new Map,Nn.set(l,a);for(var e=l.querySelectorAll("link[data-precedence],style[data-precedence]"),n=0;n<e.length;n++){var f=e[n];(f.nodeName==="LINK"||f.getAttribute("media")!=="not all")&&(a.set(f.dataset.precedence,f),u=f)}u&&a.set(null,u)}e=t.instance,f=e.getAttribute("data-precedence"),n=a.get(f)||u,n===u&&a.set(null,e),a.set(f,e),this.count++,u=Rn.bind(this),e.addEventListener("load",u),e.addEventListener("error",u),n?n.parentNode.insertBefore(e,n.nextSibling):(l=l.nodeType===9?l.head:l,l.insertBefore(e,l.firstChild)),t.state.loading|=4}}var be={$$typeof:Gl,Provider:null,Consumer:null,_currentValue:C,_currentValue2:C,_threadCount:0};function fm(l,t,a,u,e,n,f,i,c){this.tag=1,this.containerInfo=l,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=uf(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=uf(0),this.hiddenUpdates=uf(null),this.identifierPrefix=u,this.onUncaughtError=e,this.onCaughtError=n,this.onRecoverableError=f,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=c,this.incompleteTransitions=new Map}function ro(l,t,a,u,e,n,f,i,c,v,S,z){return l=new fm(l,t,a,f,c,v,S,z,i),t=1,n===!0&&(t|=24),n=et(3,null,null,t),l.current=n,n.stateNode=l,t=Zf(),t.refCount++,l.pooledCache=t,t.refCount++,n.memoizedState={element:u,isDehydrated:a,cache:t},Jf(n),l}function bo(l){return l?(l=uu,l):uu}function zo(l,t,a,u,e,n){e=bo(e),u.context===null?u.context=e:u.pendingContext=e,u=fa(t),u.payload={element:a},n=n===void 0?null:n,n!==null&&(u.callback=n),a=ia(l,u,t),a!==null&&(Fl(a,l,t),Fu(a,l,t))}function To(l,t){if(l=l.memoizedState,l!==null&&l.dehydrated!==null){var a=l.retryLane;l.retryLane=a!==0&&a<t?a:t}}function dc(l,t){To(l,t),(l=l.alternate)&&To(l,t)}function Eo(l){if(l.tag===13||l.tag===31){var t=xa(l,67108864);t!==null&&Fl(t,l,67108864),dc(l,67108864)}}function po(l){if(l.tag===13||l.tag===31){var t=st();t=ef(t);var a=xa(l,t);a!==null&&Fl(a,l,t),dc(l,t)}}var Bn=!0;function im(l,t,a,u){var e=r.T;r.T=null;var n=A.p;try{A.p=2,oc(l,t,a,u)}finally{A.p=n,r.T=e}}function cm(l,t,a,u){var e=r.T;r.T=null;var n=A.p;try{A.p=8,oc(l,t,a,u)}finally{A.p=n,r.T=e}}function oc(l,t,a,u){if(Bn){var e=yc(u);if(e===null)Fi(l,t,u,qn,a),_o(l,u);else if(dm(e,l,t,a,u))u.stopPropagation();else if(_o(l,u),t&4&&-1<sm.indexOf(l)){for(;e!==null;){var n=Ja(e);if(n!==null)switch(n.tag){case 3:if(n=n.stateNode,n.current.memoizedState.isDehydrated){var f=_a(n.pendingLanes);if(f!==0){var i=n;for(i.pendingLanes|=2,i.entangledLanes|=2;f;){var c=1<<31-at(f);i.entanglements[1]|=c,f&=~c}Ht(n),(ll&6)===0&&(rn=lt()+500,ve(0))}}break;case 31:case 13:i=xa(n,2),i!==null&&Fl(i,n,2),zn(),dc(n,2)}if(n=yc(u),n===null&&Fi(l,t,u,qn,a),n===e)break;e=n}e!==null&&u.stopPropagation()}else Fi(l,t,u,null,a)}}function yc(l){return l=mf(l),vc(l)}var qn=null;function vc(l){if(qn=null,l=Ka(l),l!==null){var t=Sl(l);if(t===null)l=null;else{var a=t.tag;if(a===13){if(l=rl(t),l!==null)return l;l=null}else if(a===31){if(l=Dl(t),l!==null)return l;l=null}else if(a===3){if(t.stateNode.current.memoizedState.isDehydrated)return t.tag===3?t.stateNode.containerInfo:null;l=null}else t!==l&&(l=null)}}return qn=l,null}function Ao(l){switch(l){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(Wo()){case Hc:return 2;case Rc:return 8;case Ae:case $o:return 32;case Nc:return 268435456;default:return 32}default:return 32}}var mc=!1,ra=null,ba=null,za=null,ze=new Map,Te=new Map,Ta=[],sm="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function _o(l,t){switch(l){case"focusin":case"focusout":ra=null;break;case"dragenter":case"dragleave":ba=null;break;case"mouseover":case"mouseout":za=null;break;case"pointerover":case"pointerout":ze.delete(t.pointerId);break;case"gotpointercapture":case"lostpointercapture":Te.delete(t.pointerId)}}function Ee(l,t,a,u,e,n){return l===null||l.nativeEvent!==n?(l={blockedOn:t,domEventName:a,eventSystemFlags:u,nativeEvent:n,targetContainers:[e]},t!==null&&(t=Ja(t),t!==null&&Eo(t)),l):(l.eventSystemFlags|=u,t=l.targetContainers,e!==null&&t.indexOf(e)===-1&&t.push(e),l)}function dm(l,t,a,u,e){switch(t){case"focusin":return ra=Ee(ra,l,t,a,u,e),!0;case"dragenter":return ba=Ee(ba,l,t,a,u,e),!0;case"mouseover":return za=Ee(za,l,t,a,u,e),!0;case"pointerover":var n=e.pointerId;return ze.set(n,Ee(ze.get(n)||null,l,t,a,u,e)),!0;case"gotpointercapture":return n=e.pointerId,Te.set(n,Ee(Te.get(n)||null,l,t,a,u,e)),!0}return!1}function Mo(l){var t=Ka(l.target);if(t!==null){var a=Sl(t);if(a!==null){if(t=a.tag,t===13){if(t=rl(a),t!==null){l.blockedOn=t,Gc(l.priority,function(){po(a)});return}}else if(t===31){if(t=Dl(a),t!==null){l.blockedOn=t,Gc(l.priority,function(){po(a)});return}}else if(t===3&&a.stateNode.current.memoizedState.isDehydrated){l.blockedOn=a.tag===3?a.stateNode.containerInfo:null;return}}}l.blockedOn=null}function jn(l){if(l.blockedOn!==null)return!1;for(var t=l.targetContainers;0<t.length;){var a=yc(l.nativeEvent);if(a===null){a=l.nativeEvent;var u=new a.constructor(a.type,a);vf=u,a.target.dispatchEvent(u),vf=null}else return t=Ja(a),t!==null&&Eo(t),l.blockedOn=a,!1;t.shift()}return!0}function Oo(l,t,a){jn(l)&&a.delete(t)}function om(){mc=!1,ra!==null&&jn(ra)&&(ra=null),ba!==null&&jn(ba)&&(ba=null),za!==null&&jn(za)&&(za=null),ze.forEach(Oo),Te.forEach(Oo)}function Yn(l,t){l.blockedOn===t&&(l.blockedOn=null,mc||(mc=!0,p.unstable_scheduleCallback(p.unstable_NormalPriority,om)))}var Gn=null;function Do(l){Gn!==l&&(Gn=l,p.unstable_scheduleCallback(p.unstable_NormalPriority,function(){Gn===l&&(Gn=null);for(var t=0;t<l.length;t+=3){var a=l[t],u=l[t+1],e=l[t+2];if(typeof u!="function"){if(vc(u||a)===null)continue;break}var n=Ja(a);n!==null&&(l.splice(t,3),t-=3,yi(n,{pending:!0,data:e,method:a.method,action:u},u,e))}}))}function Ou(l){function t(c){return Yn(c,l)}ra!==null&&Yn(ra,l),ba!==null&&Yn(ba,l),za!==null&&Yn(za,l),ze.forEach(t),Te.forEach(t);for(var a=0;a<Ta.length;a++){var u=Ta[a];u.blockedOn===l&&(u.blockedOn=null)}for(;0<Ta.length&&(a=Ta[0],a.blockedOn===null);)Mo(a),a.blockedOn===null&&Ta.shift();if(a=(l.ownerDocument||l).$$reactFormReplay,a!=null)for(u=0;u<a.length;u+=3){var e=a[u],n=a[u+1],f=e[Kl]||null;if(typeof n=="function")f||Do(a);else if(f){var i=null;if(n&&n.hasAttribute("formAction")){if(e=n,f=n[Kl]||null)i=f.formAction;else if(vc(e)!==null)continue}else i=f.action;typeof i=="function"?a[u+1]=i:(a.splice(u,3),u-=3),Do(a)}}}function Uo(){function l(n){n.canIntercept&&n.info==="react-transition"&&n.intercept({handler:function(){return new Promise(function(f){return e=f})},focusReset:"manual",scroll:"manual"})}function t(){e!==null&&(e(),e=null),u||setTimeout(a,20)}function a(){if(!u&&!navigation.transition){var n=navigation.currentEntry;n&&n.url!=null&&navigation.navigate(n.url,{state:n.getState(),info:"react-transition",history:"replace"})}}if(typeof navigation=="object"){var u=!1,e=null;return navigation.addEventListener("navigate",l),navigation.addEventListener("navigatesuccess",t),navigation.addEventListener("navigateerror",t),setTimeout(a,100),function(){u=!0,navigation.removeEventListener("navigate",l),navigation.removeEventListener("navigatesuccess",t),navigation.removeEventListener("navigateerror",t),e!==null&&(e(),e=null)}}}function hc(l){this._internalRoot=l}Xn.prototype.render=hc.prototype.render=function(l){var t=this._internalRoot;if(t===null)throw Error(h(409));var a=t.current,u=st();zo(a,u,l,t,null,null)},Xn.prototype.unmount=hc.prototype.unmount=function(){var l=this._internalRoot;if(l!==null){this._internalRoot=null;var t=l.containerInfo;zo(l.current,2,null,l,null,null),zn(),t[La]=null}};function Xn(l){this._internalRoot=l}Xn.prototype.unstable_scheduleHydration=function(l){if(l){var t=Yc();l={blockedOn:null,target:l,priority:t};for(var a=0;a<Ta.length&&t!==0&&t<Ta[a].priority;a++);Ta.splice(a,0,l),a===0&&Mo(l)}};var xo=cl.version;if(xo!=="19.2.4")throw Error(h(527,xo,"19.2.4"));A.findDOMNode=function(l){var t=l._reactInternals;if(t===void 0)throw typeof l.render=="function"?Error(h(188)):(l=Object.keys(l).join(","),Error(h(268,l)));return l=E(t),l=l!==null?k(l):null,l=l===null?null:l.stateNode,l};var ym={bundleType:0,version:"19.2.4",rendererPackageName:"react-dom",currentDispatcherRef:r,reconcilerVersion:"19.2.4"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var Qn=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!Qn.isDisabled&&Qn.supportsFiber)try{Hu=Qn.inject(ym),tt=Qn}catch{}}return Uu.createRoot=function(l,t){if(!vl(l))throw Error(h(299));var a=!1,u="",e=q0,n=j0,f=Y0;return t!=null&&(t.unstable_strictMode===!0&&(a=!0),t.identifierPrefix!==void 0&&(u=t.identifierPrefix),t.onUncaughtError!==void 0&&(e=t.onUncaughtError),t.onCaughtError!==void 0&&(n=t.onCaughtError),t.onRecoverableError!==void 0&&(f=t.onRecoverableError)),t=ro(l,1,!1,null,null,a,u,null,e,n,f,Uo),l[La]=t.current,ki(l),new hc(t)},Uu.hydrateRoot=function(l,t,a){if(!vl(l))throw Error(h(299));var u=!1,e="",n=q0,f=j0,i=Y0,c=null;return a!=null&&(a.unstable_strictMode===!0&&(u=!0),a.identifierPrefix!==void 0&&(e=a.identifierPrefix),a.onUncaughtError!==void 0&&(n=a.onUncaughtError),a.onCaughtError!==void 0&&(f=a.onCaughtError),a.onRecoverableError!==void 0&&(i=a.onRecoverableError),a.formState!==void 0&&(c=a.formState)),t=ro(l,1,!0,t,a??null,u,e,c,n,f,i,Uo),t.context=bo(null),a=t.current,u=st(),u=ef(u),e=fa(u),e.callback=null,ia(a,e,u),a=u,t.current.lanes=a,Nu(t,a),Ht(t),l[La]=t.current,ki(l),new Xn(t)},Uu.version="19.2.4",Uu}var _c;function Go(){if(_c)return Vn.exports;_c=1;function p(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(p)}catch(cl){console.error(cl)}}return p(),Vn.exports=Yo(),Vn.exports}var Xo=Go(),Rt=wn();const L={bg:"var(--bg)",bgCard:"var(--bg2)",accent:"var(--accent)",text:"var(--text)",textMuted:"var(--text2)",error:"var(--red)",border:"var(--border)",danger:"var(--red)"},X={container:{background:L.bg,color:L.text,fontFamily:"'Inter', 'Segoe UI', system-ui, sans-serif",fontSize:"14px",padding:"16px",borderRadius:"8px",border:`1px solid ${L.border}`,minWidth:"360px"},header:{display:"flex",alignItems:"center",justifyContent:"space-between",marginBottom:"16px"},title:{margin:0,fontSize:"16px",fontWeight:600,color:L.text},refreshBtn:{background:"transparent",border:`1px solid ${L.border}`,color:L.textMuted,borderRadius:"6px",padding:"4px 10px",cursor:"pointer",fontSize:"13px",transition:"color 0.15s, border-color 0.15s"},form:{background:L.bgCard,border:`1px solid ${L.border}`,borderRadius:"8px",padding:"12px",marginBottom:"16px"},textarea:{width:"100%",background:L.bg,border:`1px solid ${L.border}`,borderRadius:"6px",color:L.text,padding:"8px 10px",fontSize:"13px",resize:"vertical",minHeight:"72px",boxSizing:"border-box",outline:"none",fontFamily:"inherit"},formRow:{display:"flex",gap:"8px",marginTop:"8px",alignItems:"center"},select:{background:L.bg,border:`1px solid ${L.border}`,borderRadius:"6px",color:L.text,padding:"6px 10px",fontSize:"13px",outline:"none",cursor:"pointer",flex:"0 0 auto"},spawnBtn:{background:L.accent,border:"none",borderRadius:"6px",color:"white",padding:"6px 16px",fontSize:"13px",fontWeight:600,cursor:"pointer",flex:"1",transition:"background 0.15s"},spawnBtnDisabled:{background:"var(--accent-dim, rgba(99,140,255,0.3))",cursor:"not-allowed",opacity:.6},section:{marginBottom:"12px"},sectionTitle:{fontSize:"11px",fontWeight:700,textTransform:"uppercase",letterSpacing:"0.08em",color:L.textMuted,marginBottom:"8px",marginTop:0},taskCard:{background:L.bgCard,border:`1px solid ${L.border}`,borderRadius:"6px",padding:"10px 12px",marginBottom:"6px",display:"flex",flexDirection:"column",gap:"6px"},taskRow:{display:"flex",alignItems:"center",justifyContent:"space-between",gap:"8px"},taskDesc:{color:L.text,fontSize:"13px",flex:1,overflow:"hidden",textOverflow:"ellipsis",whiteSpace:"nowrap"},taskMeta:{display:"flex",alignItems:"center",gap:"8px",flexShrink:0},modelBadge:{background:"var(--accent-dim, rgba(99,140,255,0.15))",color:"var(--accent)",borderRadius:"4px",padding:"2px 6px",fontSize:"11px",fontWeight:600,textTransform:"capitalize"},elapsed:{color:L.textMuted,fontSize:"12px",flexShrink:0},spinner:{display:"inline-block",width:"14px",height:"14px",border:`2px solid ${L.border}`,borderTopColor:L.accent,borderRadius:"50%",flexShrink:0},killBtn:{background:"transparent",border:`1px solid ${L.danger}`,color:L.error,borderRadius:"4px",padding:"2px 8px",fontSize:"12px",cursor:"pointer",flexShrink:0},viewBtn:{background:"transparent",border:`1px solid ${L.border}`,color:L.textMuted,borderRadius:"4px",padding:"2px 8px",fontSize:"12px",cursor:"pointer",flexShrink:0},emptyState:{color:L.textMuted,fontSize:"13px",textAlign:"center",padding:"12px 0",fontStyle:"italic"},errorMsg:{color:L.error,fontSize:"12px",marginTop:"6px"},modalOverlay:{position:"fixed",inset:0,background:"rgba(0,0,0,0.7)",display:"flex",alignItems:"center",justifyContent:"center",zIndex:9999},modalBox:{background:L.bgCard,border:`1px solid ${L.border}`,borderRadius:"10px",width:"90vw",maxWidth:"640px",maxHeight:"80vh",display:"flex",flexDirection:"column",overflow:"hidden"},modalHeader:{display:"flex",alignItems:"center",justifyContent:"space-between",padding:"12px 16px",borderBottom:`1px solid ${L.border}`},modalTitle:{color:L.text,fontWeight:600,fontSize:"14px",margin:0},modalCloseBtn:{background:"transparent",border:"none",color:L.textMuted,fontSize:"18px",cursor:"pointer",lineHeight:1,padding:"0 4px"},modalBody:{overflowY:"auto",padding:"16px",flex:1},outputPre:{background:L.bg,border:`1px solid ${L.border}`,borderRadius:"6px",padding:"12px",color:L.text,fontSize:"12px",fontFamily:"'JetBrains Mono', 'Fira Code', monospace",whiteSpace:"pre-wrap",wordBreak:"break-all",margin:0,lineHeight:1.6}};function Mc(p){if(p<1e3)return`${p}ms`;if(p<6e4)return`${(p/1e3).toFixed(1)}s`;const cl=Math.floor(p/6e4),$=Math.floor(p%6e4/1e3);return`${cl}m ${$}s`}function $n(p,cl){return p.length>cl?p.slice(0,cl)+"…":p}function Qo(){return window._tok||localStorage.getItem("session_token")||""}function kn(){return{"Content-Type":"application/json","X-Session-Token":Qo()}}let Oc=!1;function Zo(){if(Oc)return;Oc=!0;const p=document.createElement("style");p.textContent="@keyframes _salmalm_spin { to { transform: rotate(360deg); } }",document.head.appendChild(p)}function Vo({task:p,onClose:cl}){return B.jsx("div",{style:X.modalOverlay,onClick:cl,children:B.jsxs("div",{style:X.modalBox,onClick:$=>$.stopPropagation(),children:[B.jsxs("div",{style:X.modalHeader,children:[B.jsxs("p",{style:X.modalTitle,children:["Task Output — ",$n(p.description,60)]}),B.jsx("button",{style:X.modalCloseBtn,onClick:cl,children:"×"})]}),B.jsx("div",{style:X.modalBody,children:B.jsx("pre",{style:X.outputPre,children:p.output||p.result_preview||"(no output)"})})]})})}function Lo(){const[p,cl]=Rt.useState([]),[$,h]=Rt.useState(""),[vl,Sl]=Rt.useState("auto"),[rl,Dl]=Rt.useState(!1),[U,E]=Rt.useState(""),[k,R]=Rt.useState(null);Rt.useEffect(()=>{Zo()},[]);const P=Rt.useCallback(async()=>{try{const H=await fetch("/api/agent/tasks",{headers:kn()});if(H.ok){const Pl=await H.json();cl(Pl.tasks??[])}}catch{}},[]);Rt.useEffect(()=>{P();const H=setInterval(P,3e3);return()=>clearInterval(H)},[P]);const jl=async()=>{if($.trim()){Dl(!0),E("");try{const Pl=await(await fetch("/api/agent/task",{method:"POST",headers:kn(),body:JSON.stringify({description:$.trim(),model:vl})})).json();Pl.ok?(h(""),await P()):E(Pl.error||"Failed to spawn agent")}catch(H){E((H==null?void 0:H.message)||"Network error")}finally{Dl(!1)}}},Yl=async H=>{try{await fetch(`/api/agent/task/${H}`,{method:"DELETE",headers:kn()}),await P()}catch{}},Ml=p.filter(H=>H.status==="running"||H.status==="pending"),Il=p.filter(H=>H.status==="done"||H.status==="failed"||H.status==="cancelled");return B.jsxs("div",{style:X.container,children:[B.jsxs("div",{style:X.header,children:[B.jsx("h2",{style:X.title,children:"🤖 Agent Tasks"}),B.jsx("button",{style:X.refreshBtn,onClick:P,children:"↻ Refresh"})]}),B.jsxs("div",{style:X.form,children:[B.jsx("textarea",{style:X.textarea,value:$,onChange:H=>h(H.target.value),placeholder:"Describe what you want the agent to do...",rows:3,onKeyDown:H=>{H.key==="Enter"&&(H.ctrlKey||H.metaKey)&&jl()}}),B.jsxs("div",{style:X.formRow,children:[B.jsxs("select",{style:X.select,value:vl,onChange:H=>Sl(H.target.value),children:[B.jsx("option",{value:"auto",children:"auto"}),B.jsx("option",{value:"haiku",children:"haiku"}),B.jsx("option",{value:"sonnet",children:"sonnet"}),B.jsx("option",{value:"opus",children:"opus"})]}),B.jsx("button",{style:{...X.spawnBtn,...rl?X.spawnBtnDisabled:{}},disabled:rl,onClick:jl,children:rl?"Spawning…":"⚡ Spawn Agent"})]}),U&&B.jsxs("p",{style:X.errorMsg,children:["⚠ ",U]})]}),B.jsxs("div",{style:X.section,children:[B.jsxs("p",{style:X.sectionTitle,children:["⚙ Active (",Ml.length,")"]}),Ml.length===0?B.jsx("p",{style:X.emptyState,children:"No active tasks — spawn one above!"}):Ml.map(H=>B.jsx("div",{style:X.taskCard,children:B.jsxs("div",{style:X.taskRow,children:[B.jsx("span",{style:{...X.spinner,animation:"_salmalm_spin 0.8s linear infinite"}}),B.jsx("span",{style:X.taskDesc,children:$n(H.description,80)}),B.jsxs("div",{style:X.taskMeta,children:[B.jsx("span",{style:X.modelBadge,children:H.model}),B.jsx("span",{style:X.elapsed,children:Mc(H.elapsed_ms)}),B.jsx("button",{style:X.killBtn,onClick:()=>Yl(H.id),children:"Kill"})]})]})},H.id))]}),B.jsxs("div",{style:X.section,children:[B.jsxs("p",{style:X.sectionTitle,children:["✓ Completed (",Il.length,")"]}),Il.length===0?B.jsx("p",{style:X.emptyState,children:"Completed tasks will appear here."}):Il.map(H=>B.jsx("div",{style:X.taskCard,children:B.jsxs("div",{style:X.taskRow,children:[B.jsx("span",{style:{fontSize:"15px",flexShrink:0},children:H.status==="done"?"✅":"❌"}),B.jsx("span",{style:X.taskDesc,children:$n(H.description,80)}),B.jsxs("div",{style:X.taskMeta,children:[B.jsx("span",{style:X.modelBadge,children:H.model}),B.jsx("span",{style:X.elapsed,children:Mc(H.elapsed_ms)}),B.jsx("button",{style:X.viewBtn,onClick:()=>R(H),children:"View Output"})]})]})},H.id))]}),k&&B.jsx(Vo,{task:k,onClose:()=>R(null)})]})}const Dc=()=>{const p=document.getElementById("agent-panel-root");p&&Xo.createRoot(p).render(B.jsx(Lo,{}))};document.readyState==="loading"?document.addEventListener("DOMContentLoaded",Dc):Dc()})();
